/* Generated by Cython 0.17.3 on Thu Sep 11 21:37:57 2014 */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02040000
    #error Cython requires Python 2.4+.
#else
#include <stddef.h> /* For offsetof */
#ifndef offsetof
#define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
#define CYTHON_COMPILING_IN_PYPY 1
#define CYTHON_COMPILING_IN_CPYTHON 0
#else
#define CYTHON_COMPILING_IN_PYPY 0
#define CYTHON_COMPILING_IN_CPYTHON 1
#endif
#if PY_VERSION_HEX < 0x02050000
  typedef int Py_ssize_t;
  #define PY_SSIZE_T_MAX INT_MAX
  #define PY_SSIZE_T_MIN INT_MIN
  #define PY_FORMAT_SIZE_T ""
  #define CYTHON_FORMAT_SSIZE_T ""
  #define PyInt_FromSsize_t(z) PyInt_FromLong(z)
  #define PyInt_AsSsize_t(o)   __Pyx_PyInt_AsInt(o)
  #define PyNumber_Index(o)    ((PyNumber_Check(o) && !PyFloat_Check(o)) ? PyNumber_Int(o) : \
                                (PyErr_Format(PyExc_TypeError, \
                                              "expected index value, got %.200s", Py_TYPE(o)->tp_name), \
                                 (PyObject*)0))
  #define __Pyx_PyIndex_Check(o) (PyNumber_Check(o) && !PyFloat_Check(o) && \
                                  !PyComplex_Check(o))
  #define PyIndex_Check __Pyx_PyIndex_Check
  #define PyErr_WarnEx(category, message, stacklevel) PyErr_Warn(category, message)
  #define __PYX_BUILD_PY_SSIZE_T "i"
#else
  #define __PYX_BUILD_PY_SSIZE_T "n"
  #define CYTHON_FORMAT_SSIZE_T "z"
  #define __Pyx_PyIndex_Check PyIndex_Check
#endif
#if PY_VERSION_HEX < 0x02060000
  #define Py_REFCNT(ob) (((PyObject*)(ob))->ob_refcnt)
  #define Py_TYPE(ob)   (((PyObject*)(ob))->ob_type)
  #define Py_SIZE(ob)   (((PyVarObject*)(ob))->ob_size)
  #define PyVarObject_HEAD_INIT(type, size) \
          PyObject_HEAD_INIT(type) size,
  #define PyType_Modified(t)
  typedef struct {
     void *buf;
     PyObject *obj;
     Py_ssize_t len;
     Py_ssize_t itemsize;
     int readonly;
     int ndim;
     char *format;
     Py_ssize_t *shape;
     Py_ssize_t *strides;
     Py_ssize_t *suboffsets;
     void *internal;
  } Py_buffer;
  #define PyBUF_SIMPLE 0
  #define PyBUF_WRITABLE 0x0001
  #define PyBUF_FORMAT 0x0004
  #define PyBUF_ND 0x0008
  #define PyBUF_STRIDES (0x0010 | PyBUF_ND)
  #define PyBUF_C_CONTIGUOUS (0x0020 | PyBUF_STRIDES)
  #define PyBUF_F_CONTIGUOUS (0x0040 | PyBUF_STRIDES)
  #define PyBUF_ANY_CONTIGUOUS (0x0080 | PyBUF_STRIDES)
  #define PyBUF_INDIRECT (0x0100 | PyBUF_STRIDES)
  #define PyBUF_RECORDS (PyBUF_STRIDES | PyBUF_FORMAT | PyBUF_WRITABLE)
  #define PyBUF_FULL (PyBUF_INDIRECT | PyBUF_FORMAT | PyBUF_WRITABLE)
  typedef int (*getbufferproc)(PyObject *, Py_buffer *, int);
  typedef void (*releasebufferproc)(PyObject *, Py_buffer *);
#endif
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
#if PY_MAJOR_VERSION < 3 && PY_MINOR_VERSION < 6
  #define PyUnicode_FromString(s) PyUnicode_Decode(s, strlen(s), "UTF-8", "strict")
#endif
#if PY_MAJOR_VERSION >= 3
  #define Py_TPFLAGS_CHECKTYPES 0
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#if (PY_VERSION_HEX < 0x02060000) || (PY_MAJOR_VERSION >= 3)
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ? \
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
#else
  #define CYTHON_PEP393_ENABLED 0
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((k=k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PyBytesObject                PyStringObject
  #define PyBytes_Type                 PyString_Type
  #define PyBytes_Check                PyString_Check
  #define PyBytes_CheckExact           PyString_CheckExact
  #define PyBytes_FromString           PyString_FromString
  #define PyBytes_FromStringAndSize    PyString_FromStringAndSize
  #define PyBytes_FromFormat           PyString_FromFormat
  #define PyBytes_DecodeEscape         PyString_DecodeEscape
  #define PyBytes_AsString             PyString_AsString
  #define PyBytes_AsStringAndSize      PyString_AsStringAndSize
  #define PyBytes_Size                 PyString_Size
  #define PyBytes_AS_STRING            PyString_AS_STRING
  #define PyBytes_GET_SIZE             PyString_GET_SIZE
  #define PyBytes_Repr                 PyString_Repr
  #define PyBytes_Concat               PyString_Concat
  #define PyBytes_ConcatAndDel         PyString_ConcatAndDel
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PySet_Check(obj)             PyObject_TypeCheck(obj, &PySet_Type)
  #define PyFrozenSet_Check(obj)       PyObject_TypeCheck(obj, &PyFrozenSet_Type)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_VERSION_HEX < 0x03020000
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if (PY_MAJOR_VERSION < 3) || (PY_VERSION_HEX >= 0x03010300)
  #define __Pyx_PySequence_GetSlice(obj, a, b) PySequence_GetSlice(obj, a, b)
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) PySequence_SetSlice(obj, a, b, value)
  #define __Pyx_PySequence_DelSlice(obj, a, b) PySequence_DelSlice(obj, a, b)
#else
  #define __Pyx_PySequence_GetSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), (PyObject*)0) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_GetSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object is unsliceable", (obj)->ob_type->tp_name), (PyObject*)0)))
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_SetSlice(obj, a, b, value)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice assignment", (obj)->ob_type->tp_name), -1)))
  #define __Pyx_PySequence_DelSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_DelSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice deletion", (obj)->ob_type->tp_name), -1)))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : PyInstanceMethod_New(func))
#endif
#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),((char *)(n)))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),((char *)(n)),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),((char *)(n)))
#else
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),(n))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),(n),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),(n))
#endif
#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_NAMESTR(n) ((char *)(n))
  #define __Pyx_DOCSTR(n)  ((char *)(n))
#else
  #define __Pyx_NAMESTR(n) (n)
  #define __Pyx_DOCSTR(n)  (n)
#endif


#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
#define _USE_MATH_DEFINES
#endif
#include <math.h>
#define __PYX_HAVE__cymysql__charsetx
#define __PYX_HAVE_API__cymysql__charsetx
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#ifdef PYREX_WITHOUT_ASSERTIONS
#define CYTHON_WITHOUT_ASSERTIONS
#endif


/* inline attribute */
#ifndef CYTHON_INLINE
  #if defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

/* unused attribute */
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif

typedef struct {PyObject **p; char *s; const long n; const char* encoding; const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry; /*proto*/


/* Type Conversion Predeclarations */

#define __Pyx_PyBytes_FromUString(s) PyBytes_FromString((char*)s)
#define __Pyx_PyBytes_AsUString(s)   ((unsigned char*) PyBytes_AsString(s))

#define __Pyx_Owned_Py_None(b) (Py_INCREF(Py_None), Py_None)
#define __Pyx_PyBool_FromLong(b) ((b) ? (Py_INCREF(Py_True), Py_True) : (Py_INCREF(Py_False), Py_False))
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x);

static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE size_t __Pyx_PyInt_AsSize_t(PyObject*);

#if CYTHON_COMPILING_IN_CPYTHON
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))

#ifdef __GNUC__
  /* Test for GCC > 2.95 */
  #if __GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95))
    #define likely(x)   __builtin_expect(!!(x), 1)
    #define unlikely(x) __builtin_expect(!!(x), 0)
  #else /* __GNUC__ > 2 ... */
    #define likely(x)   (x)
    #define unlikely(x) (x)
  #endif /* __GNUC__ > 2 ... */
#else /* __GNUC__ */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
    
static PyObject *__pyx_m;
static PyObject *__pyx_b;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "charsetx.pyx",
};

/*--- Type declarations ---*/
struct __pyx_obj_7cymysql_8charsetx_Charset;
struct __pyx_obj_7cymysql_8charsetx_Charsets;

/* "cymysql/charsetx.pyx":1
 * cdef class Charset(object):             # <<<<<<<<<<<<<<
 *     cdef public int id
 *     cdef public str name, collation
 */
struct __pyx_obj_7cymysql_8charsetx_Charset {
  PyObject_HEAD
  int id;
  PyObject *name;
  PyObject *collation;
  int is_default;
};


/* "cymysql/charsetx.pyx":9
 *         self.is_default = is_default == 'Yes'
 * 
 * cdef class Charsets(object):             # <<<<<<<<<<<<<<
 *     cdef dict _by_id
 *     cdef object by_id
 */
struct __pyx_obj_7cymysql_8charsetx_Charsets {
  PyObject_HEAD
  PyObject *_by_id;
  PyObject *by_id;
};

#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname); /*proto*/
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          if (acquire_gil) { \
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure(); \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
              PyGILState_Release(__pyx_gilstate_save); \
          } else { \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext() \
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif /* CYTHON_REFNANNY */
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found); /*proto*/

static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name); /*proto*/

static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[], \
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args, \
    const char* function_name); /*proto*/

static CYTHON_INLINE int __Pyx_CheckKeywordStrings(PyObject *kwdict, const char* function_name, int kw_allowed); /*proto*/

static int __Pyx_ArgTypeTest(PyObject *obj, PyTypeObject *type, int none_allowed,
    const char *name, int exact); /*proto*/

#define __Pyx_SetItemInt(o, i, v, size, to_py_func) (((size) <= sizeof(Py_ssize_t)) ? \
                                                    __Pyx_SetItemInt_Fast(o, i, v) : \
                                                    __Pyx_SetItemInt_Generic(o, to_py_func(i), v))
static CYTHON_INLINE int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v) {
    int r;
    if (!j) return -1;
    r = PyObject_SetItem(o, j, v);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v) {
#if CYTHON_COMPILING_IN_CPYTHON
    if (PyList_CheckExact(o)) {
        Py_ssize_t n = (likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if (likely((n >= 0) & (n < PyList_GET_SIZE(o)))) {
            PyObject* old = PyList_GET_ITEM(o, n);
            Py_INCREF(v);
            PyList_SET_ITEM(o, n, v);
            Py_DECREF(old);
            return 1;
        }
    } else {  /* inlined PySequence_SetItem() */
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_ass_item)) {
            if (unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (unlikely(l < 0)) return -1;
                i += l;
            }
            return m->sq_ass_item(o, i, v);
        }
    }
#else
#if CYTHON_COMPILING_IN_PYPY
    if (PySequence_Check(o) && !PyDict_Check(o)) {
#else
    if (PySequence_Check(o)) {
#endif
        return PySequence_SetItem(o, i, v);
    }
#endif
    return __Pyx_SetItemInt_Generic(o, PyInt_FromSsize_t(i), v);
}

static CYTHON_INLINE int __Pyx_IterFinish(void); /*proto*/

static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index); /*proto*/

static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected); /*proto*/

static CYTHON_INLINE int __Pyx_unpack_tuple2(PyObject* tuple, PyObject** value1, PyObject** value2,
                                             int is_tuple, int has_known_size, int decref_tuple);

static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type); /*proto*/

static CYTHON_INLINE unsigned char __Pyx_PyInt_AsUnsignedChar(PyObject *);

static CYTHON_INLINE unsigned short __Pyx_PyInt_AsUnsignedShort(PyObject *);

static CYTHON_INLINE unsigned int __Pyx_PyInt_AsUnsignedInt(PyObject *);

static CYTHON_INLINE char __Pyx_PyInt_AsChar(PyObject *);

static CYTHON_INLINE short __Pyx_PyInt_AsShort(PyObject *);

static CYTHON_INLINE int __Pyx_PyInt_AsInt(PyObject *);

static CYTHON_INLINE signed char __Pyx_PyInt_AsSignedChar(PyObject *);

static CYTHON_INLINE signed short __Pyx_PyInt_AsSignedShort(PyObject *);

static CYTHON_INLINE signed int __Pyx_PyInt_AsSignedInt(PyObject *);

static CYTHON_INLINE int __Pyx_PyInt_AsLongDouble(PyObject *);

static CYTHON_INLINE unsigned long __Pyx_PyInt_AsUnsignedLong(PyObject *);

static CYTHON_INLINE unsigned PY_LONG_LONG __Pyx_PyInt_AsUnsignedLongLong(PyObject *);

static CYTHON_INLINE long __Pyx_PyInt_AsLong(PyObject *);

static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_AsLongLong(PyObject *);

static CYTHON_INLINE signed long __Pyx_PyInt_AsSignedLong(PyObject *);

static CYTHON_INLINE signed PY_LONG_LONG __Pyx_PyInt_AsSignedLongLong(PyObject *);

static int __Pyx_check_binary_version(void);

typedef struct {
    int code_line;
    PyCodeObject* code_object;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename); /*proto*/

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t); /*proto*/


/* Module declarations from 'cymysql.charsetx' */
static PyTypeObject *__pyx_ptype_7cymysql_8charsetx_Charset = 0;
static PyTypeObject *__pyx_ptype_7cymysql_8charsetx_Charsets = 0;
static struct __pyx_obj_7cymysql_8charsetx_Charsets *__pyx_v_7cymysql_8charsetx__charsets = 0;
#define __Pyx_MODULE_NAME "cymysql.charsetx"
int __pyx_module_is_main_cymysql__charsetx = 0;

/* Implementation of 'cymysql.charsetx' */
static int __pyx_pf_7cymysql_8charsetx_7Charset___init__(struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_self, PyObject *__pyx_v_id, PyObject *__pyx_v_name, PyObject *__pyx_v_collation, PyObject *__pyx_v_is_default); /* proto */
static PyObject *__pyx_pf_7cymysql_8charsetx_7Charset_2id___get__(struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_8charsetx_7Charset_2id_2__set__(struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7cymysql_8charsetx_7Charset_4name___get__(struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_8charsetx_7Charset_4name_2__set__(struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_7cymysql_8charsetx_7Charset_4name_4__del__(struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_8charsetx_7Charset_9collation___get__(struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_8charsetx_7Charset_9collation_2__set__(struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_7cymysql_8charsetx_7Charset_9collation_4__del__(struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_8charsetx_7Charset_10is_default___get__(struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_8charsetx_7Charset_10is_default_2__set__(struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_7cymysql_8charsetx_8Charsets___init__(struct __pyx_obj_7cymysql_8charsetx_Charsets *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_8charsetx_8Charsets_2add(struct __pyx_obj_7cymysql_8charsetx_Charsets *__pyx_v_self, struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_c); /* proto */
static PyObject *__pyx_pf_7cymysql_8charsetx_8Charsets_4by_name(struct __pyx_obj_7cymysql_8charsetx_Charsets *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static char __pyx_k_2[] = "";
static char __pyx_k_29[] = "cp1257_lithuanian_ci";
static char __pyx_k__id[] = "id";
static char __pyx_k__Yes[] = "Yes";
static char __pyx_k__add[] = "add";
static char __pyx_k__gbk[] = "gbk";
static char __pyx_k__hp8[] = "hp8";
static char __pyx_k__big5[] = "big5";
static char __pyx_k__dec8[] = "dec8";
static char __pyx_k__name[] = "name";
static char __pyx_k__sjis[] = "sjis";
static char __pyx_k__swe7[] = "swe7";
static char __pyx_k__ucs2[] = "ucs2";
static char __pyx_k__ujis[] = "ujis";
static char __pyx_k__utf8[] = "utf8";
static char __pyx_k__ascii[] = "ascii";
static char __pyx_k__cp850[] = "cp850";
static char __pyx_k__cp852[] = "cp852";
static char __pyx_k__cp866[] = "cp866";
static char __pyx_k__cp932[] = "cp932";
static char __pyx_k__euckr[] = "euckr";
static char __pyx_k__greek[] = "greek";
static char __pyx_k__koi8r[] = "koi8r";
static char __pyx_k__koi8u[] = "koi8u";
static char __pyx_k__macce[] = "macce";
static char __pyx_k__binary[] = "binary";
static char __pyx_k__cp1250[] = "cp1250";
static char __pyx_k__cp1251[] = "cp1251";
static char __pyx_k__cp1256[] = "cp1256";
static char __pyx_k__cp1257[] = "cp1257";
static char __pyx_k__gb2312[] = "gb2312";
static char __pyx_k__hebrew[] = "hebrew";
static char __pyx_k__latin1[] = "latin1";
static char __pyx_k__latin2[] = "latin2";
static char __pyx_k__latin5[] = "latin5";
static char __pyx_k__latin7[] = "latin7";
static char __pyx_k__tis620[] = "tis620";
static char __pyx_k__by_name[] = "by_name";
static char __pyx_k__eucjpms[] = "eucjpms";
static char __pyx_k__gbk_bin[] = "gbk_bin";
static char __pyx_k__geostd8[] = "geostd8";
static char __pyx_k__hp8_bin[] = "hp8_bin";
static char __pyx_k__keybcs2[] = "keybcs2";
static char __pyx_k____main__[] = "__main__";
static char __pyx_k____test__[] = "__test__";
static char __pyx_k__armscii8[] = "armscii8";
static char __pyx_k__big5_bin[] = "big5_bin";
static char __pyx_k__dec8_bin[] = "dec8_bin";
static char __pyx_k__macroman[] = "macroman";
static char __pyx_k__sjis_bin[] = "sjis_bin";
static char __pyx_k__swe7_bin[] = "swe7_bin";
static char __pyx_k__ucs2_bin[] = "ucs2_bin";
static char __pyx_k__ujis_bin[] = "ujis_bin";
static char __pyx_k__utf8_bin[] = "utf8_bin";
static char __pyx_k__ascii_bin[] = "ascii_bin";
static char __pyx_k__collation[] = "collation";
static char __pyx_k__cp850_bin[] = "cp850_bin";
static char __pyx_k__cp852_bin[] = "cp852_bin";
static char __pyx_k__cp866_bin[] = "cp866_bin";
static char __pyx_k__cp932_bin[] = "cp932_bin";
static char __pyx_k__euckr_bin[] = "euckr_bin";
static char __pyx_k__greek_bin[] = "greek_bin";
static char __pyx_k__koi8r_bin[] = "koi8r_bin";
static char __pyx_k__koi8u_bin[] = "koi8u_bin";
static char __pyx_k__macce_bin[] = "macce_bin";
static char __pyx_k__cp1250_bin[] = "cp1250_bin";
static char __pyx_k__cp1251_bin[] = "cp1251_bin";
static char __pyx_k__cp1256_bin[] = "cp1256_bin";
static char __pyx_k__cp1257_bin[] = "cp1257_bin";
static char __pyx_k__gb2312_bin[] = "gb2312_bin";
static char __pyx_k__hebrew_bin[] = "hebrew_bin";
static char __pyx_k__is_default[] = "is_default";
static char __pyx_k__itervalues[] = "itervalues";
static char __pyx_k__latin1_bin[] = "latin1_bin";
static char __pyx_k__latin2_bin[] = "latin2_bin";
static char __pyx_k__latin5_bin[] = "latin5_bin";
static char __pyx_k__latin7_bin[] = "latin7_bin";
static char __pyx_k__tis620_bin[] = "tis620_bin";
static char __pyx_k____getitem__[] = "__getitem__";
static char __pyx_k__eucjpms_bin[] = "eucjpms_bin";
static char __pyx_k__geostd8_bin[] = "geostd8_bin";
static char __pyx_k__keybcs2_bin[] = "keybcs2_bin";
static char __pyx_k__armscii8_bin[] = "armscii8_bin";
static char __pyx_k__macroman_bin[] = "macroman_bin";
static char __pyx_k__charset_by_id[] = "charset_by_id";
static char __pyx_k__ucs2_czech_ci[] = "ucs2_czech_ci";
static char __pyx_k__ucs2_roman_ci[] = "ucs2_roman_ci";
static char __pyx_k__utf8_czech_ci[] = "utf8_czech_ci";
static char __pyx_k__utf8_roman_ci[] = "utf8_roman_ci";
static char __pyx_k__gbk_chinese_ci[] = "gbk_chinese_ci";
static char __pyx_k__hp8_english_ci[] = "hp8_english_ci";
static char __pyx_k__tis620_thai_ci[] = "tis620_thai_ci";
static char __pyx_k__ucs2_danish_ci[] = "ucs2_danish_ci";
static char __pyx_k__ucs2_polish_ci[] = "ucs2_polish_ci";
static char __pyx_k__ucs2_slovak_ci[] = "ucs2_slovak_ci";
static char __pyx_k__utf8_danish_ci[] = "utf8_danish_ci";
static char __pyx_k__utf8_polish_ci[] = "utf8_polish_ci";
static char __pyx_k__utf8_slovak_ci[] = "utf8_slovak_ci";
static char __pyx_k__big5_chinese_ci[] = "big5_chinese_ci";
static char __pyx_k__charset_by_name[] = "charset_by_name";
static char __pyx_k__cp1250_czech_cs[] = "cp1250_czech_cs";
static char __pyx_k__dec8_swedish_ci[] = "dec8_swedish_ci";
static char __pyx_k__euckr_korean_ci[] = "euckr_korean_ci";
static char __pyx_k__latin2_czech_cs[] = "latin2_czech_cs";
static char __pyx_k__swe7_swedish_ci[] = "swe7_swedish_ci";
static char __pyx_k__ucs2_general_ci[] = "ucs2_general_ci";
static char __pyx_k__ucs2_latvian_ci[] = "ucs2_latvian_ci";
static char __pyx_k__ucs2_persian_ci[] = "ucs2_persian_ci";
static char __pyx_k__ucs2_spanish_ci[] = "ucs2_spanish_ci";
static char __pyx_k__ucs2_swedish_ci[] = "ucs2_swedish_ci";
static char __pyx_k__ucs2_turkish_ci[] = "ucs2_turkish_ci";
static char __pyx_k__ucs2_unicode_ci[] = "ucs2_unicode_ci";
static char __pyx_k__utf8_general_ci[] = "utf8_general_ci";
static char __pyx_k__utf8_latvian_ci[] = "utf8_latvian_ci";
static char __pyx_k__utf8_persian_ci[] = "utf8_persian_ci";
static char __pyx_k__utf8_spanish_ci[] = "utf8_spanish_ci";
static char __pyx_k__utf8_swedish_ci[] = "utf8_swedish_ci";
static char __pyx_k__utf8_turkish_ci[] = "utf8_turkish_ci";
static char __pyx_k__utf8_unicode_ci[] = "utf8_unicode_ci";
static char __pyx_k__ascii_general_ci[] = "ascii_general_ci";
static char __pyx_k__cp1250_polish_ci[] = "cp1250_polish_ci";
static char __pyx_k__cp850_general_ci[] = "cp850_general_ci";
static char __pyx_k__cp852_general_ci[] = "cp852_general_ci";
static char __pyx_k__cp866_general_ci[] = "cp866_general_ci";
static char __pyx_k__greek_general_ci[] = "greek_general_ci";
static char __pyx_k__koi8r_general_ci[] = "koi8r_general_ci";
static char __pyx_k__koi8u_general_ci[] = "koi8u_general_ci";
static char __pyx_k__latin1_danish_ci[] = "latin1_danish_ci";
static char __pyx_k__macce_general_ci[] = "macce_general_ci";
static char __pyx_k__sjis_japanese_ci[] = "sjis_japanese_ci";
static char __pyx_k__ucs2_estonian_ci[] = "ucs2_estonian_ci";
static char __pyx_k__ucs2_romanian_ci[] = "ucs2_romanian_ci";
static char __pyx_k__ucs2_spanish2_ci[] = "ucs2_spanish2_ci";
static char __pyx_k__ujis_japanese_ci[] = "ujis_japanese_ci";
static char __pyx_k__utf8_estonian_ci[] = "utf8_estonian_ci";
static char __pyx_k__utf8_romanian_ci[] = "utf8_romanian_ci";
static char __pyx_k__utf8_spanish2_ci[] = "utf8_spanish2_ci";
static char __pyx_k__cp1250_general_ci[] = "cp1250_general_ci";
static char __pyx_k__cp1251_general_ci[] = "cp1251_general_ci";
static char __pyx_k__cp1251_general_cs[] = "cp1251_general_cs";
static char __pyx_k__cp1256_general_ci[] = "cp1256_general_ci";
static char __pyx_k__cp1257_general_ci[] = "cp1257_general_ci";
static char __pyx_k__cp932_japanese_ci[] = "cp932_japanese_ci";
static char __pyx_k__gb2312_chinese_ci[] = "gb2312_chinese_ci";
static char __pyx_k__hebrew_general_ci[] = "hebrew_general_ci";
static char __pyx_k__latin1_general_ci[] = "latin1_general_ci";
static char __pyx_k__latin1_general_cs[] = "latin1_general_cs";
static char __pyx_k__latin1_german1_ci[] = "latin1_german1_ci";
static char __pyx_k__latin1_german2_ci[] = "latin1_german2_ci";
static char __pyx_k__latin1_spanish_ci[] = "latin1_spanish_ci";
static char __pyx_k__latin1_swedish_ci[] = "latin1_swedish_ci";
static char __pyx_k__latin2_general_ci[] = "latin2_general_ci";
static char __pyx_k__latin5_turkish_ci[] = "latin5_turkish_ci";
static char __pyx_k__latin7_general_ci[] = "latin7_general_ci";
static char __pyx_k__latin7_general_cs[] = "latin7_general_cs";
static char __pyx_k__ucs2_esperanto_ci[] = "ucs2_esperanto_ci";
static char __pyx_k__ucs2_hungarian_ci[] = "ucs2_hungarian_ci";
static char __pyx_k__ucs2_icelandic_ci[] = "ucs2_icelandic_ci";
static char __pyx_k__ucs2_slovenian_ci[] = "ucs2_slovenian_ci";
static char __pyx_k__utf8_esperanto_ci[] = "utf8_esperanto_ci";
static char __pyx_k__utf8_hungarian_ci[] = "utf8_hungarian_ci";
static char __pyx_k__utf8_icelandic_ci[] = "utf8_icelandic_ci";
static char __pyx_k__utf8_slovenian_ci[] = "utf8_slovenian_ci";
static char __pyx_k__cp1250_croatian_ci[] = "cp1250_croatian_ci";
static char __pyx_k__geostd8_general_ci[] = "geostd8_general_ci";
static char __pyx_k__keybcs2_general_ci[] = "keybcs2_general_ci";
static char __pyx_k__latin2_croatian_ci[] = "latin2_croatian_ci";
static char __pyx_k__latin7_estonian_cs[] = "latin7_estonian_cs";
static char __pyx_k__ucs2_lithuanian_ci[] = "ucs2_lithuanian_ci";
static char __pyx_k__utf8_lithuanian_ci[] = "utf8_lithuanian_ci";
static char __pyx_k__armscii8_general_ci[] = "armscii8_general_ci";
static char __pyx_k__cp1251_bulgarian_ci[] = "cp1251_bulgarian_ci";
static char __pyx_k__cp1251_ukrainian_ci[] = "cp1251_ukrainian_ci";
static char __pyx_k__eucjpms_japanese_ci[] = "eucjpms_japanese_ci";
static char __pyx_k__latin2_hungarian_ci[] = "latin2_hungarian_ci";
static char __pyx_k__macroman_general_ci[] = "macroman_general_ci";
static PyObject *__pyx_kp_s_2;
static PyObject *__pyx_n_s_29;
static PyObject *__pyx_n_s__Yes;
static PyObject *__pyx_n_s____getitem__;
static PyObject *__pyx_n_s____main__;
static PyObject *__pyx_n_s____test__;
static PyObject *__pyx_n_s__add;
static PyObject *__pyx_n_s__armscii8;
static PyObject *__pyx_n_s__armscii8_bin;
static PyObject *__pyx_n_s__armscii8_general_ci;
static PyObject *__pyx_n_s__ascii;
static PyObject *__pyx_n_s__ascii_bin;
static PyObject *__pyx_n_s__ascii_general_ci;
static PyObject *__pyx_n_s__big5;
static PyObject *__pyx_n_s__big5_bin;
static PyObject *__pyx_n_s__big5_chinese_ci;
static PyObject *__pyx_n_s__binary;
static PyObject *__pyx_n_s__by_name;
static PyObject *__pyx_n_s__charset_by_id;
static PyObject *__pyx_n_s__charset_by_name;
static PyObject *__pyx_n_s__collation;
static PyObject *__pyx_n_s__cp1250;
static PyObject *__pyx_n_s__cp1250_bin;
static PyObject *__pyx_n_s__cp1250_croatian_ci;
static PyObject *__pyx_n_s__cp1250_czech_cs;
static PyObject *__pyx_n_s__cp1250_general_ci;
static PyObject *__pyx_n_s__cp1250_polish_ci;
static PyObject *__pyx_n_s__cp1251;
static PyObject *__pyx_n_s__cp1251_bin;
static PyObject *__pyx_n_s__cp1251_bulgarian_ci;
static PyObject *__pyx_n_s__cp1251_general_ci;
static PyObject *__pyx_n_s__cp1251_general_cs;
static PyObject *__pyx_n_s__cp1251_ukrainian_ci;
static PyObject *__pyx_n_s__cp1256;
static PyObject *__pyx_n_s__cp1256_bin;
static PyObject *__pyx_n_s__cp1256_general_ci;
static PyObject *__pyx_n_s__cp1257;
static PyObject *__pyx_n_s__cp1257_bin;
static PyObject *__pyx_n_s__cp1257_general_ci;
static PyObject *__pyx_n_s__cp850;
static PyObject *__pyx_n_s__cp850_bin;
static PyObject *__pyx_n_s__cp850_general_ci;
static PyObject *__pyx_n_s__cp852;
static PyObject *__pyx_n_s__cp852_bin;
static PyObject *__pyx_n_s__cp852_general_ci;
static PyObject *__pyx_n_s__cp866;
static PyObject *__pyx_n_s__cp866_bin;
static PyObject *__pyx_n_s__cp866_general_ci;
static PyObject *__pyx_n_s__cp932;
static PyObject *__pyx_n_s__cp932_bin;
static PyObject *__pyx_n_s__cp932_japanese_ci;
static PyObject *__pyx_n_s__dec8;
static PyObject *__pyx_n_s__dec8_bin;
static PyObject *__pyx_n_s__dec8_swedish_ci;
static PyObject *__pyx_n_s__eucjpms;
static PyObject *__pyx_n_s__eucjpms_bin;
static PyObject *__pyx_n_s__eucjpms_japanese_ci;
static PyObject *__pyx_n_s__euckr;
static PyObject *__pyx_n_s__euckr_bin;
static PyObject *__pyx_n_s__euckr_korean_ci;
static PyObject *__pyx_n_s__gb2312;
static PyObject *__pyx_n_s__gb2312_bin;
static PyObject *__pyx_n_s__gb2312_chinese_ci;
static PyObject *__pyx_n_s__gbk;
static PyObject *__pyx_n_s__gbk_bin;
static PyObject *__pyx_n_s__gbk_chinese_ci;
static PyObject *__pyx_n_s__geostd8;
static PyObject *__pyx_n_s__geostd8_bin;
static PyObject *__pyx_n_s__geostd8_general_ci;
static PyObject *__pyx_n_s__greek;
static PyObject *__pyx_n_s__greek_bin;
static PyObject *__pyx_n_s__greek_general_ci;
static PyObject *__pyx_n_s__hebrew;
static PyObject *__pyx_n_s__hebrew_bin;
static PyObject *__pyx_n_s__hebrew_general_ci;
static PyObject *__pyx_n_s__hp8;
static PyObject *__pyx_n_s__hp8_bin;
static PyObject *__pyx_n_s__hp8_english_ci;
static PyObject *__pyx_n_s__id;
static PyObject *__pyx_n_s__is_default;
static PyObject *__pyx_n_s__itervalues;
static PyObject *__pyx_n_s__keybcs2;
static PyObject *__pyx_n_s__keybcs2_bin;
static PyObject *__pyx_n_s__keybcs2_general_ci;
static PyObject *__pyx_n_s__koi8r;
static PyObject *__pyx_n_s__koi8r_bin;
static PyObject *__pyx_n_s__koi8r_general_ci;
static PyObject *__pyx_n_s__koi8u;
static PyObject *__pyx_n_s__koi8u_bin;
static PyObject *__pyx_n_s__koi8u_general_ci;
static PyObject *__pyx_n_s__latin1;
static PyObject *__pyx_n_s__latin1_bin;
static PyObject *__pyx_n_s__latin1_danish_ci;
static PyObject *__pyx_n_s__latin1_general_ci;
static PyObject *__pyx_n_s__latin1_general_cs;
static PyObject *__pyx_n_s__latin1_german1_ci;
static PyObject *__pyx_n_s__latin1_german2_ci;
static PyObject *__pyx_n_s__latin1_spanish_ci;
static PyObject *__pyx_n_s__latin1_swedish_ci;
static PyObject *__pyx_n_s__latin2;
static PyObject *__pyx_n_s__latin2_bin;
static PyObject *__pyx_n_s__latin2_croatian_ci;
static PyObject *__pyx_n_s__latin2_czech_cs;
static PyObject *__pyx_n_s__latin2_general_ci;
static PyObject *__pyx_n_s__latin2_hungarian_ci;
static PyObject *__pyx_n_s__latin5;
static PyObject *__pyx_n_s__latin5_bin;
static PyObject *__pyx_n_s__latin5_turkish_ci;
static PyObject *__pyx_n_s__latin7;
static PyObject *__pyx_n_s__latin7_bin;
static PyObject *__pyx_n_s__latin7_estonian_cs;
static PyObject *__pyx_n_s__latin7_general_ci;
static PyObject *__pyx_n_s__latin7_general_cs;
static PyObject *__pyx_n_s__macce;
static PyObject *__pyx_n_s__macce_bin;
static PyObject *__pyx_n_s__macce_general_ci;
static PyObject *__pyx_n_s__macroman;
static PyObject *__pyx_n_s__macroman_bin;
static PyObject *__pyx_n_s__macroman_general_ci;
static PyObject *__pyx_n_s__name;
static PyObject *__pyx_n_s__sjis;
static PyObject *__pyx_n_s__sjis_bin;
static PyObject *__pyx_n_s__sjis_japanese_ci;
static PyObject *__pyx_n_s__swe7;
static PyObject *__pyx_n_s__swe7_bin;
static PyObject *__pyx_n_s__swe7_swedish_ci;
static PyObject *__pyx_n_s__tis620;
static PyObject *__pyx_n_s__tis620_bin;
static PyObject *__pyx_n_s__tis620_thai_ci;
static PyObject *__pyx_n_s__ucs2;
static PyObject *__pyx_n_s__ucs2_bin;
static PyObject *__pyx_n_s__ucs2_czech_ci;
static PyObject *__pyx_n_s__ucs2_danish_ci;
static PyObject *__pyx_n_s__ucs2_esperanto_ci;
static PyObject *__pyx_n_s__ucs2_estonian_ci;
static PyObject *__pyx_n_s__ucs2_general_ci;
static PyObject *__pyx_n_s__ucs2_hungarian_ci;
static PyObject *__pyx_n_s__ucs2_icelandic_ci;
static PyObject *__pyx_n_s__ucs2_latvian_ci;
static PyObject *__pyx_n_s__ucs2_lithuanian_ci;
static PyObject *__pyx_n_s__ucs2_persian_ci;
static PyObject *__pyx_n_s__ucs2_polish_ci;
static PyObject *__pyx_n_s__ucs2_roman_ci;
static PyObject *__pyx_n_s__ucs2_romanian_ci;
static PyObject *__pyx_n_s__ucs2_slovak_ci;
static PyObject *__pyx_n_s__ucs2_slovenian_ci;
static PyObject *__pyx_n_s__ucs2_spanish2_ci;
static PyObject *__pyx_n_s__ucs2_spanish_ci;
static PyObject *__pyx_n_s__ucs2_swedish_ci;
static PyObject *__pyx_n_s__ucs2_turkish_ci;
static PyObject *__pyx_n_s__ucs2_unicode_ci;
static PyObject *__pyx_n_s__ujis;
static PyObject *__pyx_n_s__ujis_bin;
static PyObject *__pyx_n_s__ujis_japanese_ci;
static PyObject *__pyx_n_s__utf8;
static PyObject *__pyx_n_s__utf8_bin;
static PyObject *__pyx_n_s__utf8_czech_ci;
static PyObject *__pyx_n_s__utf8_danish_ci;
static PyObject *__pyx_n_s__utf8_esperanto_ci;
static PyObject *__pyx_n_s__utf8_estonian_ci;
static PyObject *__pyx_n_s__utf8_general_ci;
static PyObject *__pyx_n_s__utf8_hungarian_ci;
static PyObject *__pyx_n_s__utf8_icelandic_ci;
static PyObject *__pyx_n_s__utf8_latvian_ci;
static PyObject *__pyx_n_s__utf8_lithuanian_ci;
static PyObject *__pyx_n_s__utf8_persian_ci;
static PyObject *__pyx_n_s__utf8_polish_ci;
static PyObject *__pyx_n_s__utf8_roman_ci;
static PyObject *__pyx_n_s__utf8_romanian_ci;
static PyObject *__pyx_n_s__utf8_slovak_ci;
static PyObject *__pyx_n_s__utf8_slovenian_ci;
static PyObject *__pyx_n_s__utf8_spanish2_ci;
static PyObject *__pyx_n_s__utf8_spanish_ci;
static PyObject *__pyx_n_s__utf8_swedish_ci;
static PyObject *__pyx_n_s__utf8_turkish_ci;
static PyObject *__pyx_n_s__utf8_unicode_ci;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_2;
static PyObject *__pyx_int_3;
static PyObject *__pyx_int_4;
static PyObject *__pyx_int_5;
static PyObject *__pyx_int_6;
static PyObject *__pyx_int_7;
static PyObject *__pyx_int_8;
static PyObject *__pyx_int_9;
static PyObject *__pyx_int_10;
static PyObject *__pyx_int_11;
static PyObject *__pyx_int_12;
static PyObject *__pyx_int_13;
static PyObject *__pyx_int_14;
static PyObject *__pyx_int_15;
static PyObject *__pyx_int_16;
static PyObject *__pyx_int_18;
static PyObject *__pyx_int_19;
static PyObject *__pyx_int_20;
static PyObject *__pyx_int_21;
static PyObject *__pyx_int_22;
static PyObject *__pyx_int_23;
static PyObject *__pyx_int_24;
static PyObject *__pyx_int_25;
static PyObject *__pyx_int_26;
static PyObject *__pyx_int_27;
static PyObject *__pyx_int_28;
static PyObject *__pyx_int_29;
static PyObject *__pyx_int_30;
static PyObject *__pyx_int_31;
static PyObject *__pyx_int_32;
static PyObject *__pyx_int_33;
static PyObject *__pyx_int_34;
static PyObject *__pyx_int_35;
static PyObject *__pyx_int_36;
static PyObject *__pyx_int_37;
static PyObject *__pyx_int_38;
static PyObject *__pyx_int_39;
static PyObject *__pyx_int_40;
static PyObject *__pyx_int_41;
static PyObject *__pyx_int_42;
static PyObject *__pyx_int_43;
static PyObject *__pyx_int_44;
static PyObject *__pyx_int_47;
static PyObject *__pyx_int_48;
static PyObject *__pyx_int_49;
static PyObject *__pyx_int_50;
static PyObject *__pyx_int_51;
static PyObject *__pyx_int_52;
static PyObject *__pyx_int_53;
static PyObject *__pyx_int_57;
static PyObject *__pyx_int_58;
static PyObject *__pyx_int_59;
static PyObject *__pyx_int_63;
static PyObject *__pyx_int_64;
static PyObject *__pyx_int_65;
static PyObject *__pyx_int_66;
static PyObject *__pyx_int_67;
static PyObject *__pyx_int_68;
static PyObject *__pyx_int_69;
static PyObject *__pyx_int_70;
static PyObject *__pyx_int_71;
static PyObject *__pyx_int_72;
static PyObject *__pyx_int_73;
static PyObject *__pyx_int_74;
static PyObject *__pyx_int_75;
static PyObject *__pyx_int_77;
static PyObject *__pyx_int_78;
static PyObject *__pyx_int_79;
static PyObject *__pyx_int_80;
static PyObject *__pyx_int_81;
static PyObject *__pyx_int_82;
static PyObject *__pyx_int_83;
static PyObject *__pyx_int_84;
static PyObject *__pyx_int_85;
static PyObject *__pyx_int_86;
static PyObject *__pyx_int_87;
static PyObject *__pyx_int_88;
static PyObject *__pyx_int_89;
static PyObject *__pyx_int_90;
static PyObject *__pyx_int_91;
static PyObject *__pyx_int_92;
static PyObject *__pyx_int_93;
static PyObject *__pyx_int_94;
static PyObject *__pyx_int_95;
static PyObject *__pyx_int_96;
static PyObject *__pyx_int_97;
static PyObject *__pyx_int_98;
static PyObject *__pyx_int_99;
static PyObject *__pyx_int_128;
static PyObject *__pyx_int_129;
static PyObject *__pyx_int_130;
static PyObject *__pyx_int_131;
static PyObject *__pyx_int_132;
static PyObject *__pyx_int_133;
static PyObject *__pyx_int_134;
static PyObject *__pyx_int_135;
static PyObject *__pyx_int_136;
static PyObject *__pyx_int_137;
static PyObject *__pyx_int_138;
static PyObject *__pyx_int_139;
static PyObject *__pyx_int_140;
static PyObject *__pyx_int_141;
static PyObject *__pyx_int_142;
static PyObject *__pyx_int_143;
static PyObject *__pyx_int_144;
static PyObject *__pyx_int_145;
static PyObject *__pyx_int_146;
static PyObject *__pyx_int_192;
static PyObject *__pyx_int_193;
static PyObject *__pyx_int_194;
static PyObject *__pyx_int_195;
static PyObject *__pyx_int_196;
static PyObject *__pyx_int_197;
static PyObject *__pyx_int_198;
static PyObject *__pyx_int_199;
static PyObject *__pyx_int_200;
static PyObject *__pyx_int_201;
static PyObject *__pyx_int_202;
static PyObject *__pyx_int_203;
static PyObject *__pyx_int_204;
static PyObject *__pyx_int_205;
static PyObject *__pyx_int_206;
static PyObject *__pyx_int_207;
static PyObject *__pyx_int_208;
static PyObject *__pyx_int_209;
static PyObject *__pyx_int_210;
static PyObject *__pyx_k_tuple_1;
static PyObject *__pyx_k_tuple_3;
static PyObject *__pyx_k_tuple_4;
static PyObject *__pyx_k_tuple_5;
static PyObject *__pyx_k_tuple_6;
static PyObject *__pyx_k_tuple_7;
static PyObject *__pyx_k_tuple_8;
static PyObject *__pyx_k_tuple_9;
static PyObject *__pyx_k_tuple_10;
static PyObject *__pyx_k_tuple_11;
static PyObject *__pyx_k_tuple_12;
static PyObject *__pyx_k_tuple_13;
static PyObject *__pyx_k_tuple_14;
static PyObject *__pyx_k_tuple_15;
static PyObject *__pyx_k_tuple_16;
static PyObject *__pyx_k_tuple_17;
static PyObject *__pyx_k_tuple_18;
static PyObject *__pyx_k_tuple_19;
static PyObject *__pyx_k_tuple_20;
static PyObject *__pyx_k_tuple_21;
static PyObject *__pyx_k_tuple_22;
static PyObject *__pyx_k_tuple_23;
static PyObject *__pyx_k_tuple_24;
static PyObject *__pyx_k_tuple_25;
static PyObject *__pyx_k_tuple_26;
static PyObject *__pyx_k_tuple_27;
static PyObject *__pyx_k_tuple_28;
static PyObject *__pyx_k_tuple_30;
static PyObject *__pyx_k_tuple_31;
static PyObject *__pyx_k_tuple_32;
static PyObject *__pyx_k_tuple_33;
static PyObject *__pyx_k_tuple_34;
static PyObject *__pyx_k_tuple_35;
static PyObject *__pyx_k_tuple_36;
static PyObject *__pyx_k_tuple_37;
static PyObject *__pyx_k_tuple_38;
static PyObject *__pyx_k_tuple_39;
static PyObject *__pyx_k_tuple_40;
static PyObject *__pyx_k_tuple_41;
static PyObject *__pyx_k_tuple_42;
static PyObject *__pyx_k_tuple_43;
static PyObject *__pyx_k_tuple_44;
static PyObject *__pyx_k_tuple_45;
static PyObject *__pyx_k_tuple_46;
static PyObject *__pyx_k_tuple_47;
static PyObject *__pyx_k_tuple_48;
static PyObject *__pyx_k_tuple_49;
static PyObject *__pyx_k_tuple_50;
static PyObject *__pyx_k_tuple_51;
static PyObject *__pyx_k_tuple_52;
static PyObject *__pyx_k_tuple_53;
static PyObject *__pyx_k_tuple_54;
static PyObject *__pyx_k_tuple_55;
static PyObject *__pyx_k_tuple_56;
static PyObject *__pyx_k_tuple_57;
static PyObject *__pyx_k_tuple_58;
static PyObject *__pyx_k_tuple_59;
static PyObject *__pyx_k_tuple_60;
static PyObject *__pyx_k_tuple_61;
static PyObject *__pyx_k_tuple_62;
static PyObject *__pyx_k_tuple_63;
static PyObject *__pyx_k_tuple_64;
static PyObject *__pyx_k_tuple_65;
static PyObject *__pyx_k_tuple_66;
static PyObject *__pyx_k_tuple_67;
static PyObject *__pyx_k_tuple_68;
static PyObject *__pyx_k_tuple_69;
static PyObject *__pyx_k_tuple_70;
static PyObject *__pyx_k_tuple_71;
static PyObject *__pyx_k_tuple_72;
static PyObject *__pyx_k_tuple_73;
static PyObject *__pyx_k_tuple_74;
static PyObject *__pyx_k_tuple_75;
static PyObject *__pyx_k_tuple_76;
static PyObject *__pyx_k_tuple_77;
static PyObject *__pyx_k_tuple_78;
static PyObject *__pyx_k_tuple_79;
static PyObject *__pyx_k_tuple_80;
static PyObject *__pyx_k_tuple_81;
static PyObject *__pyx_k_tuple_82;
static PyObject *__pyx_k_tuple_83;
static PyObject *__pyx_k_tuple_84;
static PyObject *__pyx_k_tuple_85;
static PyObject *__pyx_k_tuple_86;
static PyObject *__pyx_k_tuple_87;
static PyObject *__pyx_k_tuple_88;
static PyObject *__pyx_k_tuple_89;
static PyObject *__pyx_k_tuple_90;
static PyObject *__pyx_k_tuple_91;
static PyObject *__pyx_k_tuple_92;
static PyObject *__pyx_k_tuple_93;
static PyObject *__pyx_k_tuple_94;
static PyObject *__pyx_k_tuple_95;
static PyObject *__pyx_k_tuple_96;
static PyObject *__pyx_k_tuple_97;
static PyObject *__pyx_k_tuple_98;
static PyObject *__pyx_k_tuple_99;
static PyObject *__pyx_k_tuple_100;
static PyObject *__pyx_k_tuple_101;
static PyObject *__pyx_k_tuple_102;
static PyObject *__pyx_k_tuple_103;
static PyObject *__pyx_k_tuple_104;
static PyObject *__pyx_k_tuple_105;
static PyObject *__pyx_k_tuple_106;
static PyObject *__pyx_k_tuple_107;
static PyObject *__pyx_k_tuple_108;
static PyObject *__pyx_k_tuple_109;
static PyObject *__pyx_k_tuple_110;
static PyObject *__pyx_k_tuple_111;
static PyObject *__pyx_k_tuple_112;
static PyObject *__pyx_k_tuple_113;
static PyObject *__pyx_k_tuple_114;
static PyObject *__pyx_k_tuple_115;
static PyObject *__pyx_k_tuple_116;
static PyObject *__pyx_k_tuple_117;
static PyObject *__pyx_k_tuple_118;
static PyObject *__pyx_k_tuple_119;
static PyObject *__pyx_k_tuple_120;
static PyObject *__pyx_k_tuple_121;
static PyObject *__pyx_k_tuple_122;
static PyObject *__pyx_k_tuple_123;
static PyObject *__pyx_k_tuple_124;
static PyObject *__pyx_k_tuple_125;
static PyObject *__pyx_k_tuple_126;
static PyObject *__pyx_k_tuple_127;
static PyObject *__pyx_k_tuple_128;
static PyObject *__pyx_k_tuple_129;

/* Python wrapper */
static int __pyx_pw_7cymysql_8charsetx_7Charset_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_7cymysql_8charsetx_7Charset_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_id = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_collation = 0;
  PyObject *__pyx_v_is_default = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__id,&__pyx_n_s__name,&__pyx_n_s__collation,&__pyx_n_s__is_default,0};
    PyObject* values[4] = {0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__id)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 5; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__collation)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 5; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  3:
        if (likely((values[3] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__is_default)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, 3); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 5; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 5; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 4) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
    }
    __pyx_v_id = values[0];
    __pyx_v_name = values[1];
    __pyx_v_collation = values[2];
    __pyx_v_is_default = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 5; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("cymysql.charsetx.Charset.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7cymysql_8charsetx_7Charset___init__(((struct __pyx_obj_7cymysql_8charsetx_Charset *)__pyx_v_self), __pyx_v_id, __pyx_v_name, __pyx_v_collation, __pyx_v_is_default);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/charsetx.pyx":5
 *     cdef public str name, collation
 *     cdef public bint is_default
 *     def __init__(self, id, name, collation, is_default):             # <<<<<<<<<<<<<<
 *         self.id, self.name, self.collation = id, name, collation
 *         self.is_default = is_default == 'Yes'
 */

static int __pyx_pf_7cymysql_8charsetx_7Charset___init__(struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_self, PyObject *__pyx_v_id, PyObject *__pyx_v_name, PyObject *__pyx_v_collation, PyObject *__pyx_v_is_default) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cymysql/charsetx.pyx":6
 *     cdef public bint is_default
 *     def __init__(self, id, name, collation, is_default):
 *         self.id, self.name, self.collation = id, name, collation             # <<<<<<<<<<<<<<
 *         self.is_default = is_default == 'Yes'
 * 
 */
  __pyx_t_1 = __Pyx_PyInt_AsInt(__pyx_v_id); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 6; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (!(likely(PyString_CheckExact(__pyx_v_name))||((__pyx_v_name) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected str, got %.200s", Py_TYPE(__pyx_v_name)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 6; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __pyx_v_name;
  __Pyx_INCREF(__pyx_t_2);
  if (!(likely(PyString_CheckExact(__pyx_v_collation))||((__pyx_v_collation) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected str, got %.200s", Py_TYPE(__pyx_v_collation)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 6; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = __pyx_v_collation;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_v_self->id = __pyx_t_1;
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->name));
  __pyx_v_self->name = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->collation);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->collation));
  __pyx_v_self->collation = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":7
 *     def __init__(self, id, name, collation, is_default):
 *         self.id, self.name, self.collation = id, name, collation
 *         self.is_default = is_default == 'Yes'             # <<<<<<<<<<<<<<
 * 
 * cdef class Charsets(object):
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_is_default, ((PyObject *)__pyx_n_s__Yes), Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 7; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 7; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_self->is_default = __pyx_t_4;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cymysql.charsetx.Charset.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_8charsetx_7Charset_2id_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_8charsetx_7Charset_2id_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_8charsetx_7Charset_2id___get__(((struct __pyx_obj_7cymysql_8charsetx_Charset *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/charsetx.pyx":2
 * cdef class Charset(object):
 *     cdef public int id             # <<<<<<<<<<<<<<
 *     cdef public str name, collation
 *     cdef public bint is_default
 */

static PyObject *__pyx_pf_7cymysql_8charsetx_7Charset_2id___get__(struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromLong(__pyx_v_self->id); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.charsetx.Charset.id.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_8charsetx_7Charset_2id_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_8charsetx_7Charset_2id_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_8charsetx_7Charset_2id_2__set__(((struct __pyx_obj_7cymysql_8charsetx_Charset *)__pyx_v_self), ((PyObject *)__pyx_v_value));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_8charsetx_7Charset_2id_2__set__(struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_AsInt(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->id = __pyx_t_1;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cymysql.charsetx.Charset.id.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_8charsetx_7Charset_4name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_8charsetx_7Charset_4name_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_8charsetx_7Charset_4name___get__(((struct __pyx_obj_7cymysql_8charsetx_Charset *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/charsetx.pyx":3
 * cdef class Charset(object):
 *     cdef public int id
 *     cdef public str name, collation             # <<<<<<<<<<<<<<
 *     cdef public bint is_default
 *     def __init__(self, id, name, collation, is_default):
 */

static PyObject *__pyx_pf_7cymysql_8charsetx_7Charset_4name___get__(struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->name));
  __pyx_r = ((PyObject *)__pyx_v_self->name);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_8charsetx_7Charset_4name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_8charsetx_7Charset_4name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_8charsetx_7Charset_4name_2__set__(((struct __pyx_obj_7cymysql_8charsetx_Charset *)__pyx_v_self), ((PyObject *)__pyx_v_value));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_8charsetx_7Charset_4name_2__set__(struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyString_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected str, got %.200s", Py_TYPE(__pyx_v_value)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 3; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->name));
  __pyx_v_self->name = ((PyObject*)__pyx_v_value);

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cymysql.charsetx.Charset.name.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_8charsetx_7Charset_4name_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_7cymysql_8charsetx_7Charset_4name_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_8charsetx_7Charset_4name_4__del__(((struct __pyx_obj_7cymysql_8charsetx_Charset *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_8charsetx_7Charset_4name_4__del__(struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->name));
  __pyx_v_self->name = ((PyObject*)Py_None);

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_8charsetx_7Charset_9collation_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_8charsetx_7Charset_9collation_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_8charsetx_7Charset_9collation___get__(((struct __pyx_obj_7cymysql_8charsetx_Charset *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_8charsetx_7Charset_9collation___get__(struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->collation));
  __pyx_r = ((PyObject *)__pyx_v_self->collation);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_8charsetx_7Charset_9collation_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_8charsetx_7Charset_9collation_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_8charsetx_7Charset_9collation_2__set__(((struct __pyx_obj_7cymysql_8charsetx_Charset *)__pyx_v_self), ((PyObject *)__pyx_v_value));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_8charsetx_7Charset_9collation_2__set__(struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyString_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected str, got %.200s", Py_TYPE(__pyx_v_value)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 3; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->collation);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->collation));
  __pyx_v_self->collation = ((PyObject*)__pyx_v_value);

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cymysql.charsetx.Charset.collation.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_8charsetx_7Charset_9collation_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_7cymysql_8charsetx_7Charset_9collation_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_8charsetx_7Charset_9collation_4__del__(((struct __pyx_obj_7cymysql_8charsetx_Charset *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_8charsetx_7Charset_9collation_4__del__(struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->collation);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->collation));
  __pyx_v_self->collation = ((PyObject*)Py_None);

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_8charsetx_7Charset_10is_default_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_8charsetx_7Charset_10is_default_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_8charsetx_7Charset_10is_default___get__(((struct __pyx_obj_7cymysql_8charsetx_Charset *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/charsetx.pyx":4
 *     cdef public int id
 *     cdef public str name, collation
 *     cdef public bint is_default             # <<<<<<<<<<<<<<
 *     def __init__(self, id, name, collation, is_default):
 *         self.id, self.name, self.collation = id, name, collation
 */

static PyObject *__pyx_pf_7cymysql_8charsetx_7Charset_10is_default___get__(struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->is_default); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 4; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.charsetx.Charset.is_default.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_8charsetx_7Charset_10is_default_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_8charsetx_7Charset_10is_default_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_8charsetx_7Charset_10is_default_2__set__(((struct __pyx_obj_7cymysql_8charsetx_Charset *)__pyx_v_self), ((PyObject *)__pyx_v_value));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_8charsetx_7Charset_10is_default_2__set__(struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 4; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->is_default = __pyx_t_1;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cymysql.charsetx.Charset.is_default.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_8charsetx_8Charsets_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_7cymysql_8charsetx_8Charsets_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__init__", 0))) return -1;
  __pyx_r = __pyx_pf_7cymysql_8charsetx_8Charsets___init__(((struct __pyx_obj_7cymysql_8charsetx_Charsets *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/charsetx.pyx":13
 *     cdef object by_id
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self._by_id = {}
 *         self.by_id = self._by_id.__getitem__
 */

static int __pyx_pf_7cymysql_8charsetx_8Charsets___init__(struct __pyx_obj_7cymysql_8charsetx_Charsets *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cymysql/charsetx.pyx":14
 * 
 *     def __init__(self):
 *         self._by_id = {}             # <<<<<<<<<<<<<<
 *         self.by_id = self._by_id.__getitem__
 * 
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_1));
  __Pyx_GOTREF(__pyx_v_self->_by_id);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_by_id));
  __pyx_v_self->_by_id = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":15
 *     def __init__(self):
 *         self._by_id = {}
 *         self.by_id = self._by_id.__getitem__             # <<<<<<<<<<<<<<
 * 
 *     def add(self, Charset c):
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_self->_by_id), __pyx_n_s____getitem__); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->by_id);
  __Pyx_DECREF(__pyx_v_self->by_id);
  __pyx_v_self->by_id = __pyx_t_1;
  __pyx_t_1 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.charsetx.Charsets.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_8charsetx_8Charsets_3add(PyObject *__pyx_v_self, PyObject *__pyx_v_c); /*proto*/
static PyObject *__pyx_pw_7cymysql_8charsetx_8Charsets_3add(PyObject *__pyx_v_self, PyObject *__pyx_v_c) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_c), __pyx_ptype_7cymysql_8charsetx_Charset, 1, "c", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 17; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_7cymysql_8charsetx_8Charsets_2add(((struct __pyx_obj_7cymysql_8charsetx_Charsets *)__pyx_v_self), ((struct __pyx_obj_7cymysql_8charsetx_Charset *)__pyx_v_c));
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/charsetx.pyx":17
 *         self.by_id = self._by_id.__getitem__
 * 
 *     def add(self, Charset c):             # <<<<<<<<<<<<<<
 *         self._by_id[c.id] = c
 * 
 */

static PyObject *__pyx_pf_7cymysql_8charsetx_8Charsets_2add(struct __pyx_obj_7cymysql_8charsetx_Charsets *__pyx_v_self, struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_c) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("add", 0);

  /* "cymysql/charsetx.pyx":18
 * 
 *     def add(self, Charset c):
 *         self._by_id[c.id] = c             # <<<<<<<<<<<<<<
 * 
 *     def by_name(self, name):
 */
  if (unlikely(((PyObject *)__pyx_v_self->_by_id) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  if (__Pyx_SetItemInt(((PyObject *)__pyx_v_self->_by_id), __pyx_v_c->id, ((PyObject *)__pyx_v_c), sizeof(int), PyInt_FromLong) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cymysql.charsetx.Charsets.add", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_8charsetx_8Charsets_5by_name(PyObject *__pyx_v_self, PyObject *__pyx_v_name); /*proto*/
static PyObject *__pyx_pw_7cymysql_8charsetx_8Charsets_5by_name(PyObject *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("by_name (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_8charsetx_8Charsets_4by_name(((struct __pyx_obj_7cymysql_8charsetx_Charsets *)__pyx_v_self), ((PyObject *)__pyx_v_name));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/charsetx.pyx":20
 *         self._by_id[c.id] = c
 * 
 *     def by_name(self, name):             # <<<<<<<<<<<<<<
 *         cdef Charset c
 *         for c in self._by_id.itervalues():
 */

static PyObject *__pyx_pf_7cymysql_8charsetx_8Charsets_4by_name(struct __pyx_obj_7cymysql_8charsetx_Charsets *__pyx_v_self, PyObject *__pyx_v_name) {
  struct __pyx_obj_7cymysql_8charsetx_Charset *__pyx_v_c = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("by_name", 0);

  /* "cymysql/charsetx.pyx":22
 *     def by_name(self, name):
 *         cdef Charset c
 *         for c in self._by_id.itervalues():             # <<<<<<<<<<<<<<
 *             if c.name == name and c.is_default:
 *                 return c
 */
  __pyx_t_2 = 0;
  if (unlikely(((PyObject *)__pyx_v_self->_by_id) == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "itervalues");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 22; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_5 = __Pyx_dict_iterator(((PyObject *)__pyx_v_self->_by_id), 1, ((PyObject *)__pyx_n_s__itervalues), (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 22; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_6 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, NULL, &__pyx_t_5, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_6 == 0)) break;
    if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 22; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_7cymysql_8charsetx_Charset))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 22; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_XDECREF(((PyObject *)__pyx_v_c));
    __pyx_v_c = ((struct __pyx_obj_7cymysql_8charsetx_Charset *)__pyx_t_5);
    __pyx_t_5 = 0;

    /* "cymysql/charsetx.pyx":23
 *         cdef Charset c
 *         for c in self._by_id.itervalues():
 *             if c.name == name and c.is_default:             # <<<<<<<<<<<<<<
 *                 return c
 * 
 */
    __pyx_t_5 = PyObject_RichCompare(((PyObject *)__pyx_v_c->name), __pyx_v_name, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 23; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 23; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_7) {
      __pyx_t_8 = __pyx_v_c->is_default;
      __pyx_t_9 = __pyx_t_8;
    } else {
      __pyx_t_9 = __pyx_t_7;
    }
    if (__pyx_t_9) {

      /* "cymysql/charsetx.pyx":24
 *         for c in self._by_id.itervalues():
 *             if c.name == name and c.is_default:
 *                 return c             # <<<<<<<<<<<<<<
 * 
 * cdef Charsets _charsets = Charsets()
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(((PyObject *)__pyx_v_c));
      __pyx_r = ((PyObject *)__pyx_v_c);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
      goto __pyx_L5;
    }
    __pyx_L5:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cymysql.charsetx.Charsets.by_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_c);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_tp_new_7cymysql_8charsetx_Charset(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_7cymysql_8charsetx_Charset *p;
  PyObject *o = (*t->tp_alloc)(t, 0);
  if (!o) return 0;
  p = ((struct __pyx_obj_7cymysql_8charsetx_Charset *)o);
  p->name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->collation = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_7cymysql_8charsetx_Charset(PyObject *o) {
  struct __pyx_obj_7cymysql_8charsetx_Charset *p = (struct __pyx_obj_7cymysql_8charsetx_Charset *)o;
  Py_CLEAR(p->name);
  Py_CLEAR(p->collation);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_7cymysql_8charsetx_Charset(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_7cymysql_8charsetx_Charset *p = (struct __pyx_obj_7cymysql_8charsetx_Charset *)o;
  if (p->name) {
    e = (*v)(p->name, a); if (e) return e;
  }
  if (p->collation) {
    e = (*v)(p->collation, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_7cymysql_8charsetx_Charset(PyObject *o) {
  struct __pyx_obj_7cymysql_8charsetx_Charset *p = (struct __pyx_obj_7cymysql_8charsetx_Charset *)o;
  PyObject* tmp;
  tmp = ((PyObject*)p->name);
  p->name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->collation);
  p->collation = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_7cymysql_8charsetx_7Charset_id(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_8charsetx_7Charset_2id_1__get__(o);
}

static int __pyx_setprop_7cymysql_8charsetx_7Charset_id(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_8charsetx_7Charset_2id_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_7cymysql_8charsetx_7Charset_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_8charsetx_7Charset_4name_1__get__(o);
}

static int __pyx_setprop_7cymysql_8charsetx_7Charset_name(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_8charsetx_7Charset_4name_3__set__(o, v);
  }
  else {
    return __pyx_pw_7cymysql_8charsetx_7Charset_4name_5__del__(o);
  }
}

static PyObject *__pyx_getprop_7cymysql_8charsetx_7Charset_collation(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_8charsetx_7Charset_9collation_1__get__(o);
}

static int __pyx_setprop_7cymysql_8charsetx_7Charset_collation(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_8charsetx_7Charset_9collation_3__set__(o, v);
  }
  else {
    return __pyx_pw_7cymysql_8charsetx_7Charset_9collation_5__del__(o);
  }
}

static PyObject *__pyx_getprop_7cymysql_8charsetx_7Charset_is_default(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_8charsetx_7Charset_10is_default_1__get__(o);
}

static int __pyx_setprop_7cymysql_8charsetx_7Charset_is_default(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_8charsetx_7Charset_10is_default_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyMethodDef __pyx_methods_7cymysql_8charsetx_Charset[] = {
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_7cymysql_8charsetx_Charset[] = {
  {(char *)"id", __pyx_getprop_7cymysql_8charsetx_7Charset_id, __pyx_setprop_7cymysql_8charsetx_7Charset_id, 0, 0},
  {(char *)"name", __pyx_getprop_7cymysql_8charsetx_7Charset_name, __pyx_setprop_7cymysql_8charsetx_7Charset_name, 0, 0},
  {(char *)"collation", __pyx_getprop_7cymysql_8charsetx_7Charset_collation, __pyx_setprop_7cymysql_8charsetx_7Charset_collation, 0, 0},
  {(char *)"is_default", __pyx_getprop_7cymysql_8charsetx_7Charset_is_default, __pyx_setprop_7cymysql_8charsetx_7Charset_is_default, 0, 0},
  {0, 0, 0, 0, 0}
};

static PyNumberMethods __pyx_tp_as_number_Charset = {
  0, /*nb_add*/
  0, /*nb_subtract*/
  0, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_divide*/
  #endif
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  0, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_nonzero*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_coerce*/
  #endif
  0, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  0, /*nb_float*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  #if PY_VERSION_HEX >= 0x02050000
  0, /*nb_index*/
  #endif
};

static PySequenceMethods __pyx_tp_as_sequence_Charset = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Charset = {
  0, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_Charset = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_getbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_releasebuffer*/
  #endif
};

static PyTypeObject __pyx_type_7cymysql_8charsetx_Charset = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("cymysql.charsetx.Charset"), /*tp_name*/
  sizeof(struct __pyx_obj_7cymysql_8charsetx_Charset), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_7cymysql_8charsetx_Charset, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  &__pyx_tp_as_number_Charset, /*tp_as_number*/
  &__pyx_tp_as_sequence_Charset, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Charset, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_Charset, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_7cymysql_8charsetx_Charset, /*tp_traverse*/
  __pyx_tp_clear_7cymysql_8charsetx_Charset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_7cymysql_8charsetx_Charset, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_7cymysql_8charsetx_Charset, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_7cymysql_8charsetx_7Charset_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7cymysql_8charsetx_Charset, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static PyObject *__pyx_tp_new_7cymysql_8charsetx_Charsets(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_7cymysql_8charsetx_Charsets *p;
  PyObject *o = (*t->tp_alloc)(t, 0);
  if (!o) return 0;
  p = ((struct __pyx_obj_7cymysql_8charsetx_Charsets *)o);
  p->_by_id = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->by_id = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_7cymysql_8charsetx_Charsets(PyObject *o) {
  struct __pyx_obj_7cymysql_8charsetx_Charsets *p = (struct __pyx_obj_7cymysql_8charsetx_Charsets *)o;
  Py_CLEAR(p->_by_id);
  Py_CLEAR(p->by_id);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_7cymysql_8charsetx_Charsets(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_7cymysql_8charsetx_Charsets *p = (struct __pyx_obj_7cymysql_8charsetx_Charsets *)o;
  if (p->_by_id) {
    e = (*v)(p->_by_id, a); if (e) return e;
  }
  if (p->by_id) {
    e = (*v)(p->by_id, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_7cymysql_8charsetx_Charsets(PyObject *o) {
  struct __pyx_obj_7cymysql_8charsetx_Charsets *p = (struct __pyx_obj_7cymysql_8charsetx_Charsets *)o;
  PyObject* tmp;
  tmp = ((PyObject*)p->_by_id);
  p->_by_id = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->by_id);
  p->by_id = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_7cymysql_8charsetx_Charsets[] = {
  {__Pyx_NAMESTR("add"), (PyCFunction)__pyx_pw_7cymysql_8charsetx_8Charsets_3add, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("by_name"), (PyCFunction)__pyx_pw_7cymysql_8charsetx_8Charsets_5by_name, METH_O, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

static PyNumberMethods __pyx_tp_as_number_Charsets = {
  0, /*nb_add*/
  0, /*nb_subtract*/
  0, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_divide*/
  #endif
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  0, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_nonzero*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_coerce*/
  #endif
  0, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  0, /*nb_float*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  #if PY_VERSION_HEX >= 0x02050000
  0, /*nb_index*/
  #endif
};

static PySequenceMethods __pyx_tp_as_sequence_Charsets = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Charsets = {
  0, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_Charsets = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_getbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_releasebuffer*/
  #endif
};

static PyTypeObject __pyx_type_7cymysql_8charsetx_Charsets = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("cymysql.charsetx.Charsets"), /*tp_name*/
  sizeof(struct __pyx_obj_7cymysql_8charsetx_Charsets), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_7cymysql_8charsetx_Charsets, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  &__pyx_tp_as_number_Charsets, /*tp_as_number*/
  &__pyx_tp_as_sequence_Charsets, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Charsets, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_Charsets, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_7cymysql_8charsetx_Charsets, /*tp_traverse*/
  __pyx_tp_clear_7cymysql_8charsetx_Charsets, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_7cymysql_8charsetx_Charsets, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_7cymysql_8charsetx_8Charsets_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7cymysql_8charsetx_Charsets, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    __Pyx_NAMESTR("charsetx"),
    0, /* m_doc */
    -1, /* m_size */
    __pyx_methods /* m_methods */,
    NULL, /* m_reload */
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_s_2, __pyx_k_2, sizeof(__pyx_k_2), 0, 0, 1, 0},
  {&__pyx_n_s_29, __pyx_k_29, sizeof(__pyx_k_29), 0, 0, 1, 1},
  {&__pyx_n_s__Yes, __pyx_k__Yes, sizeof(__pyx_k__Yes), 0, 0, 1, 1},
  {&__pyx_n_s____getitem__, __pyx_k____getitem__, sizeof(__pyx_k____getitem__), 0, 0, 1, 1},
  {&__pyx_n_s____main__, __pyx_k____main__, sizeof(__pyx_k____main__), 0, 0, 1, 1},
  {&__pyx_n_s____test__, __pyx_k____test__, sizeof(__pyx_k____test__), 0, 0, 1, 1},
  {&__pyx_n_s__add, __pyx_k__add, sizeof(__pyx_k__add), 0, 0, 1, 1},
  {&__pyx_n_s__armscii8, __pyx_k__armscii8, sizeof(__pyx_k__armscii8), 0, 0, 1, 1},
  {&__pyx_n_s__armscii8_bin, __pyx_k__armscii8_bin, sizeof(__pyx_k__armscii8_bin), 0, 0, 1, 1},
  {&__pyx_n_s__armscii8_general_ci, __pyx_k__armscii8_general_ci, sizeof(__pyx_k__armscii8_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s__ascii, __pyx_k__ascii, sizeof(__pyx_k__ascii), 0, 0, 1, 1},
  {&__pyx_n_s__ascii_bin, __pyx_k__ascii_bin, sizeof(__pyx_k__ascii_bin), 0, 0, 1, 1},
  {&__pyx_n_s__ascii_general_ci, __pyx_k__ascii_general_ci, sizeof(__pyx_k__ascii_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s__big5, __pyx_k__big5, sizeof(__pyx_k__big5), 0, 0, 1, 1},
  {&__pyx_n_s__big5_bin, __pyx_k__big5_bin, sizeof(__pyx_k__big5_bin), 0, 0, 1, 1},
  {&__pyx_n_s__big5_chinese_ci, __pyx_k__big5_chinese_ci, sizeof(__pyx_k__big5_chinese_ci), 0, 0, 1, 1},
  {&__pyx_n_s__binary, __pyx_k__binary, sizeof(__pyx_k__binary), 0, 0, 1, 1},
  {&__pyx_n_s__by_name, __pyx_k__by_name, sizeof(__pyx_k__by_name), 0, 0, 1, 1},
  {&__pyx_n_s__charset_by_id, __pyx_k__charset_by_id, sizeof(__pyx_k__charset_by_id), 0, 0, 1, 1},
  {&__pyx_n_s__charset_by_name, __pyx_k__charset_by_name, sizeof(__pyx_k__charset_by_name), 0, 0, 1, 1},
  {&__pyx_n_s__collation, __pyx_k__collation, sizeof(__pyx_k__collation), 0, 0, 1, 1},
  {&__pyx_n_s__cp1250, __pyx_k__cp1250, sizeof(__pyx_k__cp1250), 0, 0, 1, 1},
  {&__pyx_n_s__cp1250_bin, __pyx_k__cp1250_bin, sizeof(__pyx_k__cp1250_bin), 0, 0, 1, 1},
  {&__pyx_n_s__cp1250_croatian_ci, __pyx_k__cp1250_croatian_ci, sizeof(__pyx_k__cp1250_croatian_ci), 0, 0, 1, 1},
  {&__pyx_n_s__cp1250_czech_cs, __pyx_k__cp1250_czech_cs, sizeof(__pyx_k__cp1250_czech_cs), 0, 0, 1, 1},
  {&__pyx_n_s__cp1250_general_ci, __pyx_k__cp1250_general_ci, sizeof(__pyx_k__cp1250_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s__cp1250_polish_ci, __pyx_k__cp1250_polish_ci, sizeof(__pyx_k__cp1250_polish_ci), 0, 0, 1, 1},
  {&__pyx_n_s__cp1251, __pyx_k__cp1251, sizeof(__pyx_k__cp1251), 0, 0, 1, 1},
  {&__pyx_n_s__cp1251_bin, __pyx_k__cp1251_bin, sizeof(__pyx_k__cp1251_bin), 0, 0, 1, 1},
  {&__pyx_n_s__cp1251_bulgarian_ci, __pyx_k__cp1251_bulgarian_ci, sizeof(__pyx_k__cp1251_bulgarian_ci), 0, 0, 1, 1},
  {&__pyx_n_s__cp1251_general_ci, __pyx_k__cp1251_general_ci, sizeof(__pyx_k__cp1251_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s__cp1251_general_cs, __pyx_k__cp1251_general_cs, sizeof(__pyx_k__cp1251_general_cs), 0, 0, 1, 1},
  {&__pyx_n_s__cp1251_ukrainian_ci, __pyx_k__cp1251_ukrainian_ci, sizeof(__pyx_k__cp1251_ukrainian_ci), 0, 0, 1, 1},
  {&__pyx_n_s__cp1256, __pyx_k__cp1256, sizeof(__pyx_k__cp1256), 0, 0, 1, 1},
  {&__pyx_n_s__cp1256_bin, __pyx_k__cp1256_bin, sizeof(__pyx_k__cp1256_bin), 0, 0, 1, 1},
  {&__pyx_n_s__cp1256_general_ci, __pyx_k__cp1256_general_ci, sizeof(__pyx_k__cp1256_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s__cp1257, __pyx_k__cp1257, sizeof(__pyx_k__cp1257), 0, 0, 1, 1},
  {&__pyx_n_s__cp1257_bin, __pyx_k__cp1257_bin, sizeof(__pyx_k__cp1257_bin), 0, 0, 1, 1},
  {&__pyx_n_s__cp1257_general_ci, __pyx_k__cp1257_general_ci, sizeof(__pyx_k__cp1257_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s__cp850, __pyx_k__cp850, sizeof(__pyx_k__cp850), 0, 0, 1, 1},
  {&__pyx_n_s__cp850_bin, __pyx_k__cp850_bin, sizeof(__pyx_k__cp850_bin), 0, 0, 1, 1},
  {&__pyx_n_s__cp850_general_ci, __pyx_k__cp850_general_ci, sizeof(__pyx_k__cp850_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s__cp852, __pyx_k__cp852, sizeof(__pyx_k__cp852), 0, 0, 1, 1},
  {&__pyx_n_s__cp852_bin, __pyx_k__cp852_bin, sizeof(__pyx_k__cp852_bin), 0, 0, 1, 1},
  {&__pyx_n_s__cp852_general_ci, __pyx_k__cp852_general_ci, sizeof(__pyx_k__cp852_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s__cp866, __pyx_k__cp866, sizeof(__pyx_k__cp866), 0, 0, 1, 1},
  {&__pyx_n_s__cp866_bin, __pyx_k__cp866_bin, sizeof(__pyx_k__cp866_bin), 0, 0, 1, 1},
  {&__pyx_n_s__cp866_general_ci, __pyx_k__cp866_general_ci, sizeof(__pyx_k__cp866_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s__cp932, __pyx_k__cp932, sizeof(__pyx_k__cp932), 0, 0, 1, 1},
  {&__pyx_n_s__cp932_bin, __pyx_k__cp932_bin, sizeof(__pyx_k__cp932_bin), 0, 0, 1, 1},
  {&__pyx_n_s__cp932_japanese_ci, __pyx_k__cp932_japanese_ci, sizeof(__pyx_k__cp932_japanese_ci), 0, 0, 1, 1},
  {&__pyx_n_s__dec8, __pyx_k__dec8, sizeof(__pyx_k__dec8), 0, 0, 1, 1},
  {&__pyx_n_s__dec8_bin, __pyx_k__dec8_bin, sizeof(__pyx_k__dec8_bin), 0, 0, 1, 1},
  {&__pyx_n_s__dec8_swedish_ci, __pyx_k__dec8_swedish_ci, sizeof(__pyx_k__dec8_swedish_ci), 0, 0, 1, 1},
  {&__pyx_n_s__eucjpms, __pyx_k__eucjpms, sizeof(__pyx_k__eucjpms), 0, 0, 1, 1},
  {&__pyx_n_s__eucjpms_bin, __pyx_k__eucjpms_bin, sizeof(__pyx_k__eucjpms_bin), 0, 0, 1, 1},
  {&__pyx_n_s__eucjpms_japanese_ci, __pyx_k__eucjpms_japanese_ci, sizeof(__pyx_k__eucjpms_japanese_ci), 0, 0, 1, 1},
  {&__pyx_n_s__euckr, __pyx_k__euckr, sizeof(__pyx_k__euckr), 0, 0, 1, 1},
  {&__pyx_n_s__euckr_bin, __pyx_k__euckr_bin, sizeof(__pyx_k__euckr_bin), 0, 0, 1, 1},
  {&__pyx_n_s__euckr_korean_ci, __pyx_k__euckr_korean_ci, sizeof(__pyx_k__euckr_korean_ci), 0, 0, 1, 1},
  {&__pyx_n_s__gb2312, __pyx_k__gb2312, sizeof(__pyx_k__gb2312), 0, 0, 1, 1},
  {&__pyx_n_s__gb2312_bin, __pyx_k__gb2312_bin, sizeof(__pyx_k__gb2312_bin), 0, 0, 1, 1},
  {&__pyx_n_s__gb2312_chinese_ci, __pyx_k__gb2312_chinese_ci, sizeof(__pyx_k__gb2312_chinese_ci), 0, 0, 1, 1},
  {&__pyx_n_s__gbk, __pyx_k__gbk, sizeof(__pyx_k__gbk), 0, 0, 1, 1},
  {&__pyx_n_s__gbk_bin, __pyx_k__gbk_bin, sizeof(__pyx_k__gbk_bin), 0, 0, 1, 1},
  {&__pyx_n_s__gbk_chinese_ci, __pyx_k__gbk_chinese_ci, sizeof(__pyx_k__gbk_chinese_ci), 0, 0, 1, 1},
  {&__pyx_n_s__geostd8, __pyx_k__geostd8, sizeof(__pyx_k__geostd8), 0, 0, 1, 1},
  {&__pyx_n_s__geostd8_bin, __pyx_k__geostd8_bin, sizeof(__pyx_k__geostd8_bin), 0, 0, 1, 1},
  {&__pyx_n_s__geostd8_general_ci, __pyx_k__geostd8_general_ci, sizeof(__pyx_k__geostd8_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s__greek, __pyx_k__greek, sizeof(__pyx_k__greek), 0, 0, 1, 1},
  {&__pyx_n_s__greek_bin, __pyx_k__greek_bin, sizeof(__pyx_k__greek_bin), 0, 0, 1, 1},
  {&__pyx_n_s__greek_general_ci, __pyx_k__greek_general_ci, sizeof(__pyx_k__greek_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s__hebrew, __pyx_k__hebrew, sizeof(__pyx_k__hebrew), 0, 0, 1, 1},
  {&__pyx_n_s__hebrew_bin, __pyx_k__hebrew_bin, sizeof(__pyx_k__hebrew_bin), 0, 0, 1, 1},
  {&__pyx_n_s__hebrew_general_ci, __pyx_k__hebrew_general_ci, sizeof(__pyx_k__hebrew_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s__hp8, __pyx_k__hp8, sizeof(__pyx_k__hp8), 0, 0, 1, 1},
  {&__pyx_n_s__hp8_bin, __pyx_k__hp8_bin, sizeof(__pyx_k__hp8_bin), 0, 0, 1, 1},
  {&__pyx_n_s__hp8_english_ci, __pyx_k__hp8_english_ci, sizeof(__pyx_k__hp8_english_ci), 0, 0, 1, 1},
  {&__pyx_n_s__id, __pyx_k__id, sizeof(__pyx_k__id), 0, 0, 1, 1},
  {&__pyx_n_s__is_default, __pyx_k__is_default, sizeof(__pyx_k__is_default), 0, 0, 1, 1},
  {&__pyx_n_s__itervalues, __pyx_k__itervalues, sizeof(__pyx_k__itervalues), 0, 0, 1, 1},
  {&__pyx_n_s__keybcs2, __pyx_k__keybcs2, sizeof(__pyx_k__keybcs2), 0, 0, 1, 1},
  {&__pyx_n_s__keybcs2_bin, __pyx_k__keybcs2_bin, sizeof(__pyx_k__keybcs2_bin), 0, 0, 1, 1},
  {&__pyx_n_s__keybcs2_general_ci, __pyx_k__keybcs2_general_ci, sizeof(__pyx_k__keybcs2_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s__koi8r, __pyx_k__koi8r, sizeof(__pyx_k__koi8r), 0, 0, 1, 1},
  {&__pyx_n_s__koi8r_bin, __pyx_k__koi8r_bin, sizeof(__pyx_k__koi8r_bin), 0, 0, 1, 1},
  {&__pyx_n_s__koi8r_general_ci, __pyx_k__koi8r_general_ci, sizeof(__pyx_k__koi8r_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s__koi8u, __pyx_k__koi8u, sizeof(__pyx_k__koi8u), 0, 0, 1, 1},
  {&__pyx_n_s__koi8u_bin, __pyx_k__koi8u_bin, sizeof(__pyx_k__koi8u_bin), 0, 0, 1, 1},
  {&__pyx_n_s__koi8u_general_ci, __pyx_k__koi8u_general_ci, sizeof(__pyx_k__koi8u_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s__latin1, __pyx_k__latin1, sizeof(__pyx_k__latin1), 0, 0, 1, 1},
  {&__pyx_n_s__latin1_bin, __pyx_k__latin1_bin, sizeof(__pyx_k__latin1_bin), 0, 0, 1, 1},
  {&__pyx_n_s__latin1_danish_ci, __pyx_k__latin1_danish_ci, sizeof(__pyx_k__latin1_danish_ci), 0, 0, 1, 1},
  {&__pyx_n_s__latin1_general_ci, __pyx_k__latin1_general_ci, sizeof(__pyx_k__latin1_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s__latin1_general_cs, __pyx_k__latin1_general_cs, sizeof(__pyx_k__latin1_general_cs), 0, 0, 1, 1},
  {&__pyx_n_s__latin1_german1_ci, __pyx_k__latin1_german1_ci, sizeof(__pyx_k__latin1_german1_ci), 0, 0, 1, 1},
  {&__pyx_n_s__latin1_german2_ci, __pyx_k__latin1_german2_ci, sizeof(__pyx_k__latin1_german2_ci), 0, 0, 1, 1},
  {&__pyx_n_s__latin1_spanish_ci, __pyx_k__latin1_spanish_ci, sizeof(__pyx_k__latin1_spanish_ci), 0, 0, 1, 1},
  {&__pyx_n_s__latin1_swedish_ci, __pyx_k__latin1_swedish_ci, sizeof(__pyx_k__latin1_swedish_ci), 0, 0, 1, 1},
  {&__pyx_n_s__latin2, __pyx_k__latin2, sizeof(__pyx_k__latin2), 0, 0, 1, 1},
  {&__pyx_n_s__latin2_bin, __pyx_k__latin2_bin, sizeof(__pyx_k__latin2_bin), 0, 0, 1, 1},
  {&__pyx_n_s__latin2_croatian_ci, __pyx_k__latin2_croatian_ci, sizeof(__pyx_k__latin2_croatian_ci), 0, 0, 1, 1},
  {&__pyx_n_s__latin2_czech_cs, __pyx_k__latin2_czech_cs, sizeof(__pyx_k__latin2_czech_cs), 0, 0, 1, 1},
  {&__pyx_n_s__latin2_general_ci, __pyx_k__latin2_general_ci, sizeof(__pyx_k__latin2_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s__latin2_hungarian_ci, __pyx_k__latin2_hungarian_ci, sizeof(__pyx_k__latin2_hungarian_ci), 0, 0, 1, 1},
  {&__pyx_n_s__latin5, __pyx_k__latin5, sizeof(__pyx_k__latin5), 0, 0, 1, 1},
  {&__pyx_n_s__latin5_bin, __pyx_k__latin5_bin, sizeof(__pyx_k__latin5_bin), 0, 0, 1, 1},
  {&__pyx_n_s__latin5_turkish_ci, __pyx_k__latin5_turkish_ci, sizeof(__pyx_k__latin5_turkish_ci), 0, 0, 1, 1},
  {&__pyx_n_s__latin7, __pyx_k__latin7, sizeof(__pyx_k__latin7), 0, 0, 1, 1},
  {&__pyx_n_s__latin7_bin, __pyx_k__latin7_bin, sizeof(__pyx_k__latin7_bin), 0, 0, 1, 1},
  {&__pyx_n_s__latin7_estonian_cs, __pyx_k__latin7_estonian_cs, sizeof(__pyx_k__latin7_estonian_cs), 0, 0, 1, 1},
  {&__pyx_n_s__latin7_general_ci, __pyx_k__latin7_general_ci, sizeof(__pyx_k__latin7_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s__latin7_general_cs, __pyx_k__latin7_general_cs, sizeof(__pyx_k__latin7_general_cs), 0, 0, 1, 1},
  {&__pyx_n_s__macce, __pyx_k__macce, sizeof(__pyx_k__macce), 0, 0, 1, 1},
  {&__pyx_n_s__macce_bin, __pyx_k__macce_bin, sizeof(__pyx_k__macce_bin), 0, 0, 1, 1},
  {&__pyx_n_s__macce_general_ci, __pyx_k__macce_general_ci, sizeof(__pyx_k__macce_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s__macroman, __pyx_k__macroman, sizeof(__pyx_k__macroman), 0, 0, 1, 1},
  {&__pyx_n_s__macroman_bin, __pyx_k__macroman_bin, sizeof(__pyx_k__macroman_bin), 0, 0, 1, 1},
  {&__pyx_n_s__macroman_general_ci, __pyx_k__macroman_general_ci, sizeof(__pyx_k__macroman_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s__name, __pyx_k__name, sizeof(__pyx_k__name), 0, 0, 1, 1},
  {&__pyx_n_s__sjis, __pyx_k__sjis, sizeof(__pyx_k__sjis), 0, 0, 1, 1},
  {&__pyx_n_s__sjis_bin, __pyx_k__sjis_bin, sizeof(__pyx_k__sjis_bin), 0, 0, 1, 1},
  {&__pyx_n_s__sjis_japanese_ci, __pyx_k__sjis_japanese_ci, sizeof(__pyx_k__sjis_japanese_ci), 0, 0, 1, 1},
  {&__pyx_n_s__swe7, __pyx_k__swe7, sizeof(__pyx_k__swe7), 0, 0, 1, 1},
  {&__pyx_n_s__swe7_bin, __pyx_k__swe7_bin, sizeof(__pyx_k__swe7_bin), 0, 0, 1, 1},
  {&__pyx_n_s__swe7_swedish_ci, __pyx_k__swe7_swedish_ci, sizeof(__pyx_k__swe7_swedish_ci), 0, 0, 1, 1},
  {&__pyx_n_s__tis620, __pyx_k__tis620, sizeof(__pyx_k__tis620), 0, 0, 1, 1},
  {&__pyx_n_s__tis620_bin, __pyx_k__tis620_bin, sizeof(__pyx_k__tis620_bin), 0, 0, 1, 1},
  {&__pyx_n_s__tis620_thai_ci, __pyx_k__tis620_thai_ci, sizeof(__pyx_k__tis620_thai_ci), 0, 0, 1, 1},
  {&__pyx_n_s__ucs2, __pyx_k__ucs2, sizeof(__pyx_k__ucs2), 0, 0, 1, 1},
  {&__pyx_n_s__ucs2_bin, __pyx_k__ucs2_bin, sizeof(__pyx_k__ucs2_bin), 0, 0, 1, 1},
  {&__pyx_n_s__ucs2_czech_ci, __pyx_k__ucs2_czech_ci, sizeof(__pyx_k__ucs2_czech_ci), 0, 0, 1, 1},
  {&__pyx_n_s__ucs2_danish_ci, __pyx_k__ucs2_danish_ci, sizeof(__pyx_k__ucs2_danish_ci), 0, 0, 1, 1},
  {&__pyx_n_s__ucs2_esperanto_ci, __pyx_k__ucs2_esperanto_ci, sizeof(__pyx_k__ucs2_esperanto_ci), 0, 0, 1, 1},
  {&__pyx_n_s__ucs2_estonian_ci, __pyx_k__ucs2_estonian_ci, sizeof(__pyx_k__ucs2_estonian_ci), 0, 0, 1, 1},
  {&__pyx_n_s__ucs2_general_ci, __pyx_k__ucs2_general_ci, sizeof(__pyx_k__ucs2_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s__ucs2_hungarian_ci, __pyx_k__ucs2_hungarian_ci, sizeof(__pyx_k__ucs2_hungarian_ci), 0, 0, 1, 1},
  {&__pyx_n_s__ucs2_icelandic_ci, __pyx_k__ucs2_icelandic_ci, sizeof(__pyx_k__ucs2_icelandic_ci), 0, 0, 1, 1},
  {&__pyx_n_s__ucs2_latvian_ci, __pyx_k__ucs2_latvian_ci, sizeof(__pyx_k__ucs2_latvian_ci), 0, 0, 1, 1},
  {&__pyx_n_s__ucs2_lithuanian_ci, __pyx_k__ucs2_lithuanian_ci, sizeof(__pyx_k__ucs2_lithuanian_ci), 0, 0, 1, 1},
  {&__pyx_n_s__ucs2_persian_ci, __pyx_k__ucs2_persian_ci, sizeof(__pyx_k__ucs2_persian_ci), 0, 0, 1, 1},
  {&__pyx_n_s__ucs2_polish_ci, __pyx_k__ucs2_polish_ci, sizeof(__pyx_k__ucs2_polish_ci), 0, 0, 1, 1},
  {&__pyx_n_s__ucs2_roman_ci, __pyx_k__ucs2_roman_ci, sizeof(__pyx_k__ucs2_roman_ci), 0, 0, 1, 1},
  {&__pyx_n_s__ucs2_romanian_ci, __pyx_k__ucs2_romanian_ci, sizeof(__pyx_k__ucs2_romanian_ci), 0, 0, 1, 1},
  {&__pyx_n_s__ucs2_slovak_ci, __pyx_k__ucs2_slovak_ci, sizeof(__pyx_k__ucs2_slovak_ci), 0, 0, 1, 1},
  {&__pyx_n_s__ucs2_slovenian_ci, __pyx_k__ucs2_slovenian_ci, sizeof(__pyx_k__ucs2_slovenian_ci), 0, 0, 1, 1},
  {&__pyx_n_s__ucs2_spanish2_ci, __pyx_k__ucs2_spanish2_ci, sizeof(__pyx_k__ucs2_spanish2_ci), 0, 0, 1, 1},
  {&__pyx_n_s__ucs2_spanish_ci, __pyx_k__ucs2_spanish_ci, sizeof(__pyx_k__ucs2_spanish_ci), 0, 0, 1, 1},
  {&__pyx_n_s__ucs2_swedish_ci, __pyx_k__ucs2_swedish_ci, sizeof(__pyx_k__ucs2_swedish_ci), 0, 0, 1, 1},
  {&__pyx_n_s__ucs2_turkish_ci, __pyx_k__ucs2_turkish_ci, sizeof(__pyx_k__ucs2_turkish_ci), 0, 0, 1, 1},
  {&__pyx_n_s__ucs2_unicode_ci, __pyx_k__ucs2_unicode_ci, sizeof(__pyx_k__ucs2_unicode_ci), 0, 0, 1, 1},
  {&__pyx_n_s__ujis, __pyx_k__ujis, sizeof(__pyx_k__ujis), 0, 0, 1, 1},
  {&__pyx_n_s__ujis_bin, __pyx_k__ujis_bin, sizeof(__pyx_k__ujis_bin), 0, 0, 1, 1},
  {&__pyx_n_s__ujis_japanese_ci, __pyx_k__ujis_japanese_ci, sizeof(__pyx_k__ujis_japanese_ci), 0, 0, 1, 1},
  {&__pyx_n_s__utf8, __pyx_k__utf8, sizeof(__pyx_k__utf8), 0, 0, 1, 1},
  {&__pyx_n_s__utf8_bin, __pyx_k__utf8_bin, sizeof(__pyx_k__utf8_bin), 0, 0, 1, 1},
  {&__pyx_n_s__utf8_czech_ci, __pyx_k__utf8_czech_ci, sizeof(__pyx_k__utf8_czech_ci), 0, 0, 1, 1},
  {&__pyx_n_s__utf8_danish_ci, __pyx_k__utf8_danish_ci, sizeof(__pyx_k__utf8_danish_ci), 0, 0, 1, 1},
  {&__pyx_n_s__utf8_esperanto_ci, __pyx_k__utf8_esperanto_ci, sizeof(__pyx_k__utf8_esperanto_ci), 0, 0, 1, 1},
  {&__pyx_n_s__utf8_estonian_ci, __pyx_k__utf8_estonian_ci, sizeof(__pyx_k__utf8_estonian_ci), 0, 0, 1, 1},
  {&__pyx_n_s__utf8_general_ci, __pyx_k__utf8_general_ci, sizeof(__pyx_k__utf8_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s__utf8_hungarian_ci, __pyx_k__utf8_hungarian_ci, sizeof(__pyx_k__utf8_hungarian_ci), 0, 0, 1, 1},
  {&__pyx_n_s__utf8_icelandic_ci, __pyx_k__utf8_icelandic_ci, sizeof(__pyx_k__utf8_icelandic_ci), 0, 0, 1, 1},
  {&__pyx_n_s__utf8_latvian_ci, __pyx_k__utf8_latvian_ci, sizeof(__pyx_k__utf8_latvian_ci), 0, 0, 1, 1},
  {&__pyx_n_s__utf8_lithuanian_ci, __pyx_k__utf8_lithuanian_ci, sizeof(__pyx_k__utf8_lithuanian_ci), 0, 0, 1, 1},
  {&__pyx_n_s__utf8_persian_ci, __pyx_k__utf8_persian_ci, sizeof(__pyx_k__utf8_persian_ci), 0, 0, 1, 1},
  {&__pyx_n_s__utf8_polish_ci, __pyx_k__utf8_polish_ci, sizeof(__pyx_k__utf8_polish_ci), 0, 0, 1, 1},
  {&__pyx_n_s__utf8_roman_ci, __pyx_k__utf8_roman_ci, sizeof(__pyx_k__utf8_roman_ci), 0, 0, 1, 1},
  {&__pyx_n_s__utf8_romanian_ci, __pyx_k__utf8_romanian_ci, sizeof(__pyx_k__utf8_romanian_ci), 0, 0, 1, 1},
  {&__pyx_n_s__utf8_slovak_ci, __pyx_k__utf8_slovak_ci, sizeof(__pyx_k__utf8_slovak_ci), 0, 0, 1, 1},
  {&__pyx_n_s__utf8_slovenian_ci, __pyx_k__utf8_slovenian_ci, sizeof(__pyx_k__utf8_slovenian_ci), 0, 0, 1, 1},
  {&__pyx_n_s__utf8_spanish2_ci, __pyx_k__utf8_spanish2_ci, sizeof(__pyx_k__utf8_spanish2_ci), 0, 0, 1, 1},
  {&__pyx_n_s__utf8_spanish_ci, __pyx_k__utf8_spanish_ci, sizeof(__pyx_k__utf8_spanish_ci), 0, 0, 1, 1},
  {&__pyx_n_s__utf8_swedish_ci, __pyx_k__utf8_swedish_ci, sizeof(__pyx_k__utf8_swedish_ci), 0, 0, 1, 1},
  {&__pyx_n_s__utf8_turkish_ci, __pyx_k__utf8_turkish_ci, sizeof(__pyx_k__utf8_turkish_ci), 0, 0, 1, 1},
  {&__pyx_n_s__utf8_unicode_ci, __pyx_k__utf8_unicode_ci, sizeof(__pyx_k__utf8_unicode_ci), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  return 0;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "cymysql/charsetx.pyx":43
 * 
 * """
 * _charsets.add(Charset(1, 'big5', 'big5_chinese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 */
  __pyx_k_tuple_1 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_1);
  __Pyx_INCREF(__pyx_int_1);
  PyTuple_SET_ITEM(__pyx_k_tuple_1, 0, __pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__big5));
  PyTuple_SET_ITEM(__pyx_k_tuple_1, 1, ((PyObject *)__pyx_n_s__big5));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__big5));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__big5_chinese_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_1, 2, ((PyObject *)__pyx_n_s__big5_chinese_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__big5_chinese_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_1, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_1));

  /* "cymysql/charsetx.pyx":44
 * """
 * _charsets.add(Charset(1, 'big5', 'big5_chinese_ci', 'Yes'))
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 */
  __pyx_k_tuple_3 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 44; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_3);
  __Pyx_INCREF(__pyx_int_2);
  PyTuple_SET_ITEM(__pyx_k_tuple_3, 0, __pyx_int_2);
  __Pyx_GIVEREF(__pyx_int_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin2));
  PyTuple_SET_ITEM(__pyx_k_tuple_3, 1, ((PyObject *)__pyx_n_s__latin2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin2_czech_cs));
  PyTuple_SET_ITEM(__pyx_k_tuple_3, 2, ((PyObject *)__pyx_n_s__latin2_czech_cs));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin2_czech_cs));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_3, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_3));

  /* "cymysql/charsetx.pyx":45
 * _charsets.add(Charset(1, 'big5', 'big5_chinese_ci', 'Yes'))
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 */
  __pyx_k_tuple_4 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_4);
  __Pyx_INCREF(__pyx_int_3);
  PyTuple_SET_ITEM(__pyx_k_tuple_4, 0, __pyx_int_3);
  __Pyx_GIVEREF(__pyx_int_3);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__dec8));
  PyTuple_SET_ITEM(__pyx_k_tuple_4, 1, ((PyObject *)__pyx_n_s__dec8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__dec8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__dec8_swedish_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_4, 2, ((PyObject *)__pyx_n_s__dec8_swedish_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__dec8_swedish_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_4, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_4));

  /* "cymysql/charsetx.pyx":46
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 */
  __pyx_k_tuple_5 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 46; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_5);
  __Pyx_INCREF(__pyx_int_4);
  PyTuple_SET_ITEM(__pyx_k_tuple_5, 0, __pyx_int_4);
  __Pyx_GIVEREF(__pyx_int_4);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp850));
  PyTuple_SET_ITEM(__pyx_k_tuple_5, 1, ((PyObject *)__pyx_n_s__cp850));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp850));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp850_general_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_5, 2, ((PyObject *)__pyx_n_s__cp850_general_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp850_general_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_5, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_5));

  /* "cymysql/charsetx.pyx":47
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 */
  __pyx_k_tuple_6 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 47; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_6);
  __Pyx_INCREF(__pyx_int_5);
  PyTuple_SET_ITEM(__pyx_k_tuple_6, 0, __pyx_int_5);
  __Pyx_GIVEREF(__pyx_int_5);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin1));
  PyTuple_SET_ITEM(__pyx_k_tuple_6, 1, ((PyObject *)__pyx_n_s__latin1));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin1));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin1_german1_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_6, 2, ((PyObject *)__pyx_n_s__latin1_german1_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin1_german1_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_6, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_6));

  /* "cymysql/charsetx.pyx":48
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 */
  __pyx_k_tuple_7 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 48; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_7);
  __Pyx_INCREF(__pyx_int_6);
  PyTuple_SET_ITEM(__pyx_k_tuple_7, 0, __pyx_int_6);
  __Pyx_GIVEREF(__pyx_int_6);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__hp8));
  PyTuple_SET_ITEM(__pyx_k_tuple_7, 1, ((PyObject *)__pyx_n_s__hp8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__hp8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__hp8_english_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_7, 2, ((PyObject *)__pyx_n_s__hp8_english_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__hp8_english_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_7, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_7));

  /* "cymysql/charsetx.pyx":49
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 */
  __pyx_k_tuple_8 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 49; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_8);
  __Pyx_INCREF(__pyx_int_7);
  PyTuple_SET_ITEM(__pyx_k_tuple_8, 0, __pyx_int_7);
  __Pyx_GIVEREF(__pyx_int_7);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__koi8r));
  PyTuple_SET_ITEM(__pyx_k_tuple_8, 1, ((PyObject *)__pyx_n_s__koi8r));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__koi8r));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__koi8r_general_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_8, 2, ((PyObject *)__pyx_n_s__koi8r_general_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__koi8r_general_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_8, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_8));

  /* "cymysql/charsetx.pyx":50
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 */
  __pyx_k_tuple_9 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 50; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_9);
  __Pyx_INCREF(__pyx_int_8);
  PyTuple_SET_ITEM(__pyx_k_tuple_9, 0, __pyx_int_8);
  __Pyx_GIVEREF(__pyx_int_8);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin1));
  PyTuple_SET_ITEM(__pyx_k_tuple_9, 1, ((PyObject *)__pyx_n_s__latin1));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin1));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin1_swedish_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_9, 2, ((PyObject *)__pyx_n_s__latin1_swedish_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin1_swedish_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_9, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_9));

  /* "cymysql/charsetx.pyx":51
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 */
  __pyx_k_tuple_10 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_10);
  __Pyx_INCREF(__pyx_int_9);
  PyTuple_SET_ITEM(__pyx_k_tuple_10, 0, __pyx_int_9);
  __Pyx_GIVEREF(__pyx_int_9);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin2));
  PyTuple_SET_ITEM(__pyx_k_tuple_10, 1, ((PyObject *)__pyx_n_s__latin2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin2_general_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_10, 2, ((PyObject *)__pyx_n_s__latin2_general_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin2_general_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_10, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_10));

  /* "cymysql/charsetx.pyx":52
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 */
  __pyx_k_tuple_11 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 52; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_11);
  __Pyx_INCREF(__pyx_int_10);
  PyTuple_SET_ITEM(__pyx_k_tuple_11, 0, __pyx_int_10);
  __Pyx_GIVEREF(__pyx_int_10);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__swe7));
  PyTuple_SET_ITEM(__pyx_k_tuple_11, 1, ((PyObject *)__pyx_n_s__swe7));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__swe7));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__swe7_swedish_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_11, 2, ((PyObject *)__pyx_n_s__swe7_swedish_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__swe7_swedish_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_11, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_11));

  /* "cymysql/charsetx.pyx":53
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 */
  __pyx_k_tuple_12 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 53; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_12);
  __Pyx_INCREF(__pyx_int_11);
  PyTuple_SET_ITEM(__pyx_k_tuple_12, 0, __pyx_int_11);
  __Pyx_GIVEREF(__pyx_int_11);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ascii));
  PyTuple_SET_ITEM(__pyx_k_tuple_12, 1, ((PyObject *)__pyx_n_s__ascii));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ascii));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ascii_general_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_12, 2, ((PyObject *)__pyx_n_s__ascii_general_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ascii_general_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_12, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_12));

  /* "cymysql/charsetx.pyx":54
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 */
  __pyx_k_tuple_13 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 54; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_13);
  __Pyx_INCREF(__pyx_int_12);
  PyTuple_SET_ITEM(__pyx_k_tuple_13, 0, __pyx_int_12);
  __Pyx_GIVEREF(__pyx_int_12);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ujis));
  PyTuple_SET_ITEM(__pyx_k_tuple_13, 1, ((PyObject *)__pyx_n_s__ujis));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ujis));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ujis_japanese_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_13, 2, ((PyObject *)__pyx_n_s__ujis_japanese_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ujis_japanese_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_13, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_13));

  /* "cymysql/charsetx.pyx":55
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 */
  __pyx_k_tuple_14 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 55; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_14);
  __Pyx_INCREF(__pyx_int_13);
  PyTuple_SET_ITEM(__pyx_k_tuple_14, 0, __pyx_int_13);
  __Pyx_GIVEREF(__pyx_int_13);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__sjis));
  PyTuple_SET_ITEM(__pyx_k_tuple_14, 1, ((PyObject *)__pyx_n_s__sjis));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__sjis));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__sjis_japanese_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_14, 2, ((PyObject *)__pyx_n_s__sjis_japanese_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__sjis_japanese_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_14, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_14));

  /* "cymysql/charsetx.pyx":56
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 */
  __pyx_k_tuple_15 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_15)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 56; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_15);
  __Pyx_INCREF(__pyx_int_14);
  PyTuple_SET_ITEM(__pyx_k_tuple_15, 0, __pyx_int_14);
  __Pyx_GIVEREF(__pyx_int_14);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1251));
  PyTuple_SET_ITEM(__pyx_k_tuple_15, 1, ((PyObject *)__pyx_n_s__cp1251));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1251));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1251_bulgarian_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_15, 2, ((PyObject *)__pyx_n_s__cp1251_bulgarian_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1251_bulgarian_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_15, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_15));

  /* "cymysql/charsetx.pyx":57
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 */
  __pyx_k_tuple_16 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 57; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_16);
  __Pyx_INCREF(__pyx_int_15);
  PyTuple_SET_ITEM(__pyx_k_tuple_16, 0, __pyx_int_15);
  __Pyx_GIVEREF(__pyx_int_15);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin1));
  PyTuple_SET_ITEM(__pyx_k_tuple_16, 1, ((PyObject *)__pyx_n_s__latin1));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin1));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin1_danish_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_16, 2, ((PyObject *)__pyx_n_s__latin1_danish_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin1_danish_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_16, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_16));

  /* "cymysql/charsetx.pyx":58
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 */
  __pyx_k_tuple_17 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_17)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 58; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_17);
  __Pyx_INCREF(__pyx_int_16);
  PyTuple_SET_ITEM(__pyx_k_tuple_17, 0, __pyx_int_16);
  __Pyx_GIVEREF(__pyx_int_16);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__hebrew));
  PyTuple_SET_ITEM(__pyx_k_tuple_17, 1, ((PyObject *)__pyx_n_s__hebrew));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__hebrew));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__hebrew_general_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_17, 2, ((PyObject *)__pyx_n_s__hebrew_general_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__hebrew_general_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_17, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_17));

  /* "cymysql/charsetx.pyx":59
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 */
  __pyx_k_tuple_18 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_18)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 59; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_18);
  __Pyx_INCREF(__pyx_int_18);
  PyTuple_SET_ITEM(__pyx_k_tuple_18, 0, __pyx_int_18);
  __Pyx_GIVEREF(__pyx_int_18);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__tis620));
  PyTuple_SET_ITEM(__pyx_k_tuple_18, 1, ((PyObject *)__pyx_n_s__tis620));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__tis620));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__tis620_thai_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_18, 2, ((PyObject *)__pyx_n_s__tis620_thai_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__tis620_thai_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_18, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_18));

  /* "cymysql/charsetx.pyx":60
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 */
  __pyx_k_tuple_19 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_19)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 60; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_19);
  __Pyx_INCREF(__pyx_int_19);
  PyTuple_SET_ITEM(__pyx_k_tuple_19, 0, __pyx_int_19);
  __Pyx_GIVEREF(__pyx_int_19);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__euckr));
  PyTuple_SET_ITEM(__pyx_k_tuple_19, 1, ((PyObject *)__pyx_n_s__euckr));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__euckr));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__euckr_korean_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_19, 2, ((PyObject *)__pyx_n_s__euckr_korean_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__euckr_korean_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_19, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_19));

  /* "cymysql/charsetx.pyx":61
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 */
  __pyx_k_tuple_20 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_20)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 61; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_20);
  __Pyx_INCREF(__pyx_int_20);
  PyTuple_SET_ITEM(__pyx_k_tuple_20, 0, __pyx_int_20);
  __Pyx_GIVEREF(__pyx_int_20);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin7));
  PyTuple_SET_ITEM(__pyx_k_tuple_20, 1, ((PyObject *)__pyx_n_s__latin7));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin7));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin7_estonian_cs));
  PyTuple_SET_ITEM(__pyx_k_tuple_20, 2, ((PyObject *)__pyx_n_s__latin7_estonian_cs));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin7_estonian_cs));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_20, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_20));

  /* "cymysql/charsetx.pyx":62
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 */
  __pyx_k_tuple_21 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_21)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_21);
  __Pyx_INCREF(__pyx_int_21);
  PyTuple_SET_ITEM(__pyx_k_tuple_21, 0, __pyx_int_21);
  __Pyx_GIVEREF(__pyx_int_21);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin2));
  PyTuple_SET_ITEM(__pyx_k_tuple_21, 1, ((PyObject *)__pyx_n_s__latin2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin2_hungarian_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_21, 2, ((PyObject *)__pyx_n_s__latin2_hungarian_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin2_hungarian_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_21, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_21));

  /* "cymysql/charsetx.pyx":63
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 */
  __pyx_k_tuple_22 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_22)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 63; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_22);
  __Pyx_INCREF(__pyx_int_22);
  PyTuple_SET_ITEM(__pyx_k_tuple_22, 0, __pyx_int_22);
  __Pyx_GIVEREF(__pyx_int_22);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__koi8u));
  PyTuple_SET_ITEM(__pyx_k_tuple_22, 1, ((PyObject *)__pyx_n_s__koi8u));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__koi8u));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__koi8u_general_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_22, 2, ((PyObject *)__pyx_n_s__koi8u_general_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__koi8u_general_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_22, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_22));

  /* "cymysql/charsetx.pyx":64
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 */
  __pyx_k_tuple_23 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_23)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 64; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_23);
  __Pyx_INCREF(__pyx_int_23);
  PyTuple_SET_ITEM(__pyx_k_tuple_23, 0, __pyx_int_23);
  __Pyx_GIVEREF(__pyx_int_23);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1251));
  PyTuple_SET_ITEM(__pyx_k_tuple_23, 1, ((PyObject *)__pyx_n_s__cp1251));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1251));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1251_ukrainian_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_23, 2, ((PyObject *)__pyx_n_s__cp1251_ukrainian_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1251_ukrainian_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_23, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_23));

  /* "cymysql/charsetx.pyx":65
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 */
  __pyx_k_tuple_24 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_24)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_24);
  __Pyx_INCREF(__pyx_int_24);
  PyTuple_SET_ITEM(__pyx_k_tuple_24, 0, __pyx_int_24);
  __Pyx_GIVEREF(__pyx_int_24);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__gb2312));
  PyTuple_SET_ITEM(__pyx_k_tuple_24, 1, ((PyObject *)__pyx_n_s__gb2312));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__gb2312));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__gb2312_chinese_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_24, 2, ((PyObject *)__pyx_n_s__gb2312_chinese_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__gb2312_chinese_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_24, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_24));

  /* "cymysql/charsetx.pyx":66
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 */
  __pyx_k_tuple_25 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_25)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_25);
  __Pyx_INCREF(__pyx_int_25);
  PyTuple_SET_ITEM(__pyx_k_tuple_25, 0, __pyx_int_25);
  __Pyx_GIVEREF(__pyx_int_25);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__greek));
  PyTuple_SET_ITEM(__pyx_k_tuple_25, 1, ((PyObject *)__pyx_n_s__greek));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__greek));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__greek_general_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_25, 2, ((PyObject *)__pyx_n_s__greek_general_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__greek_general_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_25, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_25));

  /* "cymysql/charsetx.pyx":67
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 */
  __pyx_k_tuple_26 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_26)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_26);
  __Pyx_INCREF(__pyx_int_26);
  PyTuple_SET_ITEM(__pyx_k_tuple_26, 0, __pyx_int_26);
  __Pyx_GIVEREF(__pyx_int_26);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1250));
  PyTuple_SET_ITEM(__pyx_k_tuple_26, 1, ((PyObject *)__pyx_n_s__cp1250));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1250));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1250_general_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_26, 2, ((PyObject *)__pyx_n_s__cp1250_general_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1250_general_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_26, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_26));

  /* "cymysql/charsetx.pyx":68
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 */
  __pyx_k_tuple_27 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_27)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 68; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_27);
  __Pyx_INCREF(__pyx_int_27);
  PyTuple_SET_ITEM(__pyx_k_tuple_27, 0, __pyx_int_27);
  __Pyx_GIVEREF(__pyx_int_27);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin2));
  PyTuple_SET_ITEM(__pyx_k_tuple_27, 1, ((PyObject *)__pyx_n_s__latin2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin2_croatian_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_27, 2, ((PyObject *)__pyx_n_s__latin2_croatian_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin2_croatian_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_27, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_27));

  /* "cymysql/charsetx.pyx":69
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 */
  __pyx_k_tuple_28 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_28)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 69; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_28);
  __Pyx_INCREF(__pyx_int_28);
  PyTuple_SET_ITEM(__pyx_k_tuple_28, 0, __pyx_int_28);
  __Pyx_GIVEREF(__pyx_int_28);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__gbk));
  PyTuple_SET_ITEM(__pyx_k_tuple_28, 1, ((PyObject *)__pyx_n_s__gbk));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__gbk));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__gbk_chinese_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_28, 2, ((PyObject *)__pyx_n_s__gbk_chinese_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__gbk_chinese_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_28, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_28));

  /* "cymysql/charsetx.pyx":70
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 */
  __pyx_k_tuple_30 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_30)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 70; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_30);
  __Pyx_INCREF(__pyx_int_29);
  PyTuple_SET_ITEM(__pyx_k_tuple_30, 0, __pyx_int_29);
  __Pyx_GIVEREF(__pyx_int_29);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1257));
  PyTuple_SET_ITEM(__pyx_k_tuple_30, 1, ((PyObject *)__pyx_n_s__cp1257));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1257));
  __Pyx_INCREF(((PyObject *)__pyx_n_s_29));
  PyTuple_SET_ITEM(__pyx_k_tuple_30, 2, ((PyObject *)__pyx_n_s_29));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s_29));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_30, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_30));

  /* "cymysql/charsetx.pyx":71
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 */
  __pyx_k_tuple_31 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_31)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_31);
  __Pyx_INCREF(__pyx_int_30);
  PyTuple_SET_ITEM(__pyx_k_tuple_31, 0, __pyx_int_30);
  __Pyx_GIVEREF(__pyx_int_30);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin5));
  PyTuple_SET_ITEM(__pyx_k_tuple_31, 1, ((PyObject *)__pyx_n_s__latin5));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin5));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin5_turkish_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_31, 2, ((PyObject *)__pyx_n_s__latin5_turkish_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin5_turkish_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_31, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_31));

  /* "cymysql/charsetx.pyx":72
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 */
  __pyx_k_tuple_32 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_32)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 72; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_32);
  __Pyx_INCREF(__pyx_int_31);
  PyTuple_SET_ITEM(__pyx_k_tuple_32, 0, __pyx_int_31);
  __Pyx_GIVEREF(__pyx_int_31);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin1));
  PyTuple_SET_ITEM(__pyx_k_tuple_32, 1, ((PyObject *)__pyx_n_s__latin1));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin1));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin1_german2_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_32, 2, ((PyObject *)__pyx_n_s__latin1_german2_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin1_german2_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_32, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_32));

  /* "cymysql/charsetx.pyx":73
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 */
  __pyx_k_tuple_33 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_33)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_33);
  __Pyx_INCREF(__pyx_int_32);
  PyTuple_SET_ITEM(__pyx_k_tuple_33, 0, __pyx_int_32);
  __Pyx_GIVEREF(__pyx_int_32);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__armscii8));
  PyTuple_SET_ITEM(__pyx_k_tuple_33, 1, ((PyObject *)__pyx_n_s__armscii8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__armscii8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__armscii8_general_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_33, 2, ((PyObject *)__pyx_n_s__armscii8_general_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__armscii8_general_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_33, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_33));

  /* "cymysql/charsetx.pyx":74
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 */
  __pyx_k_tuple_34 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_34)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_34);
  __Pyx_INCREF(__pyx_int_33);
  PyTuple_SET_ITEM(__pyx_k_tuple_34, 0, __pyx_int_33);
  __Pyx_GIVEREF(__pyx_int_33);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8));
  PyTuple_SET_ITEM(__pyx_k_tuple_34, 1, ((PyObject *)__pyx_n_s__utf8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8_general_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_34, 2, ((PyObject *)__pyx_n_s__utf8_general_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8_general_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_34, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_34));

  /* "cymysql/charsetx.pyx":75
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 */
  __pyx_k_tuple_35 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_35)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 75; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_35);
  __Pyx_INCREF(__pyx_int_34);
  PyTuple_SET_ITEM(__pyx_k_tuple_35, 0, __pyx_int_34);
  __Pyx_GIVEREF(__pyx_int_34);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1250));
  PyTuple_SET_ITEM(__pyx_k_tuple_35, 1, ((PyObject *)__pyx_n_s__cp1250));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1250));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1250_czech_cs));
  PyTuple_SET_ITEM(__pyx_k_tuple_35, 2, ((PyObject *)__pyx_n_s__cp1250_czech_cs));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1250_czech_cs));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_35, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_35));

  /* "cymysql/charsetx.pyx":76
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 */
  __pyx_k_tuple_36 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_36)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_36);
  __Pyx_INCREF(__pyx_int_35);
  PyTuple_SET_ITEM(__pyx_k_tuple_36, 0, __pyx_int_35);
  __Pyx_GIVEREF(__pyx_int_35);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_36, 1, ((PyObject *)__pyx_n_s__ucs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2_general_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_36, 2, ((PyObject *)__pyx_n_s__ucs2_general_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2_general_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_36, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_36));

  /* "cymysql/charsetx.pyx":77
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 */
  __pyx_k_tuple_37 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_37)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 77; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_37);
  __Pyx_INCREF(__pyx_int_36);
  PyTuple_SET_ITEM(__pyx_k_tuple_37, 0, __pyx_int_36);
  __Pyx_GIVEREF(__pyx_int_36);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp866));
  PyTuple_SET_ITEM(__pyx_k_tuple_37, 1, ((PyObject *)__pyx_n_s__cp866));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp866));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp866_general_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_37, 2, ((PyObject *)__pyx_n_s__cp866_general_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp866_general_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_37, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_37));

  /* "cymysql/charsetx.pyx":78
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 */
  __pyx_k_tuple_38 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_38)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_38);
  __Pyx_INCREF(__pyx_int_37);
  PyTuple_SET_ITEM(__pyx_k_tuple_38, 0, __pyx_int_37);
  __Pyx_GIVEREF(__pyx_int_37);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__keybcs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_38, 1, ((PyObject *)__pyx_n_s__keybcs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__keybcs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__keybcs2_general_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_38, 2, ((PyObject *)__pyx_n_s__keybcs2_general_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__keybcs2_general_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_38, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_38));

  /* "cymysql/charsetx.pyx":79
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 */
  __pyx_k_tuple_39 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_39)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 79; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_39);
  __Pyx_INCREF(__pyx_int_38);
  PyTuple_SET_ITEM(__pyx_k_tuple_39, 0, __pyx_int_38);
  __Pyx_GIVEREF(__pyx_int_38);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__macce));
  PyTuple_SET_ITEM(__pyx_k_tuple_39, 1, ((PyObject *)__pyx_n_s__macce));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__macce));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__macce_general_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_39, 2, ((PyObject *)__pyx_n_s__macce_general_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__macce_general_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_39, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_39));

  /* "cymysql/charsetx.pyx":80
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 */
  __pyx_k_tuple_40 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_40)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 80; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_40);
  __Pyx_INCREF(__pyx_int_39);
  PyTuple_SET_ITEM(__pyx_k_tuple_40, 0, __pyx_int_39);
  __Pyx_GIVEREF(__pyx_int_39);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__macroman));
  PyTuple_SET_ITEM(__pyx_k_tuple_40, 1, ((PyObject *)__pyx_n_s__macroman));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__macroman));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__macroman_general_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_40, 2, ((PyObject *)__pyx_n_s__macroman_general_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__macroman_general_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_40, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_40));

  /* "cymysql/charsetx.pyx":81
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 */
  __pyx_k_tuple_41 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_41)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_41);
  __Pyx_INCREF(__pyx_int_40);
  PyTuple_SET_ITEM(__pyx_k_tuple_41, 0, __pyx_int_40);
  __Pyx_GIVEREF(__pyx_int_40);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp852));
  PyTuple_SET_ITEM(__pyx_k_tuple_41, 1, ((PyObject *)__pyx_n_s__cp852));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp852));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp852_general_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_41, 2, ((PyObject *)__pyx_n_s__cp852_general_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp852_general_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_41, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_41));

  /* "cymysql/charsetx.pyx":82
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 */
  __pyx_k_tuple_42 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_42)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 82; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_42);
  __Pyx_INCREF(__pyx_int_41);
  PyTuple_SET_ITEM(__pyx_k_tuple_42, 0, __pyx_int_41);
  __Pyx_GIVEREF(__pyx_int_41);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin7));
  PyTuple_SET_ITEM(__pyx_k_tuple_42, 1, ((PyObject *)__pyx_n_s__latin7));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin7));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin7_general_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_42, 2, ((PyObject *)__pyx_n_s__latin7_general_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin7_general_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_42, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_42));

  /* "cymysql/charsetx.pyx":83
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 */
  __pyx_k_tuple_43 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_43)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_43);
  __Pyx_INCREF(__pyx_int_42);
  PyTuple_SET_ITEM(__pyx_k_tuple_43, 0, __pyx_int_42);
  __Pyx_GIVEREF(__pyx_int_42);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin7));
  PyTuple_SET_ITEM(__pyx_k_tuple_43, 1, ((PyObject *)__pyx_n_s__latin7));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin7));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin7_general_cs));
  PyTuple_SET_ITEM(__pyx_k_tuple_43, 2, ((PyObject *)__pyx_n_s__latin7_general_cs));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin7_general_cs));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_43, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_43));

  /* "cymysql/charsetx.pyx":84
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 */
  __pyx_k_tuple_44 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_44)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 84; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_44);
  __Pyx_INCREF(__pyx_int_43);
  PyTuple_SET_ITEM(__pyx_k_tuple_44, 0, __pyx_int_43);
  __Pyx_GIVEREF(__pyx_int_43);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__macce));
  PyTuple_SET_ITEM(__pyx_k_tuple_44, 1, ((PyObject *)__pyx_n_s__macce));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__macce));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__macce_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_44, 2, ((PyObject *)__pyx_n_s__macce_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__macce_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_44, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_44));

  /* "cymysql/charsetx.pyx":85
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 */
  __pyx_k_tuple_45 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_45)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 85; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_45);
  __Pyx_INCREF(__pyx_int_44);
  PyTuple_SET_ITEM(__pyx_k_tuple_45, 0, __pyx_int_44);
  __Pyx_GIVEREF(__pyx_int_44);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1250));
  PyTuple_SET_ITEM(__pyx_k_tuple_45, 1, ((PyObject *)__pyx_n_s__cp1250));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1250));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1250_croatian_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_45, 2, ((PyObject *)__pyx_n_s__cp1250_croatian_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1250_croatian_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_45, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_45));

  /* "cymysql/charsetx.pyx":86
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 */
  __pyx_k_tuple_46 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_46)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_46);
  __Pyx_INCREF(__pyx_int_47);
  PyTuple_SET_ITEM(__pyx_k_tuple_46, 0, __pyx_int_47);
  __Pyx_GIVEREF(__pyx_int_47);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin1));
  PyTuple_SET_ITEM(__pyx_k_tuple_46, 1, ((PyObject *)__pyx_n_s__latin1));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin1));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin1_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_46, 2, ((PyObject *)__pyx_n_s__latin1_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin1_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_46, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_46));

  /* "cymysql/charsetx.pyx":87
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 */
  __pyx_k_tuple_47 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_47)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 87; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_47);
  __Pyx_INCREF(__pyx_int_48);
  PyTuple_SET_ITEM(__pyx_k_tuple_47, 0, __pyx_int_48);
  __Pyx_GIVEREF(__pyx_int_48);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin1));
  PyTuple_SET_ITEM(__pyx_k_tuple_47, 1, ((PyObject *)__pyx_n_s__latin1));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin1));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin1_general_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_47, 2, ((PyObject *)__pyx_n_s__latin1_general_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin1_general_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_47, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_47));

  /* "cymysql/charsetx.pyx":88
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 */
  __pyx_k_tuple_48 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_48)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 88; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_48);
  __Pyx_INCREF(__pyx_int_49);
  PyTuple_SET_ITEM(__pyx_k_tuple_48, 0, __pyx_int_49);
  __Pyx_GIVEREF(__pyx_int_49);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin1));
  PyTuple_SET_ITEM(__pyx_k_tuple_48, 1, ((PyObject *)__pyx_n_s__latin1));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin1));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin1_general_cs));
  PyTuple_SET_ITEM(__pyx_k_tuple_48, 2, ((PyObject *)__pyx_n_s__latin1_general_cs));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin1_general_cs));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_48, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_48));

  /* "cymysql/charsetx.pyx":89
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 */
  __pyx_k_tuple_49 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_49)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 89; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_49);
  __Pyx_INCREF(__pyx_int_50);
  PyTuple_SET_ITEM(__pyx_k_tuple_49, 0, __pyx_int_50);
  __Pyx_GIVEREF(__pyx_int_50);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1251));
  PyTuple_SET_ITEM(__pyx_k_tuple_49, 1, ((PyObject *)__pyx_n_s__cp1251));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1251));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1251_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_49, 2, ((PyObject *)__pyx_n_s__cp1251_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1251_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_49, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_49));

  /* "cymysql/charsetx.pyx":90
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 */
  __pyx_k_tuple_50 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_50)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 90; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_50);
  __Pyx_INCREF(__pyx_int_51);
  PyTuple_SET_ITEM(__pyx_k_tuple_50, 0, __pyx_int_51);
  __Pyx_GIVEREF(__pyx_int_51);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1251));
  PyTuple_SET_ITEM(__pyx_k_tuple_50, 1, ((PyObject *)__pyx_n_s__cp1251));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1251));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1251_general_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_50, 2, ((PyObject *)__pyx_n_s__cp1251_general_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1251_general_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_50, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_50));

  /* "cymysql/charsetx.pyx":91
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 */
  __pyx_k_tuple_51 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_51)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 91; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_51);
  __Pyx_INCREF(__pyx_int_52);
  PyTuple_SET_ITEM(__pyx_k_tuple_51, 0, __pyx_int_52);
  __Pyx_GIVEREF(__pyx_int_52);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1251));
  PyTuple_SET_ITEM(__pyx_k_tuple_51, 1, ((PyObject *)__pyx_n_s__cp1251));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1251));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1251_general_cs));
  PyTuple_SET_ITEM(__pyx_k_tuple_51, 2, ((PyObject *)__pyx_n_s__cp1251_general_cs));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1251_general_cs));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_51, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_51));

  /* "cymysql/charsetx.pyx":92
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 */
  __pyx_k_tuple_52 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_52)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 92; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_52);
  __Pyx_INCREF(__pyx_int_53);
  PyTuple_SET_ITEM(__pyx_k_tuple_52, 0, __pyx_int_53);
  __Pyx_GIVEREF(__pyx_int_53);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__macroman));
  PyTuple_SET_ITEM(__pyx_k_tuple_52, 1, ((PyObject *)__pyx_n_s__macroman));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__macroman));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__macroman_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_52, 2, ((PyObject *)__pyx_n_s__macroman_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__macroman_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_52, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_52));

  /* "cymysql/charsetx.pyx":93
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 */
  __pyx_k_tuple_53 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_53)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 93; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_53);
  __Pyx_INCREF(__pyx_int_57);
  PyTuple_SET_ITEM(__pyx_k_tuple_53, 0, __pyx_int_57);
  __Pyx_GIVEREF(__pyx_int_57);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1256));
  PyTuple_SET_ITEM(__pyx_k_tuple_53, 1, ((PyObject *)__pyx_n_s__cp1256));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1256));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1256_general_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_53, 2, ((PyObject *)__pyx_n_s__cp1256_general_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1256_general_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_53, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_53));

  /* "cymysql/charsetx.pyx":94
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 */
  __pyx_k_tuple_54 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_54)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 94; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_54);
  __Pyx_INCREF(__pyx_int_58);
  PyTuple_SET_ITEM(__pyx_k_tuple_54, 0, __pyx_int_58);
  __Pyx_GIVEREF(__pyx_int_58);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1257));
  PyTuple_SET_ITEM(__pyx_k_tuple_54, 1, ((PyObject *)__pyx_n_s__cp1257));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1257));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1257_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_54, 2, ((PyObject *)__pyx_n_s__cp1257_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1257_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_54, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_54));

  /* "cymysql/charsetx.pyx":95
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 */
  __pyx_k_tuple_55 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_55)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 95; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_55);
  __Pyx_INCREF(__pyx_int_59);
  PyTuple_SET_ITEM(__pyx_k_tuple_55, 0, __pyx_int_59);
  __Pyx_GIVEREF(__pyx_int_59);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1257));
  PyTuple_SET_ITEM(__pyx_k_tuple_55, 1, ((PyObject *)__pyx_n_s__cp1257));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1257));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1257_general_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_55, 2, ((PyObject *)__pyx_n_s__cp1257_general_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1257_general_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_55, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_55));

  /* "cymysql/charsetx.pyx":96
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 */
  __pyx_k_tuple_56 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_56)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 96; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_56);
  __Pyx_INCREF(__pyx_int_63);
  PyTuple_SET_ITEM(__pyx_k_tuple_56, 0, __pyx_int_63);
  __Pyx_GIVEREF(__pyx_int_63);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__binary));
  PyTuple_SET_ITEM(__pyx_k_tuple_56, 1, ((PyObject *)__pyx_n_s__binary));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__binary));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__binary));
  PyTuple_SET_ITEM(__pyx_k_tuple_56, 2, ((PyObject *)__pyx_n_s__binary));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__binary));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_56, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_56));

  /* "cymysql/charsetx.pyx":97
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 */
  __pyx_k_tuple_57 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_57)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 97; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_57);
  __Pyx_INCREF(__pyx_int_64);
  PyTuple_SET_ITEM(__pyx_k_tuple_57, 0, __pyx_int_64);
  __Pyx_GIVEREF(__pyx_int_64);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__armscii8));
  PyTuple_SET_ITEM(__pyx_k_tuple_57, 1, ((PyObject *)__pyx_n_s__armscii8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__armscii8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__armscii8_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_57, 2, ((PyObject *)__pyx_n_s__armscii8_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__armscii8_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_57, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_57));

  /* "cymysql/charsetx.pyx":98
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 */
  __pyx_k_tuple_58 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_58)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 98; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_58);
  __Pyx_INCREF(__pyx_int_65);
  PyTuple_SET_ITEM(__pyx_k_tuple_58, 0, __pyx_int_65);
  __Pyx_GIVEREF(__pyx_int_65);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ascii));
  PyTuple_SET_ITEM(__pyx_k_tuple_58, 1, ((PyObject *)__pyx_n_s__ascii));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ascii));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ascii_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_58, 2, ((PyObject *)__pyx_n_s__ascii_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ascii_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_58, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_58));

  /* "cymysql/charsetx.pyx":99
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 */
  __pyx_k_tuple_59 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_59)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 99; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_59);
  __Pyx_INCREF(__pyx_int_66);
  PyTuple_SET_ITEM(__pyx_k_tuple_59, 0, __pyx_int_66);
  __Pyx_GIVEREF(__pyx_int_66);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1250));
  PyTuple_SET_ITEM(__pyx_k_tuple_59, 1, ((PyObject *)__pyx_n_s__cp1250));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1250));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1250_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_59, 2, ((PyObject *)__pyx_n_s__cp1250_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1250_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_59, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_59));

  /* "cymysql/charsetx.pyx":100
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 */
  __pyx_k_tuple_60 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_60)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 100; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_60);
  __Pyx_INCREF(__pyx_int_67);
  PyTuple_SET_ITEM(__pyx_k_tuple_60, 0, __pyx_int_67);
  __Pyx_GIVEREF(__pyx_int_67);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1256));
  PyTuple_SET_ITEM(__pyx_k_tuple_60, 1, ((PyObject *)__pyx_n_s__cp1256));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1256));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1256_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_60, 2, ((PyObject *)__pyx_n_s__cp1256_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1256_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_60, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_60));

  /* "cymysql/charsetx.pyx":101
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 */
  __pyx_k_tuple_61 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_61)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 101; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_61);
  __Pyx_INCREF(__pyx_int_68);
  PyTuple_SET_ITEM(__pyx_k_tuple_61, 0, __pyx_int_68);
  __Pyx_GIVEREF(__pyx_int_68);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp866));
  PyTuple_SET_ITEM(__pyx_k_tuple_61, 1, ((PyObject *)__pyx_n_s__cp866));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp866));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp866_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_61, 2, ((PyObject *)__pyx_n_s__cp866_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp866_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_61, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_61));

  /* "cymysql/charsetx.pyx":102
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 */
  __pyx_k_tuple_62 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_62)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_62);
  __Pyx_INCREF(__pyx_int_69);
  PyTuple_SET_ITEM(__pyx_k_tuple_62, 0, __pyx_int_69);
  __Pyx_GIVEREF(__pyx_int_69);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__dec8));
  PyTuple_SET_ITEM(__pyx_k_tuple_62, 1, ((PyObject *)__pyx_n_s__dec8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__dec8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__dec8_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_62, 2, ((PyObject *)__pyx_n_s__dec8_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__dec8_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_62, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_62));

  /* "cymysql/charsetx.pyx":103
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 */
  __pyx_k_tuple_63 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_63)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_63);
  __Pyx_INCREF(__pyx_int_70);
  PyTuple_SET_ITEM(__pyx_k_tuple_63, 0, __pyx_int_70);
  __Pyx_GIVEREF(__pyx_int_70);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__greek));
  PyTuple_SET_ITEM(__pyx_k_tuple_63, 1, ((PyObject *)__pyx_n_s__greek));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__greek));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__greek_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_63, 2, ((PyObject *)__pyx_n_s__greek_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__greek_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_63, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_63));

  /* "cymysql/charsetx.pyx":104
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 */
  __pyx_k_tuple_64 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_64)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 104; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_64);
  __Pyx_INCREF(__pyx_int_71);
  PyTuple_SET_ITEM(__pyx_k_tuple_64, 0, __pyx_int_71);
  __Pyx_GIVEREF(__pyx_int_71);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__hebrew));
  PyTuple_SET_ITEM(__pyx_k_tuple_64, 1, ((PyObject *)__pyx_n_s__hebrew));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__hebrew));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__hebrew_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_64, 2, ((PyObject *)__pyx_n_s__hebrew_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__hebrew_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_64, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_64));

  /* "cymysql/charsetx.pyx":105
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 */
  __pyx_k_tuple_65 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_65)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_65);
  __Pyx_INCREF(__pyx_int_72);
  PyTuple_SET_ITEM(__pyx_k_tuple_65, 0, __pyx_int_72);
  __Pyx_GIVEREF(__pyx_int_72);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__hp8));
  PyTuple_SET_ITEM(__pyx_k_tuple_65, 1, ((PyObject *)__pyx_n_s__hp8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__hp8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__hp8_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_65, 2, ((PyObject *)__pyx_n_s__hp8_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__hp8_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_65, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_65));

  /* "cymysql/charsetx.pyx":106
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 */
  __pyx_k_tuple_66 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_66)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_66);
  __Pyx_INCREF(__pyx_int_73);
  PyTuple_SET_ITEM(__pyx_k_tuple_66, 0, __pyx_int_73);
  __Pyx_GIVEREF(__pyx_int_73);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__keybcs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_66, 1, ((PyObject *)__pyx_n_s__keybcs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__keybcs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__keybcs2_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_66, 2, ((PyObject *)__pyx_n_s__keybcs2_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__keybcs2_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_66, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_66));

  /* "cymysql/charsetx.pyx":107
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 */
  __pyx_k_tuple_67 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_67)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_67);
  __Pyx_INCREF(__pyx_int_74);
  PyTuple_SET_ITEM(__pyx_k_tuple_67, 0, __pyx_int_74);
  __Pyx_GIVEREF(__pyx_int_74);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__koi8r));
  PyTuple_SET_ITEM(__pyx_k_tuple_67, 1, ((PyObject *)__pyx_n_s__koi8r));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__koi8r));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__koi8r_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_67, 2, ((PyObject *)__pyx_n_s__koi8r_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__koi8r_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_67, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_67));

  /* "cymysql/charsetx.pyx":108
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 */
  __pyx_k_tuple_68 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_68)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 108; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_68);
  __Pyx_INCREF(__pyx_int_75);
  PyTuple_SET_ITEM(__pyx_k_tuple_68, 0, __pyx_int_75);
  __Pyx_GIVEREF(__pyx_int_75);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__koi8u));
  PyTuple_SET_ITEM(__pyx_k_tuple_68, 1, ((PyObject *)__pyx_n_s__koi8u));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__koi8u));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__koi8u_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_68, 2, ((PyObject *)__pyx_n_s__koi8u_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__koi8u_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_68, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_68));

  /* "cymysql/charsetx.pyx":109
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 */
  __pyx_k_tuple_69 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_69)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_69);
  __Pyx_INCREF(__pyx_int_77);
  PyTuple_SET_ITEM(__pyx_k_tuple_69, 0, __pyx_int_77);
  __Pyx_GIVEREF(__pyx_int_77);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin2));
  PyTuple_SET_ITEM(__pyx_k_tuple_69, 1, ((PyObject *)__pyx_n_s__latin2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin2_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_69, 2, ((PyObject *)__pyx_n_s__latin2_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin2_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_69, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_69));

  /* "cymysql/charsetx.pyx":110
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 */
  __pyx_k_tuple_70 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_70)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 110; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_70);
  __Pyx_INCREF(__pyx_int_78);
  PyTuple_SET_ITEM(__pyx_k_tuple_70, 0, __pyx_int_78);
  __Pyx_GIVEREF(__pyx_int_78);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin5));
  PyTuple_SET_ITEM(__pyx_k_tuple_70, 1, ((PyObject *)__pyx_n_s__latin5));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin5));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin5_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_70, 2, ((PyObject *)__pyx_n_s__latin5_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin5_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_70, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_70));

  /* "cymysql/charsetx.pyx":111
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 */
  __pyx_k_tuple_71 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_71)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 111; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_71);
  __Pyx_INCREF(__pyx_int_79);
  PyTuple_SET_ITEM(__pyx_k_tuple_71, 0, __pyx_int_79);
  __Pyx_GIVEREF(__pyx_int_79);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin7));
  PyTuple_SET_ITEM(__pyx_k_tuple_71, 1, ((PyObject *)__pyx_n_s__latin7));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin7));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin7_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_71, 2, ((PyObject *)__pyx_n_s__latin7_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin7_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_71, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_71));

  /* "cymysql/charsetx.pyx":112
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 */
  __pyx_k_tuple_72 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_72)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 112; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_72);
  __Pyx_INCREF(__pyx_int_80);
  PyTuple_SET_ITEM(__pyx_k_tuple_72, 0, __pyx_int_80);
  __Pyx_GIVEREF(__pyx_int_80);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp850));
  PyTuple_SET_ITEM(__pyx_k_tuple_72, 1, ((PyObject *)__pyx_n_s__cp850));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp850));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp850_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_72, 2, ((PyObject *)__pyx_n_s__cp850_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp850_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_72, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_72));

  /* "cymysql/charsetx.pyx":113
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 */
  __pyx_k_tuple_73 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_73)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 113; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_73);
  __Pyx_INCREF(__pyx_int_81);
  PyTuple_SET_ITEM(__pyx_k_tuple_73, 0, __pyx_int_81);
  __Pyx_GIVEREF(__pyx_int_81);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp852));
  PyTuple_SET_ITEM(__pyx_k_tuple_73, 1, ((PyObject *)__pyx_n_s__cp852));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp852));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp852_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_73, 2, ((PyObject *)__pyx_n_s__cp852_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp852_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_73, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_73));

  /* "cymysql/charsetx.pyx":114
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 */
  __pyx_k_tuple_74 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_74)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 114; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_74);
  __Pyx_INCREF(__pyx_int_82);
  PyTuple_SET_ITEM(__pyx_k_tuple_74, 0, __pyx_int_82);
  __Pyx_GIVEREF(__pyx_int_82);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__swe7));
  PyTuple_SET_ITEM(__pyx_k_tuple_74, 1, ((PyObject *)__pyx_n_s__swe7));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__swe7));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__swe7_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_74, 2, ((PyObject *)__pyx_n_s__swe7_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__swe7_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_74, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_74));

  /* "cymysql/charsetx.pyx":115
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 */
  __pyx_k_tuple_75 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_75)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_75);
  __Pyx_INCREF(__pyx_int_83);
  PyTuple_SET_ITEM(__pyx_k_tuple_75, 0, __pyx_int_83);
  __Pyx_GIVEREF(__pyx_int_83);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8));
  PyTuple_SET_ITEM(__pyx_k_tuple_75, 1, ((PyObject *)__pyx_n_s__utf8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_75, 2, ((PyObject *)__pyx_n_s__utf8_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_75, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_75));

  /* "cymysql/charsetx.pyx":116
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 */
  __pyx_k_tuple_76 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_76)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 116; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_76);
  __Pyx_INCREF(__pyx_int_84);
  PyTuple_SET_ITEM(__pyx_k_tuple_76, 0, __pyx_int_84);
  __Pyx_GIVEREF(__pyx_int_84);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__big5));
  PyTuple_SET_ITEM(__pyx_k_tuple_76, 1, ((PyObject *)__pyx_n_s__big5));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__big5));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__big5_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_76, 2, ((PyObject *)__pyx_n_s__big5_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__big5_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_76, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_76));

  /* "cymysql/charsetx.pyx":117
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 */
  __pyx_k_tuple_77 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_77)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 117; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_77);
  __Pyx_INCREF(__pyx_int_85);
  PyTuple_SET_ITEM(__pyx_k_tuple_77, 0, __pyx_int_85);
  __Pyx_GIVEREF(__pyx_int_85);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__euckr));
  PyTuple_SET_ITEM(__pyx_k_tuple_77, 1, ((PyObject *)__pyx_n_s__euckr));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__euckr));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__euckr_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_77, 2, ((PyObject *)__pyx_n_s__euckr_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__euckr_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_77, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_77));

  /* "cymysql/charsetx.pyx":118
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 */
  __pyx_k_tuple_78 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_78)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 118; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_78);
  __Pyx_INCREF(__pyx_int_86);
  PyTuple_SET_ITEM(__pyx_k_tuple_78, 0, __pyx_int_86);
  __Pyx_GIVEREF(__pyx_int_86);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__gb2312));
  PyTuple_SET_ITEM(__pyx_k_tuple_78, 1, ((PyObject *)__pyx_n_s__gb2312));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__gb2312));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__gb2312_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_78, 2, ((PyObject *)__pyx_n_s__gb2312_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__gb2312_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_78, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_78));

  /* "cymysql/charsetx.pyx":119
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 */
  __pyx_k_tuple_79 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_79)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 119; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_79);
  __Pyx_INCREF(__pyx_int_87);
  PyTuple_SET_ITEM(__pyx_k_tuple_79, 0, __pyx_int_87);
  __Pyx_GIVEREF(__pyx_int_87);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__gbk));
  PyTuple_SET_ITEM(__pyx_k_tuple_79, 1, ((PyObject *)__pyx_n_s__gbk));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__gbk));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__gbk_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_79, 2, ((PyObject *)__pyx_n_s__gbk_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__gbk_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_79, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_79));

  /* "cymysql/charsetx.pyx":120
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 */
  __pyx_k_tuple_80 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_80)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_80);
  __Pyx_INCREF(__pyx_int_88);
  PyTuple_SET_ITEM(__pyx_k_tuple_80, 0, __pyx_int_88);
  __Pyx_GIVEREF(__pyx_int_88);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__sjis));
  PyTuple_SET_ITEM(__pyx_k_tuple_80, 1, ((PyObject *)__pyx_n_s__sjis));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__sjis));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__sjis_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_80, 2, ((PyObject *)__pyx_n_s__sjis_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__sjis_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_80, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_80));

  /* "cymysql/charsetx.pyx":121
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 */
  __pyx_k_tuple_81 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_81)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 121; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_81);
  __Pyx_INCREF(__pyx_int_89);
  PyTuple_SET_ITEM(__pyx_k_tuple_81, 0, __pyx_int_89);
  __Pyx_GIVEREF(__pyx_int_89);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__tis620));
  PyTuple_SET_ITEM(__pyx_k_tuple_81, 1, ((PyObject *)__pyx_n_s__tis620));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__tis620));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__tis620_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_81, 2, ((PyObject *)__pyx_n_s__tis620_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__tis620_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_81, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_81));

  /* "cymysql/charsetx.pyx":122
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 */
  __pyx_k_tuple_82 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_82)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 122; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_82);
  __Pyx_INCREF(__pyx_int_90);
  PyTuple_SET_ITEM(__pyx_k_tuple_82, 0, __pyx_int_90);
  __Pyx_GIVEREF(__pyx_int_90);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_82, 1, ((PyObject *)__pyx_n_s__ucs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_82, 2, ((PyObject *)__pyx_n_s__ucs2_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_82, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_82));

  /* "cymysql/charsetx.pyx":123
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 */
  __pyx_k_tuple_83 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_83)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 123; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_83);
  __Pyx_INCREF(__pyx_int_91);
  PyTuple_SET_ITEM(__pyx_k_tuple_83, 0, __pyx_int_91);
  __Pyx_GIVEREF(__pyx_int_91);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ujis));
  PyTuple_SET_ITEM(__pyx_k_tuple_83, 1, ((PyObject *)__pyx_n_s__ujis));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ujis));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ujis_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_83, 2, ((PyObject *)__pyx_n_s__ujis_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ujis_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_83, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_83));

  /* "cymysql/charsetx.pyx":124
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 */
  __pyx_k_tuple_84 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_84)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 124; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_84);
  __Pyx_INCREF(__pyx_int_92);
  PyTuple_SET_ITEM(__pyx_k_tuple_84, 0, __pyx_int_92);
  __Pyx_GIVEREF(__pyx_int_92);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__geostd8));
  PyTuple_SET_ITEM(__pyx_k_tuple_84, 1, ((PyObject *)__pyx_n_s__geostd8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__geostd8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__geostd8_general_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_84, 2, ((PyObject *)__pyx_n_s__geostd8_general_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__geostd8_general_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_84, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_84));

  /* "cymysql/charsetx.pyx":125
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 */
  __pyx_k_tuple_85 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_85)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 125; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_85);
  __Pyx_INCREF(__pyx_int_93);
  PyTuple_SET_ITEM(__pyx_k_tuple_85, 0, __pyx_int_93);
  __Pyx_GIVEREF(__pyx_int_93);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__geostd8));
  PyTuple_SET_ITEM(__pyx_k_tuple_85, 1, ((PyObject *)__pyx_n_s__geostd8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__geostd8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__geostd8_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_85, 2, ((PyObject *)__pyx_n_s__geostd8_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__geostd8_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_85, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_85));

  /* "cymysql/charsetx.pyx":126
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 */
  __pyx_k_tuple_86 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_86)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 126; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_86);
  __Pyx_INCREF(__pyx_int_94);
  PyTuple_SET_ITEM(__pyx_k_tuple_86, 0, __pyx_int_94);
  __Pyx_GIVEREF(__pyx_int_94);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin1));
  PyTuple_SET_ITEM(__pyx_k_tuple_86, 1, ((PyObject *)__pyx_n_s__latin1));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin1));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__latin1_spanish_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_86, 2, ((PyObject *)__pyx_n_s__latin1_spanish_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__latin1_spanish_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_86, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_86));

  /* "cymysql/charsetx.pyx":127
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 */
  __pyx_k_tuple_87 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_87)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_87);
  __Pyx_INCREF(__pyx_int_95);
  PyTuple_SET_ITEM(__pyx_k_tuple_87, 0, __pyx_int_95);
  __Pyx_GIVEREF(__pyx_int_95);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp932));
  PyTuple_SET_ITEM(__pyx_k_tuple_87, 1, ((PyObject *)__pyx_n_s__cp932));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp932));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp932_japanese_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_87, 2, ((PyObject *)__pyx_n_s__cp932_japanese_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp932_japanese_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_87, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_87));

  /* "cymysql/charsetx.pyx":128
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 */
  __pyx_k_tuple_88 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_88)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_88);
  __Pyx_INCREF(__pyx_int_96);
  PyTuple_SET_ITEM(__pyx_k_tuple_88, 0, __pyx_int_96);
  __Pyx_GIVEREF(__pyx_int_96);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp932));
  PyTuple_SET_ITEM(__pyx_k_tuple_88, 1, ((PyObject *)__pyx_n_s__cp932));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp932));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp932_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_88, 2, ((PyObject *)__pyx_n_s__cp932_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp932_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_88, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_88));

  /* "cymysql/charsetx.pyx":129
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 */
  __pyx_k_tuple_89 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_89)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_89);
  __Pyx_INCREF(__pyx_int_97);
  PyTuple_SET_ITEM(__pyx_k_tuple_89, 0, __pyx_int_97);
  __Pyx_GIVEREF(__pyx_int_97);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__eucjpms));
  PyTuple_SET_ITEM(__pyx_k_tuple_89, 1, ((PyObject *)__pyx_n_s__eucjpms));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__eucjpms));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__eucjpms_japanese_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_89, 2, ((PyObject *)__pyx_n_s__eucjpms_japanese_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__eucjpms_japanese_ci));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__Yes));
  PyTuple_SET_ITEM(__pyx_k_tuple_89, 3, ((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__Yes));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_89));

  /* "cymysql/charsetx.pyx":130
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 */
  __pyx_k_tuple_90 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_90)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 130; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_90);
  __Pyx_INCREF(__pyx_int_98);
  PyTuple_SET_ITEM(__pyx_k_tuple_90, 0, __pyx_int_98);
  __Pyx_GIVEREF(__pyx_int_98);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__eucjpms));
  PyTuple_SET_ITEM(__pyx_k_tuple_90, 1, ((PyObject *)__pyx_n_s__eucjpms));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__eucjpms));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__eucjpms_bin));
  PyTuple_SET_ITEM(__pyx_k_tuple_90, 2, ((PyObject *)__pyx_n_s__eucjpms_bin));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__eucjpms_bin));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_90, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_90));

  /* "cymysql/charsetx.pyx":131
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 */
  __pyx_k_tuple_91 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_91)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 131; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_91);
  __Pyx_INCREF(__pyx_int_99);
  PyTuple_SET_ITEM(__pyx_k_tuple_91, 0, __pyx_int_99);
  __Pyx_GIVEREF(__pyx_int_99);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1250));
  PyTuple_SET_ITEM(__pyx_k_tuple_91, 1, ((PyObject *)__pyx_n_s__cp1250));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1250));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cp1250_polish_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_91, 2, ((PyObject *)__pyx_n_s__cp1250_polish_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cp1250_polish_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_91, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_91));

  /* "cymysql/charsetx.pyx":132
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 */
  __pyx_k_tuple_92 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_92)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_92);
  __Pyx_INCREF(__pyx_int_128);
  PyTuple_SET_ITEM(__pyx_k_tuple_92, 0, __pyx_int_128);
  __Pyx_GIVEREF(__pyx_int_128);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_92, 1, ((PyObject *)__pyx_n_s__ucs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2_unicode_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_92, 2, ((PyObject *)__pyx_n_s__ucs2_unicode_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2_unicode_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_92, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_92));

  /* "cymysql/charsetx.pyx":133
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 */
  __pyx_k_tuple_93 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_93)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_93);
  __Pyx_INCREF(__pyx_int_129);
  PyTuple_SET_ITEM(__pyx_k_tuple_93, 0, __pyx_int_129);
  __Pyx_GIVEREF(__pyx_int_129);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_93, 1, ((PyObject *)__pyx_n_s__ucs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2_icelandic_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_93, 2, ((PyObject *)__pyx_n_s__ucs2_icelandic_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2_icelandic_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_93, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_93));

  /* "cymysql/charsetx.pyx":134
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 */
  __pyx_k_tuple_94 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_94)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 134; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_94);
  __Pyx_INCREF(__pyx_int_130);
  PyTuple_SET_ITEM(__pyx_k_tuple_94, 0, __pyx_int_130);
  __Pyx_GIVEREF(__pyx_int_130);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_94, 1, ((PyObject *)__pyx_n_s__ucs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2_latvian_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_94, 2, ((PyObject *)__pyx_n_s__ucs2_latvian_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2_latvian_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_94, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_94));

  /* "cymysql/charsetx.pyx":135
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 */
  __pyx_k_tuple_95 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_95)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 135; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_95);
  __Pyx_INCREF(__pyx_int_131);
  PyTuple_SET_ITEM(__pyx_k_tuple_95, 0, __pyx_int_131);
  __Pyx_GIVEREF(__pyx_int_131);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_95, 1, ((PyObject *)__pyx_n_s__ucs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2_romanian_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_95, 2, ((PyObject *)__pyx_n_s__ucs2_romanian_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2_romanian_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_95, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_95));

  /* "cymysql/charsetx.pyx":136
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 */
  __pyx_k_tuple_96 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_96)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 136; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_96);
  __Pyx_INCREF(__pyx_int_132);
  PyTuple_SET_ITEM(__pyx_k_tuple_96, 0, __pyx_int_132);
  __Pyx_GIVEREF(__pyx_int_132);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_96, 1, ((PyObject *)__pyx_n_s__ucs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2_slovenian_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_96, 2, ((PyObject *)__pyx_n_s__ucs2_slovenian_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2_slovenian_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_96, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_96));

  /* "cymysql/charsetx.pyx":137
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 */
  __pyx_k_tuple_97 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_97)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 137; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_97);
  __Pyx_INCREF(__pyx_int_133);
  PyTuple_SET_ITEM(__pyx_k_tuple_97, 0, __pyx_int_133);
  __Pyx_GIVEREF(__pyx_int_133);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_97, 1, ((PyObject *)__pyx_n_s__ucs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2_polish_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_97, 2, ((PyObject *)__pyx_n_s__ucs2_polish_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2_polish_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_97, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_97));

  /* "cymysql/charsetx.pyx":138
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 */
  __pyx_k_tuple_98 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_98)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_98);
  __Pyx_INCREF(__pyx_int_134);
  PyTuple_SET_ITEM(__pyx_k_tuple_98, 0, __pyx_int_134);
  __Pyx_GIVEREF(__pyx_int_134);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_98, 1, ((PyObject *)__pyx_n_s__ucs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2_estonian_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_98, 2, ((PyObject *)__pyx_n_s__ucs2_estonian_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2_estonian_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_98, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_98));

  /* "cymysql/charsetx.pyx":139
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 */
  __pyx_k_tuple_99 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_99)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 139; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_99);
  __Pyx_INCREF(__pyx_int_135);
  PyTuple_SET_ITEM(__pyx_k_tuple_99, 0, __pyx_int_135);
  __Pyx_GIVEREF(__pyx_int_135);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_99, 1, ((PyObject *)__pyx_n_s__ucs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2_spanish_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_99, 2, ((PyObject *)__pyx_n_s__ucs2_spanish_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2_spanish_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_99, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_99));

  /* "cymysql/charsetx.pyx":140
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 */
  __pyx_k_tuple_100 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_100)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_100);
  __Pyx_INCREF(__pyx_int_136);
  PyTuple_SET_ITEM(__pyx_k_tuple_100, 0, __pyx_int_136);
  __Pyx_GIVEREF(__pyx_int_136);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_100, 1, ((PyObject *)__pyx_n_s__ucs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2_swedish_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_100, 2, ((PyObject *)__pyx_n_s__ucs2_swedish_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2_swedish_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_100, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_100));

  /* "cymysql/charsetx.pyx":141
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 */
  __pyx_k_tuple_101 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_101)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 141; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_101);
  __Pyx_INCREF(__pyx_int_137);
  PyTuple_SET_ITEM(__pyx_k_tuple_101, 0, __pyx_int_137);
  __Pyx_GIVEREF(__pyx_int_137);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_101, 1, ((PyObject *)__pyx_n_s__ucs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2_turkish_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_101, 2, ((PyObject *)__pyx_n_s__ucs2_turkish_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2_turkish_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_101, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_101));

  /* "cymysql/charsetx.pyx":142
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 */
  __pyx_k_tuple_102 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_102)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 142; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_102);
  __Pyx_INCREF(__pyx_int_138);
  PyTuple_SET_ITEM(__pyx_k_tuple_102, 0, __pyx_int_138);
  __Pyx_GIVEREF(__pyx_int_138);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_102, 1, ((PyObject *)__pyx_n_s__ucs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2_czech_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_102, 2, ((PyObject *)__pyx_n_s__ucs2_czech_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2_czech_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_102, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_102));

  /* "cymysql/charsetx.pyx":143
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 */
  __pyx_k_tuple_103 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_103)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_103);
  __Pyx_INCREF(__pyx_int_139);
  PyTuple_SET_ITEM(__pyx_k_tuple_103, 0, __pyx_int_139);
  __Pyx_GIVEREF(__pyx_int_139);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_103, 1, ((PyObject *)__pyx_n_s__ucs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2_danish_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_103, 2, ((PyObject *)__pyx_n_s__ucs2_danish_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2_danish_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_103, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_103));

  /* "cymysql/charsetx.pyx":144
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 */
  __pyx_k_tuple_104 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_104)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 144; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_104);
  __Pyx_INCREF(__pyx_int_140);
  PyTuple_SET_ITEM(__pyx_k_tuple_104, 0, __pyx_int_140);
  __Pyx_GIVEREF(__pyx_int_140);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_104, 1, ((PyObject *)__pyx_n_s__ucs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2_lithuanian_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_104, 2, ((PyObject *)__pyx_n_s__ucs2_lithuanian_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2_lithuanian_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_104, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_104));

  /* "cymysql/charsetx.pyx":145
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 */
  __pyx_k_tuple_105 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_105)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 145; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_105);
  __Pyx_INCREF(__pyx_int_141);
  PyTuple_SET_ITEM(__pyx_k_tuple_105, 0, __pyx_int_141);
  __Pyx_GIVEREF(__pyx_int_141);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_105, 1, ((PyObject *)__pyx_n_s__ucs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2_slovak_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_105, 2, ((PyObject *)__pyx_n_s__ucs2_slovak_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2_slovak_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_105, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_105));

  /* "cymysql/charsetx.pyx":146
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 */
  __pyx_k_tuple_106 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_106)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 146; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_106);
  __Pyx_INCREF(__pyx_int_142);
  PyTuple_SET_ITEM(__pyx_k_tuple_106, 0, __pyx_int_142);
  __Pyx_GIVEREF(__pyx_int_142);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_106, 1, ((PyObject *)__pyx_n_s__ucs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2_spanish2_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_106, 2, ((PyObject *)__pyx_n_s__ucs2_spanish2_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2_spanish2_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_106, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_106));

  /* "cymysql/charsetx.pyx":147
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 */
  __pyx_k_tuple_107 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_107)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 147; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_107);
  __Pyx_INCREF(__pyx_int_143);
  PyTuple_SET_ITEM(__pyx_k_tuple_107, 0, __pyx_int_143);
  __Pyx_GIVEREF(__pyx_int_143);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_107, 1, ((PyObject *)__pyx_n_s__ucs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2_roman_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_107, 2, ((PyObject *)__pyx_n_s__ucs2_roman_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2_roman_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_107, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_107));

  /* "cymysql/charsetx.pyx":148
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 */
  __pyx_k_tuple_108 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_108)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 148; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_108);
  __Pyx_INCREF(__pyx_int_144);
  PyTuple_SET_ITEM(__pyx_k_tuple_108, 0, __pyx_int_144);
  __Pyx_GIVEREF(__pyx_int_144);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_108, 1, ((PyObject *)__pyx_n_s__ucs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2_persian_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_108, 2, ((PyObject *)__pyx_n_s__ucs2_persian_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2_persian_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_108, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_108));

  /* "cymysql/charsetx.pyx":149
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 */
  __pyx_k_tuple_109 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_109)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 149; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_109);
  __Pyx_INCREF(__pyx_int_145);
  PyTuple_SET_ITEM(__pyx_k_tuple_109, 0, __pyx_int_145);
  __Pyx_GIVEREF(__pyx_int_145);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_109, 1, ((PyObject *)__pyx_n_s__ucs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2_esperanto_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_109, 2, ((PyObject *)__pyx_n_s__ucs2_esperanto_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2_esperanto_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_109, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_109));

  /* "cymysql/charsetx.pyx":150
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 */
  __pyx_k_tuple_110 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_110)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 150; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_110);
  __Pyx_INCREF(__pyx_int_146);
  PyTuple_SET_ITEM(__pyx_k_tuple_110, 0, __pyx_int_146);
  __Pyx_GIVEREF(__pyx_int_146);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2));
  PyTuple_SET_ITEM(__pyx_k_tuple_110, 1, ((PyObject *)__pyx_n_s__ucs2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ucs2_hungarian_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_110, 2, ((PyObject *)__pyx_n_s__ucs2_hungarian_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ucs2_hungarian_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_110, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_110));

  /* "cymysql/charsetx.pyx":151
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 */
  __pyx_k_tuple_111 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_111)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 151; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_111);
  __Pyx_INCREF(__pyx_int_192);
  PyTuple_SET_ITEM(__pyx_k_tuple_111, 0, __pyx_int_192);
  __Pyx_GIVEREF(__pyx_int_192);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8));
  PyTuple_SET_ITEM(__pyx_k_tuple_111, 1, ((PyObject *)__pyx_n_s__utf8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8_unicode_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_111, 2, ((PyObject *)__pyx_n_s__utf8_unicode_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8_unicode_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_111, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_111));

  /* "cymysql/charsetx.pyx":152
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 */
  __pyx_k_tuple_112 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_112)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 152; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_112);
  __Pyx_INCREF(__pyx_int_193);
  PyTuple_SET_ITEM(__pyx_k_tuple_112, 0, __pyx_int_193);
  __Pyx_GIVEREF(__pyx_int_193);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8));
  PyTuple_SET_ITEM(__pyx_k_tuple_112, 1, ((PyObject *)__pyx_n_s__utf8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8_icelandic_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_112, 2, ((PyObject *)__pyx_n_s__utf8_icelandic_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8_icelandic_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_112, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_112));

  /* "cymysql/charsetx.pyx":153
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 */
  __pyx_k_tuple_113 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_113)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 153; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_113);
  __Pyx_INCREF(__pyx_int_194);
  PyTuple_SET_ITEM(__pyx_k_tuple_113, 0, __pyx_int_194);
  __Pyx_GIVEREF(__pyx_int_194);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8));
  PyTuple_SET_ITEM(__pyx_k_tuple_113, 1, ((PyObject *)__pyx_n_s__utf8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8_latvian_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_113, 2, ((PyObject *)__pyx_n_s__utf8_latvian_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8_latvian_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_113, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_113));

  /* "cymysql/charsetx.pyx":154
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 */
  __pyx_k_tuple_114 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_114)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_114);
  __Pyx_INCREF(__pyx_int_195);
  PyTuple_SET_ITEM(__pyx_k_tuple_114, 0, __pyx_int_195);
  __Pyx_GIVEREF(__pyx_int_195);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8));
  PyTuple_SET_ITEM(__pyx_k_tuple_114, 1, ((PyObject *)__pyx_n_s__utf8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8_romanian_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_114, 2, ((PyObject *)__pyx_n_s__utf8_romanian_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8_romanian_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_114, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_114));

  /* "cymysql/charsetx.pyx":155
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 */
  __pyx_k_tuple_115 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_115)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 155; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_115);
  __Pyx_INCREF(__pyx_int_196);
  PyTuple_SET_ITEM(__pyx_k_tuple_115, 0, __pyx_int_196);
  __Pyx_GIVEREF(__pyx_int_196);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8));
  PyTuple_SET_ITEM(__pyx_k_tuple_115, 1, ((PyObject *)__pyx_n_s__utf8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8_slovenian_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_115, 2, ((PyObject *)__pyx_n_s__utf8_slovenian_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8_slovenian_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_115, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_115));

  /* "cymysql/charsetx.pyx":156
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 */
  __pyx_k_tuple_116 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_116)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 156; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_116);
  __Pyx_INCREF(__pyx_int_197);
  PyTuple_SET_ITEM(__pyx_k_tuple_116, 0, __pyx_int_197);
  __Pyx_GIVEREF(__pyx_int_197);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8));
  PyTuple_SET_ITEM(__pyx_k_tuple_116, 1, ((PyObject *)__pyx_n_s__utf8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8_polish_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_116, 2, ((PyObject *)__pyx_n_s__utf8_polish_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8_polish_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_116, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_116));

  /* "cymysql/charsetx.pyx":157
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 */
  __pyx_k_tuple_117 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_117)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 157; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_117);
  __Pyx_INCREF(__pyx_int_198);
  PyTuple_SET_ITEM(__pyx_k_tuple_117, 0, __pyx_int_198);
  __Pyx_GIVEREF(__pyx_int_198);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8));
  PyTuple_SET_ITEM(__pyx_k_tuple_117, 1, ((PyObject *)__pyx_n_s__utf8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8_estonian_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_117, 2, ((PyObject *)__pyx_n_s__utf8_estonian_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8_estonian_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_117, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_117));

  /* "cymysql/charsetx.pyx":158
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 */
  __pyx_k_tuple_118 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_118)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 158; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_118);
  __Pyx_INCREF(__pyx_int_199);
  PyTuple_SET_ITEM(__pyx_k_tuple_118, 0, __pyx_int_199);
  __Pyx_GIVEREF(__pyx_int_199);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8));
  PyTuple_SET_ITEM(__pyx_k_tuple_118, 1, ((PyObject *)__pyx_n_s__utf8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8_spanish_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_118, 2, ((PyObject *)__pyx_n_s__utf8_spanish_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8_spanish_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_118, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_118));

  /* "cymysql/charsetx.pyx":159
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 */
  __pyx_k_tuple_119 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_119)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_119);
  __Pyx_INCREF(__pyx_int_200);
  PyTuple_SET_ITEM(__pyx_k_tuple_119, 0, __pyx_int_200);
  __Pyx_GIVEREF(__pyx_int_200);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8));
  PyTuple_SET_ITEM(__pyx_k_tuple_119, 1, ((PyObject *)__pyx_n_s__utf8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8_swedish_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_119, 2, ((PyObject *)__pyx_n_s__utf8_swedish_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8_swedish_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_119, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_119));

  /* "cymysql/charsetx.pyx":160
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 */
  __pyx_k_tuple_120 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_120)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_120);
  __Pyx_INCREF(__pyx_int_201);
  PyTuple_SET_ITEM(__pyx_k_tuple_120, 0, __pyx_int_201);
  __Pyx_GIVEREF(__pyx_int_201);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8));
  PyTuple_SET_ITEM(__pyx_k_tuple_120, 1, ((PyObject *)__pyx_n_s__utf8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8_turkish_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_120, 2, ((PyObject *)__pyx_n_s__utf8_turkish_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8_turkish_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_120, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_120));

  /* "cymysql/charsetx.pyx":161
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 */
  __pyx_k_tuple_121 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_121)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 161; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_121);
  __Pyx_INCREF(__pyx_int_202);
  PyTuple_SET_ITEM(__pyx_k_tuple_121, 0, __pyx_int_202);
  __Pyx_GIVEREF(__pyx_int_202);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8));
  PyTuple_SET_ITEM(__pyx_k_tuple_121, 1, ((PyObject *)__pyx_n_s__utf8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8_czech_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_121, 2, ((PyObject *)__pyx_n_s__utf8_czech_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8_czech_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_121, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_121));

  /* "cymysql/charsetx.pyx":162
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 */
  __pyx_k_tuple_122 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_122)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_122);
  __Pyx_INCREF(__pyx_int_203);
  PyTuple_SET_ITEM(__pyx_k_tuple_122, 0, __pyx_int_203);
  __Pyx_GIVEREF(__pyx_int_203);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8));
  PyTuple_SET_ITEM(__pyx_k_tuple_122, 1, ((PyObject *)__pyx_n_s__utf8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8_danish_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_122, 2, ((PyObject *)__pyx_n_s__utf8_danish_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8_danish_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_122, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_122));

  /* "cymysql/charsetx.pyx":163
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 */
  __pyx_k_tuple_123 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_123)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_123);
  __Pyx_INCREF(__pyx_int_204);
  PyTuple_SET_ITEM(__pyx_k_tuple_123, 0, __pyx_int_204);
  __Pyx_GIVEREF(__pyx_int_204);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8));
  PyTuple_SET_ITEM(__pyx_k_tuple_123, 1, ((PyObject *)__pyx_n_s__utf8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8_lithuanian_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_123, 2, ((PyObject *)__pyx_n_s__utf8_lithuanian_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8_lithuanian_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_123, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_123));

  /* "cymysql/charsetx.pyx":164
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 */
  __pyx_k_tuple_124 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_124)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 164; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_124);
  __Pyx_INCREF(__pyx_int_205);
  PyTuple_SET_ITEM(__pyx_k_tuple_124, 0, __pyx_int_205);
  __Pyx_GIVEREF(__pyx_int_205);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8));
  PyTuple_SET_ITEM(__pyx_k_tuple_124, 1, ((PyObject *)__pyx_n_s__utf8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8_slovak_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_124, 2, ((PyObject *)__pyx_n_s__utf8_slovak_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8_slovak_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_124, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_124));

  /* "cymysql/charsetx.pyx":165
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 */
  __pyx_k_tuple_125 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_125)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 165; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_125);
  __Pyx_INCREF(__pyx_int_206);
  PyTuple_SET_ITEM(__pyx_k_tuple_125, 0, __pyx_int_206);
  __Pyx_GIVEREF(__pyx_int_206);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8));
  PyTuple_SET_ITEM(__pyx_k_tuple_125, 1, ((PyObject *)__pyx_n_s__utf8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8_spanish2_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_125, 2, ((PyObject *)__pyx_n_s__utf8_spanish2_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8_spanish2_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_125, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_125));

  /* "cymysql/charsetx.pyx":166
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))
 */
  __pyx_k_tuple_126 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_126)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 166; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_126);
  __Pyx_INCREF(__pyx_int_207);
  PyTuple_SET_ITEM(__pyx_k_tuple_126, 0, __pyx_int_207);
  __Pyx_GIVEREF(__pyx_int_207);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8));
  PyTuple_SET_ITEM(__pyx_k_tuple_126, 1, ((PyObject *)__pyx_n_s__utf8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8_roman_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_126, 2, ((PyObject *)__pyx_n_s__utf8_roman_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8_roman_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_126, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_126));

  /* "cymysql/charsetx.pyx":167
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))
 * _charsets.add(Charset(210, 'utf8', 'utf8_hungarian_ci', ''))
 */
  __pyx_k_tuple_127 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_127)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 167; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_127);
  __Pyx_INCREF(__pyx_int_208);
  PyTuple_SET_ITEM(__pyx_k_tuple_127, 0, __pyx_int_208);
  __Pyx_GIVEREF(__pyx_int_208);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8));
  PyTuple_SET_ITEM(__pyx_k_tuple_127, 1, ((PyObject *)__pyx_n_s__utf8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8_persian_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_127, 2, ((PyObject *)__pyx_n_s__utf8_persian_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8_persian_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_127, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_127));

  /* "cymysql/charsetx.pyx":168
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(210, 'utf8', 'utf8_hungarian_ci', ''))
 */
  __pyx_k_tuple_128 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_128)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_128);
  __Pyx_INCREF(__pyx_int_209);
  PyTuple_SET_ITEM(__pyx_k_tuple_128, 0, __pyx_int_209);
  __Pyx_GIVEREF(__pyx_int_209);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8));
  PyTuple_SET_ITEM(__pyx_k_tuple_128, 1, ((PyObject *)__pyx_n_s__utf8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8_esperanto_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_128, 2, ((PyObject *)__pyx_n_s__utf8_esperanto_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8_esperanto_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_128, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_128));

  /* "cymysql/charsetx.pyx":169
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))
 * _charsets.add(Charset(210, 'utf8', 'utf8_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 */
  __pyx_k_tuple_129 = PyTuple_New(4); if (unlikely(!__pyx_k_tuple_129)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 169; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_129);
  __Pyx_INCREF(__pyx_int_210);
  PyTuple_SET_ITEM(__pyx_k_tuple_129, 0, __pyx_int_210);
  __Pyx_GIVEREF(__pyx_int_210);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8));
  PyTuple_SET_ITEM(__pyx_k_tuple_129, 1, ((PyObject *)__pyx_n_s__utf8));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__utf8_hungarian_ci));
  PyTuple_SET_ITEM(__pyx_k_tuple_129, 2, ((PyObject *)__pyx_n_s__utf8_hungarian_ci));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__utf8_hungarian_ci));
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_129, 3, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_129));
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_4 = PyInt_FromLong(4); if (unlikely(!__pyx_int_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_5 = PyInt_FromLong(5); if (unlikely(!__pyx_int_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_6 = PyInt_FromLong(6); if (unlikely(!__pyx_int_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_7 = PyInt_FromLong(7); if (unlikely(!__pyx_int_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_8 = PyInt_FromLong(8); if (unlikely(!__pyx_int_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_9 = PyInt_FromLong(9); if (unlikely(!__pyx_int_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_10 = PyInt_FromLong(10); if (unlikely(!__pyx_int_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_11 = PyInt_FromLong(11); if (unlikely(!__pyx_int_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_12 = PyInt_FromLong(12); if (unlikely(!__pyx_int_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_13 = PyInt_FromLong(13); if (unlikely(!__pyx_int_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_14 = PyInt_FromLong(14); if (unlikely(!__pyx_int_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_15 = PyInt_FromLong(15); if (unlikely(!__pyx_int_15)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_16 = PyInt_FromLong(16); if (unlikely(!__pyx_int_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_18 = PyInt_FromLong(18); if (unlikely(!__pyx_int_18)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_19 = PyInt_FromLong(19); if (unlikely(!__pyx_int_19)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_20 = PyInt_FromLong(20); if (unlikely(!__pyx_int_20)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_21 = PyInt_FromLong(21); if (unlikely(!__pyx_int_21)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_22 = PyInt_FromLong(22); if (unlikely(!__pyx_int_22)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_23 = PyInt_FromLong(23); if (unlikely(!__pyx_int_23)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_24 = PyInt_FromLong(24); if (unlikely(!__pyx_int_24)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_25 = PyInt_FromLong(25); if (unlikely(!__pyx_int_25)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_26 = PyInt_FromLong(26); if (unlikely(!__pyx_int_26)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_27 = PyInt_FromLong(27); if (unlikely(!__pyx_int_27)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_28 = PyInt_FromLong(28); if (unlikely(!__pyx_int_28)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_29 = PyInt_FromLong(29); if (unlikely(!__pyx_int_29)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_30 = PyInt_FromLong(30); if (unlikely(!__pyx_int_30)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_31 = PyInt_FromLong(31); if (unlikely(!__pyx_int_31)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_32 = PyInt_FromLong(32); if (unlikely(!__pyx_int_32)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_33 = PyInt_FromLong(33); if (unlikely(!__pyx_int_33)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_34 = PyInt_FromLong(34); if (unlikely(!__pyx_int_34)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_35 = PyInt_FromLong(35); if (unlikely(!__pyx_int_35)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_36 = PyInt_FromLong(36); if (unlikely(!__pyx_int_36)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_37 = PyInt_FromLong(37); if (unlikely(!__pyx_int_37)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_38 = PyInt_FromLong(38); if (unlikely(!__pyx_int_38)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_39 = PyInt_FromLong(39); if (unlikely(!__pyx_int_39)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_40 = PyInt_FromLong(40); if (unlikely(!__pyx_int_40)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_41 = PyInt_FromLong(41); if (unlikely(!__pyx_int_41)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_42 = PyInt_FromLong(42); if (unlikely(!__pyx_int_42)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_43 = PyInt_FromLong(43); if (unlikely(!__pyx_int_43)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_44 = PyInt_FromLong(44); if (unlikely(!__pyx_int_44)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_47 = PyInt_FromLong(47); if (unlikely(!__pyx_int_47)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_48 = PyInt_FromLong(48); if (unlikely(!__pyx_int_48)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_49 = PyInt_FromLong(49); if (unlikely(!__pyx_int_49)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_50 = PyInt_FromLong(50); if (unlikely(!__pyx_int_50)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_51 = PyInt_FromLong(51); if (unlikely(!__pyx_int_51)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_52 = PyInt_FromLong(52); if (unlikely(!__pyx_int_52)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_53 = PyInt_FromLong(53); if (unlikely(!__pyx_int_53)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_57 = PyInt_FromLong(57); if (unlikely(!__pyx_int_57)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_58 = PyInt_FromLong(58); if (unlikely(!__pyx_int_58)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_59 = PyInt_FromLong(59); if (unlikely(!__pyx_int_59)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_63 = PyInt_FromLong(63); if (unlikely(!__pyx_int_63)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_64 = PyInt_FromLong(64); if (unlikely(!__pyx_int_64)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_65 = PyInt_FromLong(65); if (unlikely(!__pyx_int_65)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_66 = PyInt_FromLong(66); if (unlikely(!__pyx_int_66)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_67 = PyInt_FromLong(67); if (unlikely(!__pyx_int_67)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_68 = PyInt_FromLong(68); if (unlikely(!__pyx_int_68)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_69 = PyInt_FromLong(69); if (unlikely(!__pyx_int_69)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_70 = PyInt_FromLong(70); if (unlikely(!__pyx_int_70)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_71 = PyInt_FromLong(71); if (unlikely(!__pyx_int_71)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_72 = PyInt_FromLong(72); if (unlikely(!__pyx_int_72)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_73 = PyInt_FromLong(73); if (unlikely(!__pyx_int_73)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_74 = PyInt_FromLong(74); if (unlikely(!__pyx_int_74)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_75 = PyInt_FromLong(75); if (unlikely(!__pyx_int_75)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_77 = PyInt_FromLong(77); if (unlikely(!__pyx_int_77)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_78 = PyInt_FromLong(78); if (unlikely(!__pyx_int_78)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_79 = PyInt_FromLong(79); if (unlikely(!__pyx_int_79)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_80 = PyInt_FromLong(80); if (unlikely(!__pyx_int_80)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_81 = PyInt_FromLong(81); if (unlikely(!__pyx_int_81)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_82 = PyInt_FromLong(82); if (unlikely(!__pyx_int_82)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_83 = PyInt_FromLong(83); if (unlikely(!__pyx_int_83)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_84 = PyInt_FromLong(84); if (unlikely(!__pyx_int_84)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_85 = PyInt_FromLong(85); if (unlikely(!__pyx_int_85)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_86 = PyInt_FromLong(86); if (unlikely(!__pyx_int_86)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_87 = PyInt_FromLong(87); if (unlikely(!__pyx_int_87)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_88 = PyInt_FromLong(88); if (unlikely(!__pyx_int_88)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_89 = PyInt_FromLong(89); if (unlikely(!__pyx_int_89)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_90 = PyInt_FromLong(90); if (unlikely(!__pyx_int_90)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_91 = PyInt_FromLong(91); if (unlikely(!__pyx_int_91)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_92 = PyInt_FromLong(92); if (unlikely(!__pyx_int_92)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_93 = PyInt_FromLong(93); if (unlikely(!__pyx_int_93)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_94 = PyInt_FromLong(94); if (unlikely(!__pyx_int_94)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_95 = PyInt_FromLong(95); if (unlikely(!__pyx_int_95)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_96 = PyInt_FromLong(96); if (unlikely(!__pyx_int_96)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_97 = PyInt_FromLong(97); if (unlikely(!__pyx_int_97)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_98 = PyInt_FromLong(98); if (unlikely(!__pyx_int_98)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_99 = PyInt_FromLong(99); if (unlikely(!__pyx_int_99)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_128 = PyInt_FromLong(128); if (unlikely(!__pyx_int_128)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_129 = PyInt_FromLong(129); if (unlikely(!__pyx_int_129)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_130 = PyInt_FromLong(130); if (unlikely(!__pyx_int_130)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_131 = PyInt_FromLong(131); if (unlikely(!__pyx_int_131)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_132 = PyInt_FromLong(132); if (unlikely(!__pyx_int_132)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_133 = PyInt_FromLong(133); if (unlikely(!__pyx_int_133)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_134 = PyInt_FromLong(134); if (unlikely(!__pyx_int_134)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_135 = PyInt_FromLong(135); if (unlikely(!__pyx_int_135)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_136 = PyInt_FromLong(136); if (unlikely(!__pyx_int_136)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_137 = PyInt_FromLong(137); if (unlikely(!__pyx_int_137)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_138 = PyInt_FromLong(138); if (unlikely(!__pyx_int_138)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_139 = PyInt_FromLong(139); if (unlikely(!__pyx_int_139)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_140 = PyInt_FromLong(140); if (unlikely(!__pyx_int_140)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_141 = PyInt_FromLong(141); if (unlikely(!__pyx_int_141)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_142 = PyInt_FromLong(142); if (unlikely(!__pyx_int_142)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_143 = PyInt_FromLong(143); if (unlikely(!__pyx_int_143)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_144 = PyInt_FromLong(144); if (unlikely(!__pyx_int_144)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_145 = PyInt_FromLong(145); if (unlikely(!__pyx_int_145)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_146 = PyInt_FromLong(146); if (unlikely(!__pyx_int_146)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_192 = PyInt_FromLong(192); if (unlikely(!__pyx_int_192)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_193 = PyInt_FromLong(193); if (unlikely(!__pyx_int_193)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_194 = PyInt_FromLong(194); if (unlikely(!__pyx_int_194)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_195 = PyInt_FromLong(195); if (unlikely(!__pyx_int_195)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_196 = PyInt_FromLong(196); if (unlikely(!__pyx_int_196)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_197 = PyInt_FromLong(197); if (unlikely(!__pyx_int_197)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_198 = PyInt_FromLong(198); if (unlikely(!__pyx_int_198)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_199 = PyInt_FromLong(199); if (unlikely(!__pyx_int_199)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_200 = PyInt_FromLong(200); if (unlikely(!__pyx_int_200)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_201 = PyInt_FromLong(201); if (unlikely(!__pyx_int_201)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_202 = PyInt_FromLong(202); if (unlikely(!__pyx_int_202)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_203 = PyInt_FromLong(203); if (unlikely(!__pyx_int_203)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_204 = PyInt_FromLong(204); if (unlikely(!__pyx_int_204)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_205 = PyInt_FromLong(205); if (unlikely(!__pyx_int_205)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_206 = PyInt_FromLong(206); if (unlikely(!__pyx_int_206)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_207 = PyInt_FromLong(207); if (unlikely(!__pyx_int_207)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_208 = PyInt_FromLong(208); if (unlikely(!__pyx_int_208)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_209 = PyInt_FromLong(209); if (unlikely(!__pyx_int_209)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_210 = PyInt_FromLong(210); if (unlikely(!__pyx_int_210)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  return 0;
  __pyx_L1_error:;
  return -1;
}

#if PY_MAJOR_VERSION < 3
PyMODINIT_FUNC initcharsetx(void); /*proto*/
PyMODINIT_FUNC initcharsetx(void)
#else
PyMODINIT_FUNC PyInit_charsetx(void); /*proto*/
PyMODINIT_FUNC PyInit_charsetx(void)
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannyDeclarations
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
      PyErr_Clear();
      __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
      if (!__Pyx_RefNanny)
          Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  __Pyx_RefNannySetupContext("PyMODINIT_FUNC PyInit_charsetx(void)", 0);
  if ( __Pyx_check_binary_version() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #ifdef __Pyx_CyFunction_USED
  if (__Pyx_CyFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4(__Pyx_NAMESTR("charsetx"), __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (!PyDict_GetItemString(modules, "cymysql.charsetx")) {
      if (unlikely(PyDict_SetItemString(modules, "cymysql.charsetx", __pyx_m) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
  }
  #endif
  __pyx_b = PyImport_AddModule(__Pyx_NAMESTR(__Pyx_BUILTIN_MODULE_NAME)); if (unlikely(!__pyx_b)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if CYTHON_COMPILING_IN_PYPY
  Py_INCREF(__pyx_b);
  #endif
  if (__Pyx_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  /*--- Initialize various global constants etc. ---*/
  if (unlikely(__Pyx_InitGlobals() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_module_is_main_cymysql__charsetx) {
    if (__Pyx_SetAttrString(__pyx_m, "__name__", __pyx_n_s____main__) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  }
  /*--- Builtin init code ---*/
  if (unlikely(__Pyx_InitCachedBuiltins() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Constants init code ---*/
  if (unlikely(__Pyx_InitCachedConstants() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Global init code ---*/
  __pyx_v_7cymysql_8charsetx__charsets = ((struct __pyx_obj_7cymysql_8charsetx_Charsets *)Py_None); Py_INCREF(Py_None);
  /*--- Variable export code ---*/
  /*--- Function export code ---*/
  /*--- Type init code ---*/
  if (PyType_Ready(&__pyx_type_7cymysql_8charsetx_Charset) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "Charset", (PyObject *)&__pyx_type_7cymysql_8charsetx_Charset) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_7cymysql_8charsetx_Charset = &__pyx_type_7cymysql_8charsetx_Charset;
  if (PyType_Ready(&__pyx_type_7cymysql_8charsetx_Charsets) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 9; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "Charsets", (PyObject *)&__pyx_type_7cymysql_8charsetx_Charsets) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 9; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_7cymysql_8charsetx_Charsets = &__pyx_type_7cymysql_8charsetx_Charsets;
  /*--- Type import code ---*/
  /*--- Variable import code ---*/
  /*--- Function import code ---*/
  /*--- Execution code ---*/

  /* "cymysql/charsetx.pyx":26
 *                 return c
 * 
 * cdef Charsets _charsets = Charsets()             # <<<<<<<<<<<<<<
 * 
 * charset_by_name = _charsets.by_name
 */
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charsets)), ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_XGOTREF(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets));
  __Pyx_DECREF(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets));
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_v_7cymysql_8charsetx__charsets = ((struct __pyx_obj_7cymysql_8charsetx_Charsets *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":28
 * cdef Charsets _charsets = Charsets()
 * 
 * charset_by_name = _charsets.by_name             # <<<<<<<<<<<<<<
 * charset_by_id = _charsets.by_id
 * 
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__by_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 28; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__charset_by_name, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 28; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":29
 * 
 * charset_by_name = _charsets.by_name
 * charset_by_id = _charsets.by_id             # <<<<<<<<<<<<<<
 * 
 * """
 */
  __pyx_t_1 = __pyx_v_7cymysql_8charsetx__charsets->by_id;
  __Pyx_INCREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__charset_by_id, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 29; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":43
 * 
 * """
 * _charsets.add(Charset(1, 'big5', 'big5_chinese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":44
 * """
 * _charsets.add(Charset(1, 'big5', 'big5_chinese_ci', 'Yes'))
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 44; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_3), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 44; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 44; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 44; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":45
 * _charsets.add(Charset(1, 'big5', 'big5_chinese_ci', 'Yes'))
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_4), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":46
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 46; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_5), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 46; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 46; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 46; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":47
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 47; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_6), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 47; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 47; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 47; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":48
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 48; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_7), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 48; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 48; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 48; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":49
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 49; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_8), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 49; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 49; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 49; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":50
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 50; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_9), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 50; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 50; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 50; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":51
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_10), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":52
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 52; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_11), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 52; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 52; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 52; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":53
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 53; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_12), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 53; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 53; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 53; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":54
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 54; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_13), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 54; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 54; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 54; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":55
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 55; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_14), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 55; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 55; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 55; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":56
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 56; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_15), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 56; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 56; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 56; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":57
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 57; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_16), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 57; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 57; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 57; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":58
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 58; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_17), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 58; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 58; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 58; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":59
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 59; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_18), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 59; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 59; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 59; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":60
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 60; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_19), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 60; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 60; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 60; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":61
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 61; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_20), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 61; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 61; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 61; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":62
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_21), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":63
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 63; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_22), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 63; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 63; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 63; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":64
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 64; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_23), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 64; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 64; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 64; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":65
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_24), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":66
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_25), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":67
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_26), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":68
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 68; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_27), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 68; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 68; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 68; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":69
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 69; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_28), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 69; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 69; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 69; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":70
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 70; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_30), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 70; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 70; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 70; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":71
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_31), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":72
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 72; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_32), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 72; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 72; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 72; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":73
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_33), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":74
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_34), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":75
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 75; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_35), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 75; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 75; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 75; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":76
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_36), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":77
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 77; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_37), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 77; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 77; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 77; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":78
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_38), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":79
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 79; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_39), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 79; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 79; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 79; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":80
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 80; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_40), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 80; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 80; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 80; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":81
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_41), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":82
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 82; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_42), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 82; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 82; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 82; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":83
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_43), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":84
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 84; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_44), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 84; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 84; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 84; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":85
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 85; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_45), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 85; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 85; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 85; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":86
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_46), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":87
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 87; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_47), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 87; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 87; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 87; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":88
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 88; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_48), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 88; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 88; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 88; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":89
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 89; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_49), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 89; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 89; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 89; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":90
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 90; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_50), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 90; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 90; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 90; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":91
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 91; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_51), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 91; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 91; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 91; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":92
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 92; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_52), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 92; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 92; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 92; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":93
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 93; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_53), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 93; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 93; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 93; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":94
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 94; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_54), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 94; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 94; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 94; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":95
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 95; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_55), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 95; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 95; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 95; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":96
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 96; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_56), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 96; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 96; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 96; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":97
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 97; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_57), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 97; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 97; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 97; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":98
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 98; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_58), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 98; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 98; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 98; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":99
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 99; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_59), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 99; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 99; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 99; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":100
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 100; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_60), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 100; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 100; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 100; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":101
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 101; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_61), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 101; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 101; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 101; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":102
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_62), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":103
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_63), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":104
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 104; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_64), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 104; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 104; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 104; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":105
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_65), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":106
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_66), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":107
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_67), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":108
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 108; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_68), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 108; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 108; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 108; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":109
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_69), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":110
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 110; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_70), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 110; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 110; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 110; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":111
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 111; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_71), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 111; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 111; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 111; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":112
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 112; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_72), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 112; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 112; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 112; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":113
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 113; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_73), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 113; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 113; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 113; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":114
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 114; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_74), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 114; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 114; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 114; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":115
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_75), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":116
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 116; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_76), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 116; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 116; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 116; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":117
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 117; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_77), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 117; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 117; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 117; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":118
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 118; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_78), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 118; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 118; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 118; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":119
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 119; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_79), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 119; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 119; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 119; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":120
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_80), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":121
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 121; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_81), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 121; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 121; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 121; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":122
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 122; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_82), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 122; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 122; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 122; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":123
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 123; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_83), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 123; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 123; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 123; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":124
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 124; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_84), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 124; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 124; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 124; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":125
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 125; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_85), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 125; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 125; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 125; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":126
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 126; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_86), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 126; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 126; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 126; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":127
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_87), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":128
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_88), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":129
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_89), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":130
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 130; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_90), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 130; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 130; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 130; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":131
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 131; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_91), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 131; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 131; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 131; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":132
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_92), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":133
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_93), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":134
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 134; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_94), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 134; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 134; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 134; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":135
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 135; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_95), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 135; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 135; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 135; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":136
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 136; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_96), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 136; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 136; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 136; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":137
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 137; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_97), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 137; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 137; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 137; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":138
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_98), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":139
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 139; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_99), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 139; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 139; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 139; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":140
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_100), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":141
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 141; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_101), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 141; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 141; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 141; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":142
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 142; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_102), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 142; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 142; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 142; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":143
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_103), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":144
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 144; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_104), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 144; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 144; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 144; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":145
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 145; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_105), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 145; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 145; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 145; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":146
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 146; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_106), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 146; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 146; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 146; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":147
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 147; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_107), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 147; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 147; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 147; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":148
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 148; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_108), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 148; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 148; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 148; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":149
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 149; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_109), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 149; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 149; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 149; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":150
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 150; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_110), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 150; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 150; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 150; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":151
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 151; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_111), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 151; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 151; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 151; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":152
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 152; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_112), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 152; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 152; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 152; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":153
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 153; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_113), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 153; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 153; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 153; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":154
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_114), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":155
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 155; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_115), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 155; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 155; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 155; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":156
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 156; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_116), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 156; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 156; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 156; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":157
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 157; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_117), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 157; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 157; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 157; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":158
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 158; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_118), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 158; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 158; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 158; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":159
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_119), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":160
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_120), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":161
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 161; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_121), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 161; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 161; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 161; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":162
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_122), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":163
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_123), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":164
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 164; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_124), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 164; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 164; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 164; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":165
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 165; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_125), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 165; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 165; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 165; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":166
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 166; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_126), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 166; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 166; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 166; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":167
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))
 * _charsets.add(Charset(210, 'utf8', 'utf8_hungarian_ci', ''))
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 167; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_127), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 167; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 167; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 167; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/charsetx.pyx":168
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(210, 'utf8', 'utf8_hungarian_ci', ''))
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_128), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charsetx.pyx":169
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))
 * _charsets.add(Charset(210, 'utf8', 'utf8_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_7cymysql_8charsetx__charsets), __pyx_n_s__add); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 169; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_8charsetx_Charset)), ((PyObject *)__pyx_k_tuple_129), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 169; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 169; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 169; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charsetx.pyx":1
 * cdef class Charset(object):             # <<<<<<<<<<<<<<
 *     cdef public int id
 *     cdef public str name, collation
 */
  __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_2));
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s____test__, ((PyObject *)__pyx_t_2)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  if (__pyx_m) {
    __Pyx_AddTraceback("init cymysql.charsetx", __pyx_clineno, __pyx_lineno, __pyx_filename);
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init cymysql.charsetx");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if PY_MAJOR_VERSION < 3
  return;
  #else
  return __pyx_m;
  #endif
}

/* Runtime support code */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif /* CYTHON_REFNANNY */

static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%s() takes %s %" CYTHON_FORMAT_SSIZE_T "d positional argument%s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_CheckExact(key)) || likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (PyUnicode_GET_SIZE(**name) != PyUnicode_GET_SIZE(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (PyUnicode_GET_SIZE(**argname) != PyUnicode_GET_SIZE(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%s() got an unexpected keyword argument '%s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

static CYTHON_INLINE int __Pyx_CheckKeywordStrings(
    PyObject *kwdict,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CPYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kwdict, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    while (PyDict_Next(kwdict, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_CheckExact(key)) && unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if ((!kw_allowed) && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%s() got an unexpected keyword argument '%s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

static int __Pyx_ArgTypeTest(PyObject *obj, PyTypeObject *type, int none_allowed,
    const char *name, int exact)
{
    if (!type) {
        PyErr_Format(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (none_allowed && obj == Py_None) return 1;
    else if (exact) {
        if (Py_TYPE(obj) == type) return 1;
    }
    else {
        if (PyObject_TypeCheck(obj, type)) return 1;
    }
    PyErr_Format(PyExc_TypeError,
        "Argument '%s' has incorrect type (expected %s, got %s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
    return 0;
}

static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(exc_type == PyExc_StopIteration) || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%s to unpack",
                 index, (index == 1) ? "" : "s");
}

static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else if (PyTuple_GET_SIZE(t) < index) {
      __Pyx_RaiseNeedMoreValuesError(PyTuple_GET_SIZE(t));
    } else {
      __Pyx_RaiseTooManyValuesError(index);
    }
}

static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    } else {
        return __Pyx_IterFinish();
    }
    return 0;
}

static CYTHON_INLINE int __Pyx_unpack_tuple2(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                             int is_tuple, int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    if (!is_tuple && unlikely(!PyTuple_Check(tuple))) {
        iternextfunc iternext;
        iter = PyObject_GetIter(tuple);
        if (unlikely(!iter)) goto bad;
        if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
        iternext = Py_TYPE(iter)->tp_iternext;
        value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
        value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
        if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
        Py_DECREF(iter);
    } else {
        if (!has_known_size && unlikely(PyTuple_GET_SIZE(tuple) != 2)) {
            __Pyx_UnpackTupleError(tuple, 2);
            goto bad;
        }
#if CYTHON_COMPILING_IN_PYPY
        value1 = PySequence_ITEM(tuple, 0);
        if (unlikely(!value1)) goto bad;
        value2 = PySequence_ITEM(tuple, 1);
        if (unlikely(!value2)) goto bad;
#else
        value1 = PyTuple_GET_ITEM(tuple, 0);
        value2 = PyTuple_GET_ITEM(tuple, 1);
        Py_INCREF(value1);
        Py_INCREF(value2);
#endif
        if (decref_tuple) { Py_DECREF(tuple); }
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
#if !CYTHON_COMPILING_IN_PYPY
    if (is_dict) {
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
    }
#endif
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = PyObject_CallMethodObjArgs(iterable, method_name, NULL);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* iter_obj, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_COMPILING_IN_PYPY
    if (source_is_dict) {
        PyObject *key, *value;
        if (unlikely(orig_length != PyDict_Size(iter_obj))) {
            PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
            return -1;
        }
        if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
            return 0;
        }
        if (pitem) {
            PyObject* tuple = PyTuple_New(2);
            if (unlikely(!tuple)) {
                return -1;
            }
            Py_INCREF(key);
            Py_INCREF(value);
            PyTuple_SET_ITEM(tuple, 0, key);
            PyTuple_SET_ITEM(tuple, 1, value);
            *pitem = tuple;
        } else {
            if (pkey) {
                Py_INCREF(key);
                *pkey = key;
            }
            if (pvalue) {
                Py_INCREF(value);
                *pvalue = value;
            }
        }
        return 1;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyTuple_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyList_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyList_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_Format(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(PyObject_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

static CYTHON_INLINE unsigned char __Pyx_PyInt_AsUnsignedChar(PyObject* x) {
    const unsigned char neg_one = (unsigned char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned char" :
                    "value too large to convert to unsigned char");
            }
            return (unsigned char)-1;
        }
        return (unsigned char)val;
    }
    return (unsigned char)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE unsigned short __Pyx_PyInt_AsUnsignedShort(PyObject* x) {
    const unsigned short neg_one = (unsigned short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned short" :
                    "value too large to convert to unsigned short");
            }
            return (unsigned short)-1;
        }
        return (unsigned short)val;
    }
    return (unsigned short)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE unsigned int __Pyx_PyInt_AsUnsignedInt(PyObject* x) {
    const unsigned int neg_one = (unsigned int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned int" :
                    "value too large to convert to unsigned int");
            }
            return (unsigned int)-1;
        }
        return (unsigned int)val;
    }
    return (unsigned int)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE char __Pyx_PyInt_AsChar(PyObject* x) {
    const char neg_one = (char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to char" :
                    "value too large to convert to char");
            }
            return (char)-1;
        }
        return (char)val;
    }
    return (char)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE short __Pyx_PyInt_AsShort(PyObject* x) {
    const short neg_one = (short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to short" :
                    "value too large to convert to short");
            }
            return (short)-1;
        }
        return (short)val;
    }
    return (short)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE int __Pyx_PyInt_AsInt(PyObject* x) {
    const int neg_one = (int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to int" :
                    "value too large to convert to int");
            }
            return (int)-1;
        }
        return (int)val;
    }
    return (int)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE signed char __Pyx_PyInt_AsSignedChar(PyObject* x) {
    const signed char neg_one = (signed char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed char" :
                    "value too large to convert to signed char");
            }
            return (signed char)-1;
        }
        return (signed char)val;
    }
    return (signed char)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE signed short __Pyx_PyInt_AsSignedShort(PyObject* x) {
    const signed short neg_one = (signed short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed short" :
                    "value too large to convert to signed short");
            }
            return (signed short)-1;
        }
        return (signed short)val;
    }
    return (signed short)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE signed int __Pyx_PyInt_AsSignedInt(PyObject* x) {
    const signed int neg_one = (signed int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed int" :
                    "value too large to convert to signed int");
            }
            return (signed int)-1;
        }
        return (signed int)val;
    }
    return (signed int)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE int __Pyx_PyInt_AsLongDouble(PyObject* x) {
    const int neg_one = (int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to int" :
                    "value too large to convert to int");
            }
            return (int)-1;
        }
        return (int)val;
    }
    return (int)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE unsigned long __Pyx_PyInt_AsUnsignedLong(PyObject* x) {
    const unsigned long neg_one = (unsigned long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to unsigned long");
            return (unsigned long)-1;
        }
        return (unsigned long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to unsigned long");
                return (unsigned long)-1;
            }
            return (unsigned long)PyLong_AsUnsignedLong(x);
        } else {
            return (unsigned long)PyLong_AsLong(x);
        }
    } else {
        unsigned long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (unsigned long)-1;
        val = __Pyx_PyInt_AsUnsignedLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE unsigned PY_LONG_LONG __Pyx_PyInt_AsUnsignedLongLong(PyObject* x) {
    const unsigned PY_LONG_LONG neg_one = (unsigned PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to unsigned PY_LONG_LONG");
            return (unsigned PY_LONG_LONG)-1;
        }
        return (unsigned PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to unsigned PY_LONG_LONG");
                return (unsigned PY_LONG_LONG)-1;
            }
            return (unsigned PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
            return (unsigned PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        unsigned PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (unsigned PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsUnsignedLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE long __Pyx_PyInt_AsLong(PyObject* x) {
    const long neg_one = (long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to long");
            return (long)-1;
        }
        return (long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to long");
                return (long)-1;
            }
            return (long)PyLong_AsUnsignedLong(x);
        } else {
            return (long)PyLong_AsLong(x);
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (long)-1;
        val = __Pyx_PyInt_AsLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_AsLongLong(PyObject* x) {
    const PY_LONG_LONG neg_one = (PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to PY_LONG_LONG");
            return (PY_LONG_LONG)-1;
        }
        return (PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to PY_LONG_LONG");
                return (PY_LONG_LONG)-1;
            }
            return (PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
            return (PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE signed long __Pyx_PyInt_AsSignedLong(PyObject* x) {
    const signed long neg_one = (signed long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to signed long");
            return (signed long)-1;
        }
        return (signed long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to signed long");
                return (signed long)-1;
            }
            return (signed long)PyLong_AsUnsignedLong(x);
        } else {
            return (signed long)PyLong_AsLong(x);
        }
    } else {
        signed long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (signed long)-1;
        val = __Pyx_PyInt_AsSignedLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE signed PY_LONG_LONG __Pyx_PyInt_AsSignedLongLong(PyObject* x) {
    const signed PY_LONG_LONG neg_one = (signed PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to signed PY_LONG_LONG");
            return (signed PY_LONG_LONG)-1;
        }
        return (signed PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to signed PY_LONG_LONG");
                return (signed PY_LONG_LONG)-1;
            }
            return (signed PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
            return (signed PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        signed PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (signed PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsSignedLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        #if PY_VERSION_HEX < 0x02050000
        return PyErr_Warn(NULL, message);
        #else
        return PyErr_WarnEx(NULL, message, 1);
        #endif
    }
    return 0;
}

static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = (start + end) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,            /*int argcount,*/
        0,            /*int kwonlyargcount,*/
        0,            /*int nlocals,*/
        0,            /*int stacksize,*/
        0,            /*int flags,*/
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,      /*int firstlineno,*/
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_globals = 0;
    PyFrameObject *py_frame = 0;
    py_code = __pyx_find_code_object(c_line ? c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? c_line : py_line, py_code);
    }
    py_globals = PyModule_GetDict(__pyx_m);
    if (!py_globals) goto bad;
    py_frame = PyFrame_New(
        PyThreadState_GET(), /*PyThreadState *tstate,*/
        py_code,             /*PyCodeObject *code,*/
        py_globals,          /*PyObject *globals,*/
        0                    /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    py_frame->f_lineno = py_line;
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else  /* Python 3+ has unicode identifiers */
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        ++t;
    }
    return 0;
}


/* Type Conversion Functions */

static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}

static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x) {
  PyNumberMethods *m;
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_VERSION_HEX < 0x03000000
  if (PyInt_Check(x) || PyLong_Check(x))
#else
  if (PyLong_Check(x))
#endif
    return Py_INCREF(x), x;
  m = Py_TYPE(x)->tp_as_number;
#if PY_VERSION_HEX < 0x03000000
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = PyNumber_Long(x);
  }
#else
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Long(x);
  }
#endif
  if (res) {
#if PY_VERSION_HEX < 0x03000000
    if (!PyInt_Check(res) && !PyLong_Check(res)) {
#else
    if (!PyLong_Check(res)) {
#endif
      PyErr_Format(PyExc_TypeError,
                   "__%s__ returned non-%s (type %.200s)",
                   name, name, Py_TYPE(res)->tp_name);
      Py_DECREF(res);
      return NULL;
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}

static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject* x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}

static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
#if PY_VERSION_HEX < 0x02050000
   if (ival <= LONG_MAX)
       return PyInt_FromLong((long)ival);
   else {
       unsigned char *bytes = (unsigned char *) &ival;
       int one = 1; int little = (int)*(unsigned char*)&one;
       return _PyLong_FromByteArray(bytes, sizeof(size_t), little, 0);
   }
#else
   return PyInt_FromSize_t(ival);
#endif
}

static CYTHON_INLINE size_t __Pyx_PyInt_AsSize_t(PyObject* x) {
   unsigned PY_LONG_LONG val = __Pyx_PyInt_AsUnsignedLongLong(x);
   if (unlikely(val == (unsigned PY_LONG_LONG)-1 && PyErr_Occurred())) {
       return (size_t)-1;
   } else if (unlikely(val != (unsigned PY_LONG_LONG)(size_t)val)) {
       PyErr_SetString(PyExc_OverflowError,
                       "value too large to convert to size_t");
       return (size_t)-1;
   }
   return (size_t)val;
}


#endif /* Py_PYTHON_H */
